package io.netty.channel;

import io.netty.buffer.ByteBuf;
import io.netty.buffer.ByteBufAllocator;
import io.netty.buffer.CompositeByteBuf;
import io.netty.util.ReferenceCountUtil;
import io.netty.util.concurrent.Future;
import io.netty.util.concurrent.GenericFutureListener;
import io.netty.util.internal.ObjectUtil;
import io.netty.util.internal.PlatformDependent;
import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.util.ArrayDeque;
/* loaded from: classes.dex */
public abstract class AbstractCoalescingBufferQueue {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final InternalLogger logger = InternalLoggerFactory.getInstance(AbstractCoalescingBufferQueue.class);
    private final ArrayDeque<Object> bufAndListenerPairs;
    private int readableBytes;
    private final PendingBytesTracker tracker;

    protected abstract ByteBuf compose(ByteBufAllocator byteBufAllocator, ByteBuf byteBuf, ByteBuf byteBuf2);

    protected abstract ByteBuf removeEmptyValue();

    /* JADX INFO: Access modifiers changed from: protected */
    public AbstractCoalescingBufferQueue(Channel channel, int initSize) {
        this.bufAndListenerPairs = new ArrayDeque<>(initSize);
        this.tracker = channel == null ? null : PendingBytesTracker.newTracker(channel);
    }

    public final void addFirst(ByteBuf buf, ChannelPromise promise) {
        addFirst(buf, toChannelFutureListener(promise));
    }

    private void addFirst(ByteBuf buf, ChannelFutureListener listener) {
        if (listener != null) {
            this.bufAndListenerPairs.addFirst(listener);
        }
        this.bufAndListenerPairs.addFirst(buf);
        incrementReadableBytes(buf.readableBytes());
    }

    public final void add(ByteBuf buf) {
        add(buf, (ChannelFutureListener) null);
    }

    public final void add(ByteBuf buf, ChannelPromise promise) {
        add(buf, toChannelFutureListener(promise));
    }

    public final void add(ByteBuf buf, ChannelFutureListener listener) {
        this.bufAndListenerPairs.add(buf);
        if (listener != null) {
            this.bufAndListenerPairs.add(listener);
        }
        incrementReadableBytes(buf.readableBytes());
    }

    public final ByteBuf removeFirst(ChannelPromise aggregatePromise) {
        Object entry = this.bufAndListenerPairs.poll();
        if (entry == null) {
            return null;
        }
        ByteBuf result = (ByteBuf) entry;
        decrementReadableBytes(result.readableBytes());
        Object entry2 = this.bufAndListenerPairs.peek();
        if (entry2 instanceof ChannelFutureListener) {
            aggregatePromise.addListener((GenericFutureListener<? extends Future<? super Void>>) ((ChannelFutureListener) entry2));
            this.bufAndListenerPairs.poll();
        }
        return result;
    }

    public final ByteBuf remove(ByteBufAllocator alloc, int bytes, ChannelPromise aggregatePromise) {
        ObjectUtil.checkPositiveOrZero(bytes, "bytes");
        ObjectUtil.checkNotNull(aggregatePromise, "aggregatePromise");
        if (this.bufAndListenerPairs.isEmpty()) {
            return removeEmptyValue();
        }
        int bytes2 = Math.min(bytes, this.readableBytes);
        ByteBuf toReturn = null;
        ByteBuf entryBuffer = null;
        while (true) {
            try {
                Object entry = this.bufAndListenerPairs.poll();
                if (entry == null) {
                    break;
                } else if (entry instanceof ChannelFutureListener) {
                    aggregatePromise.addListener((GenericFutureListener<? extends Future<? super Void>>) ((ChannelFutureListener) entry));
                } else {
                    ByteBuf entryBuffer2 = (ByteBuf) entry;
                    if (entryBuffer2.readableBytes() > bytes2) {
                        this.bufAndListenerPairs.addFirst(entryBuffer2);
                        if (bytes2 > 0) {
                            ByteBuf entryBuffer3 = entryBuffer2.readRetainedSlice(bytes2);
                            toReturn = toReturn == null ? composeFirst(alloc, entryBuffer3) : compose(alloc, toReturn, entryBuffer3);
                            bytes2 = 0;
                        }
                    } else {
                        bytes2 -= entryBuffer2.readableBytes();
                        toReturn = toReturn == null ? composeFirst(alloc, entryBuffer2) : compose(alloc, toReturn, entryBuffer2);
                        entryBuffer = null;
                    }
                }
            } catch (Throwable cause) {
                ReferenceCountUtil.safeRelease(entryBuffer);
                ReferenceCountUtil.safeRelease(toReturn);
                aggregatePromise.setFailure(cause);
                PlatformDependent.throwException(cause);
            }
        }
        decrementReadableBytes(bytes2 - bytes2);
        return toReturn;
    }

    public final int readableBytes() {
        return this.readableBytes;
    }

    public final boolean isEmpty() {
        return this.bufAndListenerPairs.isEmpty();
    }

    public final void releaseAndFailAll(ChannelOutboundInvoker invoker, Throwable cause) {
        releaseAndCompleteAll(invoker.newFailedFuture(cause));
    }

    public final void copyTo(AbstractCoalescingBufferQueue dest) {
        dest.bufAndListenerPairs.addAll(this.bufAndListenerPairs);
        dest.incrementReadableBytes(this.readableBytes);
    }

    /* JADX WARN: Removed duplicated region for block: B:31:0x0051 A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:33:0x004f A[SYNTHETIC] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public final void writeAndRemoveAll(ChannelHandlerContext ctx) {
        decrementReadableBytes(this.readableBytes);
        Throwable pending = null;
        ByteBuf previousBuf = null;
        while (true) {
            Object entry = this.bufAndListenerPairs.poll();
            if (entry == null) {
                if (previousBuf == null) {
                    break;
                }
                ctx.write(previousBuf, ctx.voidPromise());
                break;
            }
            try {
                if (entry instanceof ByteBuf) {
                    if (previousBuf != null) {
                        ctx.write(previousBuf, ctx.voidPromise());
                    }
                    previousBuf = (ByteBuf) entry;
                } else if (entry instanceof ChannelPromise) {
                    ctx.write(previousBuf, (ChannelPromise) entry);
                    previousBuf = null;
                } else {
                    ctx.write(previousBuf).addListener((GenericFutureListener<? extends Future<? super Void>>) ((ChannelFutureListener) entry));
                    previousBuf = null;
                }
            } catch (Throwable t) {
                if (pending != null) {
                }
            }
            if (pending != null) {
                pending = t;
            } else {
                logger.info("Throwable being suppressed because Throwable {} is already pending", pending, t);
            }
        }
        if (pending != null) {
            throw new IllegalStateException(pending);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public final ByteBuf composeIntoComposite(ByteBufAllocator alloc, ByteBuf cumulation, ByteBuf next) {
        CompositeByteBuf composite = alloc.compositeBuffer(size() + 2);
        try {
            composite.addComponent(true, cumulation);
            composite.addComponent(true, next);
        } catch (Throwable cause) {
            composite.release();
            ReferenceCountUtil.safeRelease(next);
            PlatformDependent.throwException(cause);
        }
        return composite;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public final ByteBuf copyAndCompose(ByteBufAllocator alloc, ByteBuf cumulation, ByteBuf next) {
        ByteBuf newCumulation = alloc.ioBuffer(cumulation.readableBytes() + next.readableBytes());
        try {
            newCumulation.writeBytes(cumulation).writeBytes(next);
        } catch (Throwable cause) {
            newCumulation.release();
            ReferenceCountUtil.safeRelease(next);
            PlatformDependent.throwException(cause);
        }
        cumulation.release();
        next.release();
        return newCumulation;
    }

    protected ByteBuf composeFirst(ByteBufAllocator allocator, ByteBuf first) {
        return first;
    }

    protected final int size() {
        return this.bufAndListenerPairs.size();
    }

    private void releaseAndCompleteAll(ChannelFuture future) {
        decrementReadableBytes(this.readableBytes);
        Throwable pending = null;
        while (true) {
            Object entry = this.bufAndListenerPairs.poll();
            if (entry == null) {
                break;
            }
            try {
                if (entry instanceof ByteBuf) {
                    ReferenceCountUtil.safeRelease(entry);
                } else {
                    ((ChannelFutureListener) entry).operationComplete(future);
                }
            } catch (Throwable t) {
                if (pending == null) {
                    pending = t;
                } else {
                    logger.info("Throwable being suppressed because Throwable {} is already pending", pending, t);
                }
            }
        }
        if (pending != null) {
            throw new IllegalStateException(pending);
        }
    }

    private void incrementReadableBytes(int increment) {
        int i = this.readableBytes;
        int nextReadableBytes = i + increment;
        if (nextReadableBytes < i) {
            throw new IllegalStateException("buffer queue length overflow: " + this.readableBytes + " + " + increment);
        }
        this.readableBytes = nextReadableBytes;
        PendingBytesTracker pendingBytesTracker = this.tracker;
        if (pendingBytesTracker != null) {
            pendingBytesTracker.incrementPendingOutboundBytes(increment);
        }
    }

    private void decrementReadableBytes(int decrement) {
        this.readableBytes -= decrement;
        PendingBytesTracker pendingBytesTracker = this.tracker;
        if (pendingBytesTracker != null) {
            pendingBytesTracker.decrementPendingOutboundBytes(decrement);
        }
    }

    private static ChannelFutureListener toChannelFutureListener(ChannelPromise promise) {
        if (promise.isVoid()) {
            return null;
        }
        return new DelegatingChannelPromiseNotifier(promise);
    }
}
