package io.netty.channel.epoll;

import io.netty.channel.EventLoopGroup;
import io.netty.channel.EventLoopTaskQueueFactory;
import io.netty.channel.SelectStrategy;
import io.netty.channel.SingleThreadEventLoop;
import io.netty.channel.epoll.AbstractEpollChannel;
import io.netty.channel.unix.FileDescriptor;
import io.netty.channel.unix.IovArray;
import io.netty.util.IntSupplier;
import io.netty.util.collection.IntObjectHashMap;
import io.netty.util.collection.IntObjectMap;
import io.netty.util.concurrent.RejectedExecutionHandler;
import io.netty.util.internal.ObjectUtil;
import io.netty.util.internal.PlatformDependent;
import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.io.IOException;
import java.util.Queue;
import java.util.concurrent.Executor;
import java.util.concurrent.atomic.AtomicLong;
/* loaded from: classes.dex */
class EpollEventLoop extends SingleThreadEventLoop {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final long AWAKE = -1;
    private static final long MAX_SCHEDULED_TIMERFD_NS = 999999999;
    private static final long NONE = Long.MAX_VALUE;
    private static final InternalLogger logger = InternalLoggerFactory.getInstance(EpollEventLoop.class);
    private final boolean allowGrowing;
    private final IntObjectMap<AbstractEpollChannel> channels;
    private NativeDatagramPacketArray datagramPacketArray;
    private final FileDescriptor epollFd;
    private final FileDescriptor eventFd;
    private final EpollEventArray events;
    private volatile int ioRatio;
    private IovArray iovArray;
    private final AtomicLong nextWakeupNanos;
    private boolean pendingWakeup;
    private final IntSupplier selectNowSupplier;
    private final SelectStrategy selectStrategy;
    private final FileDescriptor timerFd;

    static {
        Epoll.ensureAvailability();
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public EpollEventLoop(EventLoopGroup parent, Executor executor, int maxEvents, SelectStrategy strategy, RejectedExecutionHandler rejectedExecutionHandler, EventLoopTaskQueueFactory queueFactory) {
        super(parent, executor, false, newTaskQueue(queueFactory), newTaskQueue(queueFactory), rejectedExecutionHandler);
        this.channels = new IntObjectHashMap(4096);
        this.selectNowSupplier = new IntSupplier() { // from class: io.netty.channel.epoll.EpollEventLoop.1
            @Override // io.netty.util.IntSupplier
            public int get() throws Exception {
                return EpollEventLoop.this.epollWaitNow();
            }
        };
        this.nextWakeupNanos = new AtomicLong(-1L);
        this.ioRatio = 50;
        this.selectStrategy = (SelectStrategy) ObjectUtil.checkNotNull(strategy, "strategy");
        if (maxEvents == 0) {
            this.allowGrowing = true;
            this.events = new EpollEventArray(4096);
        } else {
            this.allowGrowing = false;
            this.events = new EpollEventArray(maxEvents);
        }
        FileDescriptor epollFd = null;
        FileDescriptor eventFd = null;
        FileDescriptor timerFd = null;
        try {
            FileDescriptor newEpollCreate = Native.newEpollCreate();
            epollFd = newEpollCreate;
            this.epollFd = newEpollCreate;
            FileDescriptor newEventFd = Native.newEventFd();
            eventFd = newEventFd;
            this.eventFd = newEventFd;
            try {
                Native.epollCtlAdd(epollFd.intValue(), eventFd.intValue(), Native.EPOLLIN | Native.EPOLLET);
                FileDescriptor newTimerFd = Native.newTimerFd();
                timerFd = newTimerFd;
                this.timerFd = newTimerFd;
                try {
                    Native.epollCtlAdd(epollFd.intValue(), timerFd.intValue(), Native.EPOLLIN | Native.EPOLLET);
                    if (1 == 0) {
                        if (epollFd != null) {
                            try {
                                epollFd.close();
                            } catch (Exception e) {
                            }
                        }
                        if (eventFd != null) {
                            try {
                                eventFd.close();
                            } catch (Exception e2) {
                            }
                        }
                        if (timerFd != null) {
                            try {
                                timerFd.close();
                            } catch (Exception e3) {
                            }
                        }
                    }
                } catch (IOException e4) {
                    throw new IllegalStateException("Unable to add timerFd filedescriptor to epoll", e4);
                }
            } catch (IOException e5) {
                throw new IllegalStateException("Unable to add eventFd filedescriptor to epoll", e5);
            }
        } catch (Throwable e6) {
            if (0 == 0) {
                if (epollFd != null) {
                    try {
                        epollFd.close();
                    } catch (Exception e7) {
                    }
                }
                if (eventFd != null) {
                    try {
                        eventFd.close();
                    } catch (Exception e8) {
                    }
                }
                if (timerFd != null) {
                    try {
                        timerFd.close();
                    } catch (Exception e9) {
                    }
                }
            }
            throw e6;
        }
    }

    private static Queue<Runnable> newTaskQueue(EventLoopTaskQueueFactory queueFactory) {
        if (queueFactory == null) {
            return newTaskQueue0(DEFAULT_MAX_PENDING_TASKS);
        }
        return queueFactory.newTaskQueue(DEFAULT_MAX_PENDING_TASKS);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public IovArray cleanIovArray() {
        IovArray iovArray = this.iovArray;
        if (iovArray == null) {
            this.iovArray = new IovArray();
        } else {
            iovArray.clear();
        }
        return this.iovArray;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public NativeDatagramPacketArray cleanDatagramPacketArray() {
        NativeDatagramPacketArray nativeDatagramPacketArray = this.datagramPacketArray;
        if (nativeDatagramPacketArray == null) {
            this.datagramPacketArray = new NativeDatagramPacketArray();
        } else {
            nativeDatagramPacketArray.clear();
        }
        return this.datagramPacketArray;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // io.netty.util.concurrent.SingleThreadEventExecutor
    public void wakeup(boolean inEventLoop) {
        if (!inEventLoop && this.nextWakeupNanos.getAndSet(-1L) != -1) {
            Native.eventFdWrite(this.eventFd.intValue(), 1L);
        }
    }

    @Override // io.netty.util.concurrent.AbstractScheduledEventExecutor
    protected boolean beforeScheduledTaskSubmitted(long deadlineNanos) {
        return deadlineNanos < this.nextWakeupNanos.get();
    }

    @Override // io.netty.util.concurrent.AbstractScheduledEventExecutor
    protected boolean afterScheduledTaskSubmitted(long deadlineNanos) {
        return deadlineNanos < this.nextWakeupNanos.get();
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void add(AbstractEpollChannel ch) throws IOException {
        int fd = ch.socket.intValue();
        Native.epollCtlAdd(this.epollFd.intValue(), fd, ch.flags);
        this.channels.put(fd, (int) ch);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void modify(AbstractEpollChannel ch) throws IOException {
        Native.epollCtlMod(this.epollFd.intValue(), ch.socket.intValue(), ch.flags);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void remove(AbstractEpollChannel ch) throws IOException {
        int fd = ch.socket.intValue();
        AbstractEpollChannel old = this.channels.remove(fd);
        if (old != null && old != ch) {
            this.channels.put(fd, (int) old);
        } else if (ch.isOpen()) {
            Native.epollCtlDel(this.epollFd.intValue(), fd);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // io.netty.util.concurrent.SingleThreadEventExecutor
    public Queue<Runnable> newTaskQueue(int maxPendingTasks) {
        return newTaskQueue0(maxPendingTasks);
    }

    private static Queue<Runnable> newTaskQueue0(int maxPendingTasks) {
        return maxPendingTasks == Integer.MAX_VALUE ? PlatformDependent.newMpscQueue() : PlatformDependent.newMpscQueue(maxPendingTasks);
    }

    public int getIoRatio() {
        return this.ioRatio;
    }

    public void setIoRatio(int ioRatio) {
        if (ioRatio <= 0 || ioRatio > 100) {
            throw new IllegalArgumentException("ioRatio: " + ioRatio + " (expected: 0 < ioRatio <= 100)");
        }
        this.ioRatio = ioRatio;
    }

    @Override // io.netty.channel.SingleThreadEventLoop
    public int registeredChannels() {
        return this.channels.size();
    }

    private int epollWait(long deadlineNanos) throws IOException {
        if (deadlineNanos == Long.MAX_VALUE) {
            return Native.epollWait(this.epollFd, this.events, this.timerFd, Integer.MAX_VALUE, 0);
        }
        long totalDelay = deadlineToDelayNanos(deadlineNanos);
        int delaySeconds = (int) Math.min(totalDelay / 1000000000, 2147483647L);
        int delayNanos = (int) Math.min(totalDelay - (delaySeconds * 1000000000), (long) MAX_SCHEDULED_TIMERFD_NS);
        return Native.epollWait(this.epollFd, this.events, this.timerFd, delaySeconds, delayNanos);
    }

    private int epollWaitNoTimerChange() throws IOException {
        return Native.epollWait(this.epollFd, this.events, false);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public int epollWaitNow() throws IOException {
        return Native.epollWait(this.epollFd, this.events, true);
    }

    private int epollBusyWait() throws IOException {
        return Native.epollBusyWait(this.epollFd, this.events);
    }

    private int epollWaitTimeboxed() throws IOException {
        return Native.epollWait(this.epollFd, this.events, 1000);
    }

    /* JADX WARN: Can't wrap try/catch for region: R(13:2|3|(2:5|(4:7|8|9|10)(3:11|12|(10:51|(2:53|(1:55)(2:56|(1:58)))|59|(1:61)|62|63|64|(2:66|(1:68)(2:69|70))|71|(1:75))(1:14)))(2:76|77)|15|16|(2:(1:21)|22)(1:(4:45|46|(1:48)|49)(1:50))|23|(1:27)|28|29|31|(3:33|34|(2:36|37)(1:39))(1:40)|10) */
    /* JADX WARN: Code restructure failed: missing block: B:79:0x011d, code lost:
        r2 = move-exception;
     */
    /* JADX WARN: Code restructure failed: missing block: B:80:0x011e, code lost:
        handleLoopException(r2);
     */
    @Override // io.netty.util.concurrent.SingleThreadEventExecutor
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    protected void run() {
        int strategy;
        long prevDeadlineNanos = Long.MAX_VALUE;
        while (true) {
            try {
                strategy = this.selectStrategy.calculateStrategy(this.selectNowSupplier, hasTasks());
            } catch (Throwable t) {
                handleLoopException(t);
            }
            if (strategy == -3) {
                strategy = epollBusyWait();
            } else if (strategy != -2) {
                if (strategy == -1) {
                    if (this.pendingWakeup) {
                        strategy = epollWaitTimeboxed();
                        if (strategy == 0) {
                            logger.warn("Missed eventfd write (not seen after > 1 second)");
                            this.pendingWakeup = false;
                            if (hasTasks()) {
                            }
                        }
                    }
                    long curDeadlineNanos = nextScheduledTaskDeadlineNanos();
                    if (curDeadlineNanos == -1) {
                        curDeadlineNanos = Long.MAX_VALUE;
                    }
                    this.nextWakeupNanos.set(curDeadlineNanos);
                    if (!hasTasks()) {
                        if (curDeadlineNanos == prevDeadlineNanos) {
                            strategy = epollWaitNoTimerChange();
                        } else {
                            prevDeadlineNanos = curDeadlineNanos;
                            strategy = epollWait(curDeadlineNanos);
                        }
                    }
                    if (this.nextWakeupNanos.get() == -1 || this.nextWakeupNanos.getAndSet(-1L) == -1) {
                        this.pendingWakeup = true;
                    }
                }
            }
            int ioRatio = this.ioRatio;
            if (ioRatio == 100) {
                if (strategy > 0 && processReady(this.events, strategy)) {
                    prevDeadlineNanos = Long.MAX_VALUE;
                }
                runAllTasks();
            } else if (strategy > 0) {
                long ioStartTime = System.nanoTime();
                if (processReady(this.events, strategy)) {
                    prevDeadlineNanos = Long.MAX_VALUE;
                }
                long ioTime = System.nanoTime() - ioStartTime;
                runAllTasks(((100 - ioRatio) * ioTime) / ioRatio);
            } else {
                runAllTasks(0L);
            }
            if (this.allowGrowing && strategy == this.events.length()) {
                this.events.increase();
            }
            if (isShuttingDown()) {
                closeAll();
                if (confirmShutdown()) {
                    return;
                }
            } else {
                continue;
            }
        }
    }

    void handleLoopException(Throwable t) {
        logger.warn("Unexpected exception in the selector loop.", t);
        try {
            Thread.sleep(1000L);
        } catch (InterruptedException e) {
        }
    }

    private void closeAll() {
        AbstractEpollChannel[] localChannels = (AbstractEpollChannel[]) this.channels.values().toArray(new AbstractEpollChannel[0]);
        for (AbstractEpollChannel ch : localChannels) {
            ch.unsafe().close(ch.unsafe().voidPromise());
        }
    }

    private boolean processReady(EpollEventArray events, int ready) {
        boolean timerFired = false;
        for (int i = 0; i < ready; i++) {
            int fd = events.fd(i);
            if (fd == this.eventFd.intValue()) {
                this.pendingWakeup = false;
            } else if (fd == this.timerFd.intValue()) {
                timerFired = true;
            } else {
                long ev = events.events(i);
                AbstractEpollChannel ch = this.channels.get(fd);
                if (ch != null) {
                    AbstractEpollChannel.AbstractEpollUnsafe unsafe = (AbstractEpollChannel.AbstractEpollUnsafe) ch.unsafe();
                    if (((Native.EPOLLERR | Native.EPOLLOUT) & ev) != 0) {
                        unsafe.epollOutReady();
                    }
                    if (((Native.EPOLLERR | Native.EPOLLIN) & ev) != 0) {
                        unsafe.epollInReady();
                    }
                    if ((Native.EPOLLRDHUP & ev) != 0) {
                        unsafe.epollRdHupReady();
                    }
                } else {
                    try {
                        Native.epollCtlDel(this.epollFd.intValue(), fd);
                    } catch (IOException e) {
                    }
                }
            }
        }
        return timerFired;
    }

    /* JADX WARN: Type inference failed for: r0v0, types: [io.netty.channel.epoll.NativeDatagramPacketArray, io.netty.channel.unix.IovArray] */
    @Override // io.netty.util.concurrent.SingleThreadEventExecutor
    protected void cleanup() {
        int count;
        while (true) {
            try {
                if (this.pendingWakeup) {
                    try {
                        count = epollWaitTimeboxed();
                    } catch (IOException e) {
                    }
                    if (count == 0) {
                        break;
                    }
                    int i = 0;
                    while (true) {
                        if (i >= count) {
                            break;
                        } else if (this.events.fd(i) != this.eventFd.intValue()) {
                            i++;
                        } else {
                            this.pendingWakeup = false;
                            break;
                        }
                    }
                }
            } finally {
                IovArray iovArray = this.iovArray;
                if (iovArray != null) {
                    iovArray.release();
                    this.iovArray = null;
                }
                NativeDatagramPacketArray nativeDatagramPacketArray = this.datagramPacketArray;
                if (nativeDatagramPacketArray != null) {
                    nativeDatagramPacketArray.release();
                    this.datagramPacketArray = null;
                }
                this.events.free();
            }
        }
        try {
            this.eventFd.close();
        } catch (IOException e2) {
            logger.warn("Failed to close the event fd.", (Throwable) e2);
        }
        try {
            this.timerFd.close();
        } catch (IOException e3) {
            logger.warn("Failed to close the timer fd.", (Throwable) e3);
        }
        try {
            this.epollFd.close();
        } catch (IOException e4) {
            logger.warn("Failed to close the epoll fd.", (Throwable) e4);
        }
    }
}
