package io.netty.channel.kqueue;

import io.netty.channel.EventLoopGroup;
import io.netty.channel.EventLoopTaskQueueFactory;
import io.netty.channel.SelectStrategy;
import io.netty.channel.SingleThreadEventLoop;
import io.netty.channel.kqueue.AbstractKQueueChannel;
import io.netty.channel.unix.FileDescriptor;
import io.netty.channel.unix.IovArray;
import io.netty.util.IntSupplier;
import io.netty.util.collection.IntObjectHashMap;
import io.netty.util.collection.IntObjectMap;
import io.netty.util.concurrent.RejectedExecutionHandler;
import io.netty.util.internal.ObjectUtil;
import io.netty.util.internal.PlatformDependent;
import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.io.IOException;
import java.util.Queue;
import java.util.concurrent.Executor;
import java.util.concurrent.atomic.AtomicIntegerFieldUpdater;
/* JADX INFO: Access modifiers changed from: package-private */
/* loaded from: classes.dex */
public final class KQueueEventLoop extends SingleThreadEventLoop {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final int KQUEUE_WAKE_UP_IDENT = 0;
    private final boolean allowGrowing;
    private final KQueueEventArray changeList;
    private final IntObjectMap<AbstractKQueueChannel> channels;
    private final KQueueEventArray eventList;
    private volatile int ioRatio;
    private final IovArray iovArray;
    private final FileDescriptor kqueueFd;
    private final IntSupplier selectNowSupplier;
    private final SelectStrategy selectStrategy;
    private volatile int wakenUp;
    private static final InternalLogger logger = InternalLoggerFactory.getInstance(KQueueEventLoop.class);
    private static final AtomicIntegerFieldUpdater<KQueueEventLoop> WAKEN_UP_UPDATER = AtomicIntegerFieldUpdater.newUpdater(KQueueEventLoop.class, "wakenUp");

    static {
        KQueue.ensureAvailability();
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public KQueueEventLoop(EventLoopGroup parent, Executor executor, int maxEvents, SelectStrategy strategy, RejectedExecutionHandler rejectedExecutionHandler, EventLoopTaskQueueFactory queueFactory) {
        super(parent, executor, false, newTaskQueue(queueFactory), newTaskQueue(queueFactory), rejectedExecutionHandler);
        this.iovArray = new IovArray();
        this.selectNowSupplier = new IntSupplier() { // from class: io.netty.channel.kqueue.KQueueEventLoop.1
            @Override // io.netty.util.IntSupplier
            public int get() throws Exception {
                return KQueueEventLoop.this.kqueueWaitNow();
            }
        };
        this.channels = new IntObjectHashMap(4096);
        this.ioRatio = 50;
        this.selectStrategy = (SelectStrategy) ObjectUtil.checkNotNull(strategy, "strategy");
        this.kqueueFd = Native.newKQueue();
        if (maxEvents == 0) {
            this.allowGrowing = true;
            maxEvents = 4096;
        } else {
            this.allowGrowing = false;
        }
        this.changeList = new KQueueEventArray(maxEvents);
        this.eventList = new KQueueEventArray(maxEvents);
        int result = Native.keventAddUserEvent(this.kqueueFd.intValue(), 0);
        if (result < 0) {
            cleanup();
            throw new IllegalStateException("kevent failed to add user event with errno: " + (-result));
        }
    }

    private static Queue<Runnable> newTaskQueue(EventLoopTaskQueueFactory queueFactory) {
        if (queueFactory == null) {
            return newTaskQueue0(DEFAULT_MAX_PENDING_TASKS);
        }
        return queueFactory.newTaskQueue(DEFAULT_MAX_PENDING_TASKS);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void add(AbstractKQueueChannel ch) {
        this.channels.put(ch.fd().intValue(), (int) ch);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void evSet(AbstractKQueueChannel ch, short filter, short flags, int fflags) {
        this.changeList.evSet(ch, filter, flags, fflags);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void remove(AbstractKQueueChannel ch) throws Exception {
        int fd = ch.fd().intValue();
        AbstractKQueueChannel old = this.channels.remove(fd);
        if (old != null && old != ch) {
            this.channels.put(fd, (int) old);
        } else if (ch.isOpen()) {
            ch.unregisterFilters();
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public IovArray cleanArray() {
        this.iovArray.clear();
        return this.iovArray;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // io.netty.util.concurrent.SingleThreadEventExecutor
    public void wakeup(boolean inEventLoop) {
        if (!inEventLoop && WAKEN_UP_UPDATER.compareAndSet(this, 0, 1)) {
            wakeup();
        }
    }

    private void wakeup() {
        Native.keventTriggerUserEvent(this.kqueueFd.intValue(), 0);
    }

    private int kqueueWait(boolean oldWakeup) throws IOException {
        if (oldWakeup && hasTasks()) {
            return kqueueWaitNow();
        }
        long totalDelay = delayNanos(System.nanoTime());
        int delaySeconds = (int) Math.min(totalDelay / 1000000000, 2147483647L);
        return kqueueWait(delaySeconds, (int) Math.min(totalDelay - (delaySeconds * 1000000000), 2147483647L));
    }

    /* JADX INFO: Access modifiers changed from: private */
    public int kqueueWaitNow() throws IOException {
        return kqueueWait(0, 0);
    }

    private int kqueueWait(int timeoutSec, int timeoutNs) throws IOException {
        int numEvents = Native.keventWait(this.kqueueFd.intValue(), this.changeList, this.eventList, timeoutSec, timeoutNs);
        this.changeList.clear();
        return numEvents;
    }

    private void processReady(int ready) {
        for (int i = 0; i < ready; i++) {
            short filter = this.eventList.filter(i);
            short flags = this.eventList.flags(i);
            int fd = this.eventList.fd(i);
            if (filter != Native.EVFILT_USER && (Native.EV_ERROR & flags) == 0) {
                AbstractKQueueChannel channel = this.channels.get(fd);
                if (channel == null) {
                    logger.warn("events[{}]=[{}, {}] had no channel!", Integer.valueOf(i), Integer.valueOf(this.eventList.fd(i)), Short.valueOf(filter));
                } else {
                    AbstractKQueueChannel.AbstractKQueueUnsafe unsafe = (AbstractKQueueChannel.AbstractKQueueUnsafe) channel.unsafe();
                    if (filter == Native.EVFILT_WRITE) {
                        unsafe.writeReady();
                    } else if (filter == Native.EVFILT_READ) {
                        unsafe.readReady(this.eventList.data(i));
                    } else if (filter == Native.EVFILT_SOCK && (this.eventList.fflags(i) & Native.NOTE_RDHUP) != 0) {
                        unsafe.readEOF();
                    }
                    if ((Native.EV_EOF & flags) != 0) {
                        unsafe.readEOF();
                    }
                }
            }
        }
    }

    /* JADX WARN: Can't wrap try/catch for region: R(17:1|2|(1:52)(2:4|(4:6|7|8|9)(3:10|11|(11:13|14|15|(2:(1:18)|19)(3:41|(1:43)|44)|20|(1:24)|25|26|28|(3:30|31|(2:33|34)(1:36))(1:37)|9)))|45|(1:47)(1:51)|48|(1:50)|14|15|(0)(0)|20|(2:22|24)|25|26|28|(0)(0)|9) */
    /* JADX WARN: Code restructure failed: missing block: B:48:0x0096, code lost:
        r0 = move-exception;
     */
    /* JADX WARN: Code restructure failed: missing block: B:49:0x0097, code lost:
        handleLoopException(r0);
     */
    /* JADX WARN: Removed duplicated region for block: B:20:0x0036  */
    /* JADX WARN: Removed duplicated region for block: B:27:0x0045 A[Catch: all -> 0x0081, TRY_LEAVE, TryCatch #4 {all -> 0x0081, blocks: (B:2:0x0000, B:17:0x0030, B:26:0x0041, B:35:0x006f, B:37:0x0073, B:39:0x007b, B:27:0x0045, B:34:0x0060, B:10:0x0018, B:14:0x0024, B:16:0x002d, B:21:0x0038, B:29:0x004b), top: B:51:0x0000 }] */
    /* JADX WARN: Removed duplicated region for block: B:55:0x008b A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:63:0x0000 A[SYNTHETIC] */
    @Override // io.netty.util.concurrent.SingleThreadEventExecutor
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    protected void run() {
        int strategy;
        int ioRatio;
        while (true) {
            try {
                strategy = this.selectStrategy.calculateStrategy(this.selectNowSupplier, hasTasks());
            } catch (Throwable t) {
                handleLoopException(t);
            }
            if (strategy != -3) {
                if (strategy != -2) {
                    if (strategy != -1) {
                        ioRatio = this.ioRatio;
                        if (ioRatio != 100) {
                            if (strategy > 0) {
                                processReady(strategy);
                            }
                            runAllTasks();
                        } else {
                            long ioStartTime = System.nanoTime();
                            if (strategy > 0) {
                                processReady(strategy);
                            }
                            long ioTime = System.nanoTime() - ioStartTime;
                            runAllTasks(((100 - ioRatio) * ioTime) / ioRatio);
                        }
                        if (this.allowGrowing && strategy == this.eventList.capacity()) {
                            this.eventList.realloc(false);
                        }
                        if (isShuttingDown()) {
                            continue;
                        } else {
                            closeAll();
                            if (confirmShutdown()) {
                                return;
                            }
                        }
                    }
                }
            }
            strategy = kqueueWait(WAKEN_UP_UPDATER.getAndSet(this, 0) == 1);
            if (this.wakenUp == 1) {
                wakeup();
            }
            ioRatio = this.ioRatio;
            if (ioRatio != 100) {
            }
            if (this.allowGrowing) {
                this.eventList.realloc(false);
            }
            if (isShuttingDown()) {
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // io.netty.util.concurrent.SingleThreadEventExecutor
    public Queue<Runnable> newTaskQueue(int maxPendingTasks) {
        return newTaskQueue0(maxPendingTasks);
    }

    private static Queue<Runnable> newTaskQueue0(int maxPendingTasks) {
        return maxPendingTasks == Integer.MAX_VALUE ? PlatformDependent.newMpscQueue() : PlatformDependent.newMpscQueue(maxPendingTasks);
    }

    public int getIoRatio() {
        return this.ioRatio;
    }

    public void setIoRatio(int ioRatio) {
        if (ioRatio <= 0 || ioRatio > 100) {
            throw new IllegalArgumentException("ioRatio: " + ioRatio + " (expected: 0 < ioRatio <= 100)");
        }
        this.ioRatio = ioRatio;
    }

    @Override // io.netty.channel.SingleThreadEventLoop
    public int registeredChannels() {
        return this.channels.size();
    }

    @Override // io.netty.util.concurrent.SingleThreadEventExecutor
    protected void cleanup() {
        try {
            try {
                this.kqueueFd.close();
            } catch (IOException e) {
                logger.warn("Failed to close the kqueue fd.", (Throwable) e);
            }
        } finally {
            this.changeList.free();
            this.eventList.free();
        }
    }

    private void closeAll() {
        try {
            kqueueWaitNow();
        } catch (IOException e) {
        }
        AbstractKQueueChannel[] localChannels = (AbstractKQueueChannel[]) this.channels.values().toArray(new AbstractKQueueChannel[0]);
        for (AbstractKQueueChannel ch : localChannels) {
            ch.unsafe().close(ch.unsafe().voidPromise());
        }
    }

    private static void handleLoopException(Throwable t) {
        logger.warn("Unexpected exception in the selector loop.", t);
        try {
            Thread.sleep(1000L);
        } catch (InterruptedException e) {
        }
    }
}
