package io.netty.handler.codec.compression;

import io.netty.buffer.ByteBuf;
import io.netty.channel.ChannelHandlerContext;
import io.netty.handler.codec.MessageToByteEncoder;
import java.util.zip.Adler32;
import java.util.zip.Checksum;
/* loaded from: classes.dex */
public class FastLzFrameEncoder extends MessageToByteEncoder<ByteBuf> {
    private final Checksum checksum;
    private final int level;

    public FastLzFrameEncoder() {
        this(0, null);
    }

    public FastLzFrameEncoder(int level) {
        this(level, null);
    }

    public FastLzFrameEncoder(boolean validateChecksums) {
        this(0, validateChecksums ? new Adler32() : null);
    }

    public FastLzFrameEncoder(int level, Checksum checksum) {
        super(false);
        if (level != 0 && level != 1 && level != 2) {
            throw new IllegalArgumentException(String.format("level: %d (expected: %d or %d or %d)", Integer.valueOf(level), 0, 1, 2));
        }
        this.level = level;
        this.checksum = checksum;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // io.netty.handler.codec.MessageToByteEncoder
    public void encode(ChannelHandlerContext ctx, ByteBuf in, ByteBuf out) throws Exception {
        byte[] input;
        int inputPtr;
        int compressedLength;
        int chunkLength;
        int inputPtr2;
        int outputOffset;
        byte[] input2;
        int inputPtr3;
        Checksum checksum = this.checksum;
        while (in.isReadable()) {
            int idx = in.readerIndex();
            int length = Math.min(in.readableBytes(), 65535);
            int outputIdx = out.writerIndex();
            out.setMedium(outputIdx, 4607066);
            int outputOffset2 = outputIdx + 4 + (checksum != null ? 4 : 0);
            if (length < 32) {
                compressedLength = 0;
                out.ensureWritable(outputOffset2 + 2 + length);
                byte[] output = out.array();
                int outputPtr = out.arrayOffset() + outputOffset2 + 2;
                if (checksum != null) {
                    if (in.hasArray()) {
                        input2 = in.array();
                        inputPtr3 = in.arrayOffset() + idx;
                    } else {
                        input2 = new byte[length];
                        in.getBytes(idx, input2);
                        inputPtr3 = 0;
                    }
                    checksum.reset();
                    checksum.update(input2, inputPtr3, length);
                    outputOffset = outputOffset2;
                    out.setInt(outputIdx + 4, (int) checksum.getValue());
                    System.arraycopy(input2, inputPtr3, output, outputPtr, length);
                } else {
                    outputOffset = outputOffset2;
                    in.getBytes(idx, output, outputPtr, length);
                }
                chunkLength = length;
                inputPtr2 = outputOffset;
            } else {
                if (in.hasArray()) {
                    input = in.array();
                    inputPtr = in.arrayOffset() + idx;
                } else {
                    byte[] input3 = new byte[length];
                    in.getBytes(idx, input3);
                    input = input3;
                    inputPtr = 0;
                }
                if (checksum != null) {
                    checksum.reset();
                    checksum.update(input, inputPtr, length);
                    out.setInt(outputIdx + 4, (int) checksum.getValue());
                }
                int maxOutputLength = FastLz.calculateOutputBufferLength(length);
                out.ensureWritable(outputOffset2 + 4 + maxOutputLength);
                byte[] output2 = out.array();
                int outputPtr2 = out.arrayOffset() + outputOffset2 + 4;
                int compressedLength2 = FastLz.compress(input, inputPtr, length, output2, outputPtr2, this.level);
                if (compressedLength2 < length) {
                    out.setShort(outputOffset2, compressedLength2);
                    compressedLength = 1;
                    chunkLength = compressedLength2;
                    inputPtr2 = outputOffset2 + 2;
                } else {
                    System.arraycopy(input, inputPtr, output2, outputPtr2 - 2, length);
                    compressedLength = 0;
                    chunkLength = length;
                    inputPtr2 = outputOffset2;
                }
            }
            out.setShort(inputPtr2, length);
            out.setByte(outputIdx + 3, compressedLength | (checksum != null ? 16 : 0));
            out.writerIndex(inputPtr2 + 2 + chunkLength);
            in.skipBytes(length);
        }
    }
}
