package io.netty.handler.codec.compression;

import io.netty.buffer.ByteBuf;
import io.netty.channel.ChannelHandlerContext;
import io.netty.handler.codec.ByteToMessageDecoder;
import java.util.List;
/* loaded from: classes.dex */
public class SnappyFrameDecoder extends ByteToMessageDecoder {
    private static final int MAX_UNCOMPRESSED_DATA_SIZE = 65540;
    private static final int SNAPPY_IDENTIFIER_LEN = 6;
    private boolean corrupted;
    private final Snappy snappy;
    private boolean started;
    private final boolean validateChecksums;

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public enum ChunkType {
        STREAM_IDENTIFIER,
        COMPRESSED_DATA,
        UNCOMPRESSED_DATA,
        RESERVED_UNSKIPPABLE,
        RESERVED_SKIPPABLE
    }

    public SnappyFrameDecoder() {
        this(false);
    }

    public SnappyFrameDecoder(boolean validateChecksums) {
        this.snappy = new Snappy();
        this.validateChecksums = validateChecksums;
    }

    @Override // io.netty.handler.codec.ByteToMessageDecoder
    protected void decode(ChannelHandlerContext ctx, ByteBuf in, List<Object> out) throws Exception {
        if (this.corrupted) {
            in.skipBytes(in.readableBytes());
            return;
        }
        try {
            int idx = in.readerIndex();
            int inSize = in.readableBytes();
            if (inSize < 4) {
                return;
            }
            int chunkTypeVal = in.getUnsignedByte(idx);
            ChunkType chunkType = mapChunkType((byte) chunkTypeVal);
            int chunkLength = in.getUnsignedMediumLE(idx + 1);
            int i = AnonymousClass1.$SwitchMap$io$netty$handler$codec$compression$SnappyFrameDecoder$ChunkType[chunkType.ordinal()];
            if (i == 1) {
                if (chunkLength != 6) {
                    throw new DecompressionException("Unexpected length of stream identifier: " + chunkLength);
                } else if (inSize >= 10) {
                    in.skipBytes(4);
                    int offset = in.readerIndex();
                    in.skipBytes(6);
                    int offset2 = offset + 1;
                    checkByte(in.getByte(offset), (byte) 115);
                    int offset3 = offset2 + 1;
                    checkByte(in.getByte(offset2), (byte) 78);
                    int offset4 = offset3 + 1;
                    checkByte(in.getByte(offset3), (byte) 97);
                    int offset5 = offset4 + 1;
                    checkByte(in.getByte(offset4), (byte) 80);
                    checkByte(in.getByte(offset5), (byte) 112);
                    checkByte(in.getByte(offset5 + 1), (byte) 89);
                    this.started = true;
                }
            } else if (i == 2) {
                if (!this.started) {
                    throw new DecompressionException("Received RESERVED_SKIPPABLE tag before STREAM_IDENTIFIER");
                }
                if (inSize < chunkLength + 4) {
                    return;
                }
                in.skipBytes(chunkLength + 4);
            } else if (i != 3) {
                if (i == 4) {
                    if (!this.started) {
                        throw new DecompressionException("Received UNCOMPRESSED_DATA tag before STREAM_IDENTIFIER");
                    }
                    if (chunkLength > 65540) {
                        throw new DecompressionException("Received UNCOMPRESSED_DATA larger than 65540 bytes");
                    }
                    if (inSize < chunkLength + 4) {
                        return;
                    }
                    in.skipBytes(4);
                    if (this.validateChecksums) {
                        int checksum = in.readIntLE();
                        Snappy.validateChecksum(checksum, in, in.readerIndex(), chunkLength - 4);
                    } else {
                        in.skipBytes(4);
                    }
                    out.add(in.readRetainedSlice(chunkLength - 4));
                } else if (i == 5) {
                    if (!this.started) {
                        throw new DecompressionException("Received COMPRESSED_DATA tag before STREAM_IDENTIFIER");
                    }
                    if (inSize < chunkLength + 4) {
                        return;
                    }
                    in.skipBytes(4);
                    int checksum2 = in.readIntLE();
                    ByteBuf uncompressed = ctx.alloc().buffer();
                    if (this.validateChecksums) {
                        int oldWriterIndex = in.writerIndex();
                        try {
                            in.writerIndex((in.readerIndex() + chunkLength) - 4);
                            this.snappy.decode(in, uncompressed);
                            in.writerIndex(oldWriterIndex);
                            Snappy.validateChecksum(checksum2, uncompressed, 0, uncompressed.writerIndex());
                        } catch (Throwable th) {
                            in.writerIndex(oldWriterIndex);
                            throw th;
                        }
                    } else {
                        this.snappy.decode(in.readSlice(chunkLength - 4), uncompressed);
                    }
                    out.add(uncompressed);
                    ByteBuf uncompressed2 = null;
                    if (0 != 0) {
                        uncompressed2.release();
                    }
                    this.snappy.reset();
                }
            } else {
                throw new DecompressionException("Found reserved unskippable chunk type: 0x" + Integer.toHexString(chunkTypeVal));
            }
        } catch (Exception e) {
            this.corrupted = true;
            throw e;
        }
    }

    /* renamed from: io.netty.handler.codec.compression.SnappyFrameDecoder$1  reason: invalid class name */
    /* loaded from: classes.dex */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$io$netty$handler$codec$compression$SnappyFrameDecoder$ChunkType;

        static {
            int[] iArr = new int[ChunkType.values().length];
            $SwitchMap$io$netty$handler$codec$compression$SnappyFrameDecoder$ChunkType = iArr;
            try {
                iArr[ChunkType.STREAM_IDENTIFIER.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$SnappyFrameDecoder$ChunkType[ChunkType.RESERVED_SKIPPABLE.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$SnappyFrameDecoder$ChunkType[ChunkType.RESERVED_UNSKIPPABLE.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$SnappyFrameDecoder$ChunkType[ChunkType.UNCOMPRESSED_DATA.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$SnappyFrameDecoder$ChunkType[ChunkType.COMPRESSED_DATA.ordinal()] = 5;
            } catch (NoSuchFieldError e5) {
            }
        }
    }

    private static void checkByte(byte actual, byte expect) {
        if (actual != expect) {
            throw new DecompressionException("Unexpected stream identifier contents. Mismatched snappy protocol version?");
        }
    }

    private static ChunkType mapChunkType(byte type) {
        if (type == 0) {
            return ChunkType.COMPRESSED_DATA;
        }
        if (type == 1) {
            return ChunkType.UNCOMPRESSED_DATA;
        }
        if (type == -1) {
            return ChunkType.STREAM_IDENTIFIER;
        }
        if ((type & 128) == 128) {
            return ChunkType.RESERVED_SKIPPABLE;
        }
        return ChunkType.RESERVED_UNSKIPPABLE;
    }
}
