package io.netty.handler.codec.http.websocketx;

import io.netty.buffer.ByteBuf;
import io.netty.channel.ChannelHandlerContext;
import io.netty.handler.codec.MessageToMessageEncoder;
import io.netty.handler.codec.TooLongFrameException;
import io.netty.handler.codec.dns.DnsRecord;
import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.util.List;
import kotlin.UByte;
/* loaded from: classes.dex */
public class WebSocket08FrameEncoder extends MessageToMessageEncoder<WebSocketFrame> implements WebSocketFrameEncoder {
    private static final int GATHERING_WRITE_THRESHOLD = 1024;
    private static final byte OPCODE_BINARY = 2;
    private static final byte OPCODE_CLOSE = 8;
    private static final byte OPCODE_CONT = 0;
    private static final byte OPCODE_PING = 9;
    private static final byte OPCODE_PONG = 10;
    private static final byte OPCODE_TEXT = 1;
    private static final InternalLogger logger = InternalLoggerFactory.getInstance(WebSocket08FrameEncoder.class);
    private final boolean maskPayload;

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // io.netty.handler.codec.MessageToMessageEncoder
    public /* bridge */ /* synthetic */ void encode(ChannelHandlerContext channelHandlerContext, WebSocketFrame webSocketFrame, List list) throws Exception {
        encode2(channelHandlerContext, webSocketFrame, (List<Object>) list);
    }

    public WebSocket08FrameEncoder(boolean maskPayload) {
        this.maskPayload = maskPayload;
    }

    /* renamed from: encode  reason: avoid collision after fix types in other method */
    protected void encode2(ChannelHandlerContext ctx, WebSocketFrame msg, List<Object> out) throws Exception {
        byte opcode;
        ByteBuf buf;
        int end;
        int i;
        ByteBuf data = msg.content();
        if (msg instanceof TextWebSocketFrame) {
            opcode = 1;
        } else if (msg instanceof PingWebSocketFrame) {
            opcode = 9;
        } else if (msg instanceof PongWebSocketFrame) {
            opcode = 10;
        } else if (msg instanceof CloseWebSocketFrame) {
            opcode = 8;
        } else if (msg instanceof BinaryWebSocketFrame) {
            opcode = 2;
        } else if (msg instanceof ContinuationWebSocketFrame) {
            opcode = 0;
        } else {
            throw new UnsupportedOperationException("Cannot encode frame of type: " + msg.getClass().getName());
        }
        int length = data.readableBytes();
        if (logger.isTraceEnabled()) {
            logger.trace("Encoding WebSocket Frame opCode={} length={}", Byte.valueOf(opcode), Integer.valueOf(length));
        }
        int b0 = 0;
        if (msg.isFinalFragment()) {
            b0 = 0 | 128;
        }
        int b02 = (opcode % 128) | b0 | ((msg.rsv() % 8) << 4);
        if (opcode == 9 && length > 125) {
            throw new TooLongFrameException("invalid payload for PING (payload length must be <= 125, was " + length);
        }
        boolean release = true;
        ByteBuf buf2 = null;
        try {
            int maskLength = this.maskPayload ? 4 : 0;
            if (length <= 125) {
                int size = maskLength + 2;
                if (this.maskPayload || length <= 1024) {
                    size += length;
                }
                buf = ctx.alloc().buffer(size);
                buf.writeByte(b02);
                byte b = (byte) (this.maskPayload ? ((byte) length) | 128 : (byte) length);
                buf.writeByte(b);
            } else if (length <= 65535) {
                int size2 = maskLength + 4;
                if (this.maskPayload || length <= 1024) {
                    size2 += length;
                }
                buf = ctx.alloc().buffer(size2);
                buf.writeByte(b02);
                buf.writeByte(this.maskPayload ? DnsRecord.CLASS_NONE : 126);
                buf.writeByte((length >>> 8) & 255);
                buf.writeByte(length & 255);
            } else {
                int size3 = maskLength + 10;
                if (this.maskPayload || length <= 1024) {
                    size3 += length;
                }
                buf = ctx.alloc().buffer(size3);
                buf.writeByte(b02);
                buf.writeByte(this.maskPayload ? 255 : 127);
                buf.writeLong(length);
            }
            if (this.maskPayload) {
                int random = (int) (Math.random() * 2.147483647E9d);
                byte[] mask = ByteBuffer.allocate(4).putInt(random).array();
                buf2.writeBytes(mask);
                ByteOrder srcOrder = data.order();
                ByteOrder dstOrder = buf2.order();
                int counter = 0;
                int i2 = data.readerIndex();
                int end2 = data.writerIndex();
                if (srcOrder == dstOrder) {
                    int intMask = (255 & mask[3]) | ((mask[0] & UByte.MAX_VALUE) << 24) | ((mask[1] & UByte.MAX_VALUE) << 16) | ((mask[2] & UByte.MAX_VALUE) << 8);
                    if (srcOrder != ByteOrder.LITTLE_ENDIAN) {
                        i = i2;
                    } else {
                        intMask = Integer.reverseBytes(intMask);
                        i = i2;
                    }
                    while (true) {
                        end = end2;
                        if (i + 3 >= end) {
                            break;
                        }
                        int intData = data.getInt(i);
                        buf2.writeInt(intData ^ intMask);
                        i += 4;
                        end2 = end;
                    }
                } else {
                    end = end2;
                    i = i2;
                }
                while (i < end) {
                    byte byteData = data.getByte(i);
                    buf2.writeByte(mask[counter % 4] ^ byteData);
                    i++;
                    counter++;
                }
                out.add(buf2);
            } else {
                if (buf2.writableBytes() >= data.readableBytes()) {
                    buf2.writeBytes(data);
                    out.add(buf2);
                } else {
                    out.add(buf2);
                    out.add(data.retain());
                }
            }
            release = false;
        } finally {
            if (release && buf2 != null) {
                buf2.release();
            }
        }
    }
}
