package io.netty.handler.codec.http.websocketx;

import io.netty.channel.ChannelFuture;
import io.netty.channel.ChannelFutureListener;
import io.netty.channel.ChannelHandlerContext;
import io.netty.channel.ChannelOutboundHandlerAdapter;
import io.netty.channel.ChannelPromise;
import io.netty.util.ReferenceCountUtil;
import io.netty.util.concurrent.Future;
import io.netty.util.concurrent.GenericFutureListener;
import io.netty.util.concurrent.ScheduledFuture;
import io.netty.util.internal.ObjectUtil;
import java.nio.channels.ClosedChannelException;
import java.util.concurrent.TimeUnit;
/* loaded from: classes.dex */
final class WebSocketCloseFrameHandler extends ChannelOutboundHandlerAdapter {
    private ChannelPromise closeSent;
    private final WebSocketCloseStatus closeStatus;
    private final long forceCloseTimeoutMillis;

    /* JADX INFO: Access modifiers changed from: package-private */
    public WebSocketCloseFrameHandler(WebSocketCloseStatus closeStatus, long forceCloseTimeoutMillis) {
        this.closeStatus = (WebSocketCloseStatus) ObjectUtil.checkNotNull(closeStatus, "closeStatus");
        this.forceCloseTimeoutMillis = forceCloseTimeoutMillis;
    }

    @Override // io.netty.channel.ChannelOutboundHandlerAdapter, io.netty.channel.ChannelOutboundHandler
    public void close(final ChannelHandlerContext ctx, final ChannelPromise promise) throws Exception {
        if (!ctx.channel().isActive()) {
            ctx.close(promise);
            return;
        }
        if (this.closeSent == null) {
            write(ctx, new CloseWebSocketFrame(this.closeStatus), ctx.newPromise());
        }
        flush(ctx);
        applyCloseSentTimeout(ctx);
        this.closeSent.addListener((GenericFutureListener<? extends Future<? super Void>>) new ChannelFutureListener() { // from class: io.netty.handler.codec.http.websocketx.WebSocketCloseFrameHandler.1
            @Override // io.netty.util.concurrent.GenericFutureListener
            public void operationComplete(ChannelFuture future) {
                ctx.close(promise);
            }
        });
    }

    @Override // io.netty.channel.ChannelOutboundHandlerAdapter, io.netty.channel.ChannelOutboundHandler
    public void write(ChannelHandlerContext ctx, Object msg, ChannelPromise promise) throws Exception {
        if (this.closeSent != null) {
            ReferenceCountUtil.release(msg);
            promise.setFailure((Throwable) new ClosedChannelException());
            return;
        }
        if (msg instanceof CloseWebSocketFrame) {
            promise = promise.unvoid();
            this.closeSent = promise;
        }
        super.write(ctx, msg, promise);
    }

    private void applyCloseSentTimeout(ChannelHandlerContext ctx) {
        if (this.closeSent.isDone() || this.forceCloseTimeoutMillis < 0) {
            return;
        }
        final ScheduledFuture<?> timeoutTask = ctx.executor().schedule(new Runnable() { // from class: io.netty.handler.codec.http.websocketx.WebSocketCloseFrameHandler.2
            @Override // java.lang.Runnable
            public void run() {
                if (!WebSocketCloseFrameHandler.this.closeSent.isDone()) {
                    WebSocketCloseFrameHandler.this.closeSent.tryFailure(new WebSocketHandshakeException("send close frame timed out"));
                }
            }
        }, this.forceCloseTimeoutMillis, TimeUnit.MILLISECONDS);
        this.closeSent.addListener((GenericFutureListener<? extends Future<? super Void>>) new ChannelFutureListener() { // from class: io.netty.handler.codec.http.websocketx.WebSocketCloseFrameHandler.3
            @Override // io.netty.util.concurrent.GenericFutureListener
            public void operationComplete(ChannelFuture future) {
                timeoutTask.cancel(false);
            }
        });
    }
}
