package io.netty.handler.ssl;

import io.netty.buffer.ByteBuf;
import io.netty.buffer.ByteBufUtil;
import io.netty.channel.ChannelHandlerContext;
import io.netty.channel.ChannelOutboundHandler;
import io.netty.channel.ChannelPromise;
import io.netty.handler.codec.ByteToMessageDecoder;
import io.netty.handler.codec.DecoderException;
import io.netty.util.CharsetUtil;
import io.netty.util.concurrent.Future;
import io.netty.util.concurrent.FutureListener;
import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.net.SocketAddress;
import java.util.List;
import java.util.Locale;
/* loaded from: classes.dex */
public abstract class AbstractSniHandler<T> extends ByteToMessageDecoder implements ChannelOutboundHandler {
    private static final InternalLogger logger = InternalLoggerFactory.getInstance(AbstractSniHandler.class);
    private ByteBuf handshakeBuffer;
    private boolean handshakeFailed;
    private boolean readPending;
    private boolean suppressRead;

    protected abstract Future<T> lookup(ChannelHandlerContext channelHandlerContext, String str) throws Exception;

    protected abstract void onLookupComplete(ChannelHandlerContext channelHandlerContext, String str, Future<T> future) throws Exception;

    @Override // io.netty.handler.codec.ByteToMessageDecoder
    protected void decode(ChannelHandlerContext ctx, ByteBuf in, List<Object> out) throws Exception {
        if (!this.suppressRead && !this.handshakeFailed) {
            try {
                int readerIndex = in.readerIndex();
                int readableBytes = in.readableBytes();
                int handshakeLength = -1;
                while (readableBytes >= 5) {
                    int contentType = in.getUnsignedByte(readerIndex);
                    switch (contentType) {
                        case 20:
                        case 21:
                            int len = SslUtils.getEncryptedPacketLength(in, readerIndex);
                            if (len == -2) {
                                this.handshakeFailed = true;
                                NotSslRecordException e = new NotSslRecordException("not an SSL/TLS record: " + ByteBufUtil.hexDump(in));
                                in.skipBytes(in.readableBytes());
                                ctx.fireUserEventTriggered((Object) new SniCompletionEvent(e));
                                SslUtils.handleHandshakeFailure(ctx, e, true);
                                throw e;
                            } else if (len == -1) {
                                return;
                            } else {
                                select(ctx, null);
                                return;
                            }
                        case 22:
                            int majorVersion = in.getUnsignedByte(readerIndex + 1);
                            if (majorVersion == 3) {
                                int packetLength = in.getUnsignedShort(readerIndex + 3) + 5;
                                if (readableBytes < packetLength) {
                                    return;
                                }
                                if (packetLength == 5) {
                                    select(ctx, null);
                                    return;
                                }
                                int endOffset = readerIndex + packetLength;
                                if (handshakeLength == -1) {
                                    if (readerIndex + 4 > endOffset) {
                                        return;
                                    }
                                    int handshakeType = in.getUnsignedByte(readerIndex + 5);
                                    if (handshakeType != 1) {
                                        select(ctx, null);
                                        return;
                                    }
                                    handshakeLength = in.getUnsignedMedium(readerIndex + 5 + 1);
                                    readerIndex += 4;
                                    packetLength -= 4;
                                    if (handshakeLength + 4 + 5 <= packetLength) {
                                        int readerIndex2 = readerIndex + 5;
                                        select(ctx, extractSniHostname(in, readerIndex2, readerIndex2 + handshakeLength));
                                        return;
                                    } else if (this.handshakeBuffer == null) {
                                        this.handshakeBuffer = ctx.alloc().buffer(handshakeLength);
                                    } else {
                                        this.handshakeBuffer.clear();
                                    }
                                }
                                this.handshakeBuffer.writeBytes(in, readerIndex + 5, packetLength - 5);
                                readerIndex += packetLength;
                                readableBytes -= packetLength;
                                if (handshakeLength <= this.handshakeBuffer.readableBytes()) {
                                    select(ctx, extractSniHostname(this.handshakeBuffer, 0, handshakeLength));
                                    return;
                                }
                            } else {
                                select(ctx, null);
                                return;
                            }
                        default:
                            select(ctx, null);
                            return;
                    }
                }
            } catch (NotSslRecordException e2) {
                throw e2;
            } catch (Exception e3) {
                if (logger.isDebugEnabled()) {
                    logger.debug("Unexpected client hello packet: " + ByteBufUtil.hexDump(in), (Throwable) e3);
                }
                select(ctx, null);
            }
        }
    }

    private static String extractSniHostname(ByteBuf in, int offset, int endOffset) {
        int offset2 = offset + 34;
        if (endOffset - offset2 >= 6) {
            int sessionIdLength = in.getUnsignedByte(offset2);
            int offset3 = offset2 + sessionIdLength + 1;
            int cipherSuitesLength = in.getUnsignedShort(offset3);
            int offset4 = offset3 + cipherSuitesLength + 2;
            int compressionMethodLength = in.getUnsignedByte(offset4);
            int offset5 = offset4 + compressionMethodLength + 1;
            int extensionsLength = in.getUnsignedShort(offset5);
            int offset6 = offset5 + 2;
            int extensionsLimit = offset6 + extensionsLength;
            if (extensionsLimit <= endOffset) {
                while (extensionsLimit - offset6 >= 4) {
                    int extensionType = in.getUnsignedShort(offset6);
                    int offset7 = offset6 + 2;
                    int extensionLength = in.getUnsignedShort(offset7);
                    int offset8 = offset7 + 2;
                    if (extensionsLimit - offset8 >= extensionLength) {
                        if (extensionType == 0) {
                            int offset9 = offset8 + 2;
                            if (extensionsLimit - offset9 >= 3) {
                                int serverNameType = in.getUnsignedByte(offset9);
                                int offset10 = offset9 + 1;
                                if (serverNameType == 0) {
                                    int serverNameLength = in.getUnsignedShort(offset10);
                                    int offset11 = offset10 + 2;
                                    if (extensionsLimit - offset11 >= serverNameLength) {
                                        String hostname = in.toString(offset11, serverNameLength, CharsetUtil.US_ASCII);
                                        return hostname.toLowerCase(Locale.US);
                                    }
                                    return null;
                                }
                                return null;
                            }
                            return null;
                        }
                        offset6 = offset8 + extensionLength;
                    } else {
                        return null;
                    }
                }
                return null;
            }
            return null;
        }
        return null;
    }

    private void releaseHandshakeBuffer() {
        ByteBuf byteBuf = this.handshakeBuffer;
        if (byteBuf != null) {
            byteBuf.release();
            this.handshakeBuffer = null;
        }
    }

    private void select(final ChannelHandlerContext ctx, final String hostname) throws Exception {
        releaseHandshakeBuffer();
        Future<T> future = lookup(ctx, hostname);
        if (future.isDone()) {
            fireSniCompletionEvent(ctx, hostname, future);
            onLookupComplete(ctx, hostname, future);
            return;
        }
        this.suppressRead = true;
        future.addListener(new FutureListener<T>() { // from class: io.netty.handler.ssl.AbstractSniHandler.1
            @Override // io.netty.util.concurrent.GenericFutureListener
            public void operationComplete(Future<T> future2) {
                try {
                    AbstractSniHandler.this.suppressRead = false;
                    try {
                        AbstractSniHandler.this.fireSniCompletionEvent(ctx, hostname, future2);
                        AbstractSniHandler.this.onLookupComplete(ctx, hostname, future2);
                    } catch (DecoderException err) {
                        ctx.fireExceptionCaught((Throwable) err);
                    } catch (Exception cause) {
                        ctx.fireExceptionCaught((Throwable) new DecoderException(cause));
                    }
                } finally {
                    if (AbstractSniHandler.this.readPending) {
                        AbstractSniHandler.this.readPending = false;
                        ctx.read();
                    }
                }
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // io.netty.handler.codec.ByteToMessageDecoder
    public void handlerRemoved0(ChannelHandlerContext ctx) throws Exception {
        releaseHandshakeBuffer();
        super.handlerRemoved0(ctx);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void fireSniCompletionEvent(ChannelHandlerContext ctx, String hostname, Future<T> future) {
        Throwable cause = future.cause();
        if (cause == null) {
            ctx.fireUserEventTriggered((Object) new SniCompletionEvent(hostname));
        } else {
            ctx.fireUserEventTriggered((Object) new SniCompletionEvent(hostname, cause));
        }
    }

    @Override // io.netty.channel.ChannelOutboundHandler
    public void read(ChannelHandlerContext ctx) throws Exception {
        if (this.suppressRead) {
            this.readPending = true;
        } else {
            ctx.read();
        }
    }

    @Override // io.netty.channel.ChannelOutboundHandler
    public void bind(ChannelHandlerContext ctx, SocketAddress localAddress, ChannelPromise promise) throws Exception {
        ctx.bind(localAddress, promise);
    }

    @Override // io.netty.channel.ChannelOutboundHandler
    public void connect(ChannelHandlerContext ctx, SocketAddress remoteAddress, SocketAddress localAddress, ChannelPromise promise) throws Exception {
        ctx.connect(remoteAddress, localAddress, promise);
    }

    @Override // io.netty.channel.ChannelOutboundHandler
    public void disconnect(ChannelHandlerContext ctx, ChannelPromise promise) throws Exception {
        ctx.disconnect(promise);
    }

    @Override // io.netty.channel.ChannelOutboundHandler
    public void close(ChannelHandlerContext ctx, ChannelPromise promise) throws Exception {
        ctx.close(promise);
    }

    @Override // io.netty.channel.ChannelOutboundHandler
    public void deregister(ChannelHandlerContext ctx, ChannelPromise promise) throws Exception {
        ctx.deregister(promise);
    }

    @Override // io.netty.channel.ChannelOutboundHandler
    public void write(ChannelHandlerContext ctx, Object msg, ChannelPromise promise) throws Exception {
        ctx.write(msg, promise);
    }

    @Override // io.netty.channel.ChannelOutboundHandler
    public void flush(ChannelHandlerContext ctx) throws Exception {
        ctx.flush();
    }
}
