package io.netty.handler.ssl;

import io.netty.buffer.ByteBuf;
import io.netty.buffer.ByteBufAllocator;
import io.netty.buffer.UnpooledByteBufAllocator;
import io.netty.internal.tcnative.Buffer;
import io.netty.internal.tcnative.CertificateCallback;
import io.netty.internal.tcnative.Library;
import io.netty.internal.tcnative.SSL;
import io.netty.internal.tcnative.SSLContext;
import io.netty.util.CharsetUtil;
import io.netty.util.ReferenceCountUtil;
import io.netty.util.ReferenceCounted;
import io.netty.util.internal.NativeLibraryLoader;
import io.netty.util.internal.PlatformDependent;
import io.netty.util.internal.SystemPropertyUtil;
import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.io.ByteArrayInputStream;
import java.security.cert.CertificateException;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Collections;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
/* loaded from: classes.dex */
public final class OpenSsl {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    static final Set<String> AVAILABLE_CIPHER_SUITES;
    private static final Set<String> AVAILABLE_JAVA_CIPHER_SUITES;
    private static final Set<String> AVAILABLE_OPENSSL_CIPHER_SUITES;
    private static final String CERT = "-----BEGIN CERTIFICATE-----\nMIICrjCCAZagAwIBAgIIdSvQPv1QAZQwDQYJKoZIhvcNAQELBQAwFjEUMBIGA1UEAxMLZXhhbXBs\nZS5jb20wIBcNMTgwNDA2MjIwNjU5WhgPOTk5OTEyMzEyMzU5NTlaMBYxFDASBgNVBAMTC2V4YW1w\nbGUuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAggbWsmDQ6zNzRZ5AW8E3eoGl\nqWvOBDb5Fs1oBRrVQHuYmVAoaqwDzXYJ0LOwa293AgWEQ1jpcbZ2hpoYQzqEZBTLnFhMrhRFlH6K\nbJND8Y33kZ/iSVBBDuGbdSbJShlM+4WwQ9IAso4MZ4vW3S1iv5fGGpLgbtXRmBf/RU8omN0Gijlv\nWlLWHWijLN8xQtySFuBQ7ssW8RcKAary3pUm6UUQB+Co6lnfti0Tzag8PgjhAJq2Z3wbsGRnP2YS\nvYoaK6qzmHXRYlp/PxrjBAZAmkLJs4YTm/XFF+fkeYx4i9zqHbyone5yerRibsHaXZWLnUL+rFoe\nMdKvr0VS3sGmhQIDAQABMA0GCSqGSIb3DQEBCwUAA4IBAQADQi441pKmXf9FvUV5EHU4v8nJT9Iq\nyqwsKwXnr7AsUlDGHBD7jGrjAXnG5rGxuNKBQ35wRxJATKrUtyaquFUL6H8O6aGQehiFTk6zmPbe\n12Gu44vqqTgIUxnv3JQJiox8S2hMxsSddpeCmSdvmalvD6WG4NthH6B9ZaBEiep1+0s0RUaBYn73\nI7CCUaAtbjfR6pcJjrFk5ei7uwdQZFSJtkP2z8r7zfeANJddAKFlkaMWn7u+OIVuB4XPooWicObk\nNAHFtP65bocUYnDpTVdiyvn8DdqyZ/EO8n1bBKBzuSLplk2msW4pdgaFgY7Vw/0wzcFXfUXmL1uy\nG8sQD/wx\n-----END CERTIFICATE-----";
    static final List<String> DEFAULT_CIPHERS;
    private static final boolean IS_BORINGSSL;
    private static final String KEY = "-----BEGIN PRIVATE KEY-----\nMIIEvQIBADANBgkqhkiG9w0BAQEFAASCBKcwggSjAgEAAoIBAQCCBtayYNDrM3NFnkBbwTd6gaWp\na84ENvkWzWgFGtVAe5iZUChqrAPNdgnQs7Brb3cCBYRDWOlxtnaGmhhDOoRkFMucWEyuFEWUfops\nk0PxjfeRn+JJUEEO4Zt1JslKGUz7hbBD0gCyjgxni9bdLWK/l8YakuBu1dGYF/9FTyiY3QaKOW9a\nUtYdaKMs3zFC3JIW4FDuyxbxFwoBqvLelSbpRRAH4KjqWd+2LRPNqDw+COEAmrZnfBuwZGc/ZhK9\nihorqrOYddFiWn8/GuMEBkCaQsmzhhOb9cUX5+R5jHiL3OodvKid7nJ6tGJuwdpdlYudQv6sWh4x\n0q+vRVLewaaFAgMBAAECggEAP8tPJvFtTxhNJAkCloHz0D0vpDHqQBMgntlkgayqmBqLwhyb18pR\ni0qwgh7HHc7wWqOOQuSqlEnrWRrdcI6TSe8R/sErzfTQNoznKWIPYcI/hskk4sdnQ//Yn9/Jvnsv\nU/BBjOTJxtD+sQbhAl80JcA3R+5sArURQkfzzHOL/YMqzAsn5hTzp7HZCxUqBk3KaHRxV7NefeOE\nxlZuWSmxYWfbFIs4kx19/1t7h8CHQWezw+G60G2VBtSBBxDnhBWvqG6R/wpzJ3nEhPLLY9T+XIHe\nipzdMOOOUZorfIg7M+pyYPji+ZIZxIpY5OjrOzXHciAjRtr5Y7l99K1CG1LguQKBgQDrQfIMxxtZ\nvxU/1cRmUV9l7pt5bjV5R6byXq178LxPKVYNjdZ840Q0/OpZEVqaT1xKVi35ohP1QfNjxPLlHD+K\niDAR9z6zkwjIrbwPCnb5kuXy4lpwPcmmmkva25fI7qlpHtbcuQdoBdCfr/KkKaUCMPyY89LCXgEw\n5KTDj64UywKBgQCNfbO+eZLGzhiHhtNJurresCsIGWlInv322gL8CSfBMYl6eNfUTZvUDdFhPISL\nUljKWzXDrjw0ujFSPR0XhUGtiq89H+HUTuPPYv25gVXO+HTgBFZEPl4PpA+BUsSVZy0NddneyqLk\n42Wey9omY9Q8WsdNQS5cbUvy0uG6WFoX7wKBgQDZ1jpW8pa0x2bZsQsm4vo+3G5CRnZlUp+XlWt2\ndDcp5dC0xD1zbs1dc0NcLeGDOTDv9FSl7hok42iHXXq8AygjEm/QcuwwQ1nC2HxmQP5holAiUs4D\nWHM8PWs3wFYPzE459EBoKTxeaeP/uWAn+he8q7d5uWvSZlEcANs/6e77eQKBgD21Ar0hfFfj7mK8\n9E0FeRZBsqK3omkfnhcYgZC11Xa2SgT1yvs2Va2n0RcdM5kncr3eBZav2GYOhhAdwyBM55XuE/sO\neokDVutNeuZ6d5fqV96TRaRBpvgfTvvRwxZ9hvKF4Vz+9wfn/JvCwANaKmegF6ejs7pvmF3whq2k\ndrZVAoGAX5YxQ5XMTD0QbMAl7/6qp6S58xNoVdfCkmkj1ZLKaHKIjS/benkKGlySVQVPexPfnkZx\np/Vv9yyphBoudiTBS9Uog66ueLYZqpgxlM/6OhYg86Gm3U2ycvMxYjBM1NFiyze21AqAhI+HX+Ot\nmraV2/guSgDgZAhukRZzeQ2RucI=\n-----END PRIVATE KEY-----";
    static final Set<String> SUPPORTED_PROTOCOLS_SET;
    private static final boolean SUPPORTS_KEYMANAGER_FACTORY;
    private static final boolean SUPPORTS_OCSP;
    private static final boolean TLSV13_SUPPORTED;
    private static final Throwable UNAVAILABILITY_CAUSE;
    private static final boolean USE_KEYMANAGER_FACTORY;
    private static final InternalLogger logger = InternalLoggerFactory.getInstance(OpenSsl.class);

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Removed duplicated region for block: B:121:0x0284 A[Catch: all -> 0x02ce, TryCatch #19 {all -> 0x02ce, blocks: (B:119:0x027d, B:121:0x0284, B:124:0x028b, B:127:0x0292, B:130:0x0299, B:140:0x02ad, B:142:0x02b4, B:145:0x02bb, B:148:0x02c2, B:151:0x02c9, B:153:0x02cd), top: B:215:0x0172 }] */
    /* JADX WARN: Removed duplicated region for block: B:124:0x028b A[Catch: all -> 0x02ce, TryCatch #19 {all -> 0x02ce, blocks: (B:119:0x027d, B:121:0x0284, B:124:0x028b, B:127:0x0292, B:130:0x0299, B:140:0x02ad, B:142:0x02b4, B:145:0x02bb, B:148:0x02c2, B:151:0x02c9, B:153:0x02cd), top: B:215:0x0172 }] */
    /* JADX WARN: Removed duplicated region for block: B:127:0x0292 A[Catch: all -> 0x02ce, TryCatch #19 {all -> 0x02ce, blocks: (B:119:0x027d, B:121:0x0284, B:124:0x028b, B:127:0x0292, B:130:0x0299, B:140:0x02ad, B:142:0x02b4, B:145:0x02bb, B:148:0x02c2, B:151:0x02c9, B:153:0x02cd), top: B:215:0x0172 }] */
    /* JADX WARN: Removed duplicated region for block: B:130:0x0299 A[Catch: all -> 0x02ce, TRY_LEAVE, TryCatch #19 {all -> 0x02ce, blocks: (B:119:0x027d, B:121:0x0284, B:124:0x028b, B:127:0x0292, B:130:0x0299, B:140:0x02ad, B:142:0x02b4, B:145:0x02bb, B:148:0x02c2, B:151:0x02c9, B:153:0x02cd), top: B:215:0x0172 }] */
    /* JADX WARN: Removed duplicated region for block: B:142:0x02b4 A[Catch: all -> 0x02ce, TryCatch #19 {all -> 0x02ce, blocks: (B:119:0x027d, B:121:0x0284, B:124:0x028b, B:127:0x0292, B:130:0x0299, B:140:0x02ad, B:142:0x02b4, B:145:0x02bb, B:148:0x02c2, B:151:0x02c9, B:153:0x02cd), top: B:215:0x0172 }] */
    /* JADX WARN: Removed duplicated region for block: B:145:0x02bb A[Catch: all -> 0x02ce, TryCatch #19 {all -> 0x02ce, blocks: (B:119:0x027d, B:121:0x0284, B:124:0x028b, B:127:0x0292, B:130:0x0299, B:140:0x02ad, B:142:0x02b4, B:145:0x02bb, B:148:0x02c2, B:151:0x02c9, B:153:0x02cd), top: B:215:0x0172 }] */
    /* JADX WARN: Removed duplicated region for block: B:148:0x02c2 A[Catch: all -> 0x02ce, TryCatch #19 {all -> 0x02ce, blocks: (B:119:0x027d, B:121:0x0284, B:124:0x028b, B:127:0x0292, B:130:0x0299, B:140:0x02ad, B:142:0x02b4, B:145:0x02bb, B:148:0x02c2, B:151:0x02c9, B:153:0x02cd), top: B:215:0x0172 }] */
    /* JADX WARN: Removed duplicated region for block: B:151:0x02c9 A[Catch: all -> 0x02ce, TryCatch #19 {all -> 0x02ce, blocks: (B:119:0x027d, B:121:0x0284, B:124:0x028b, B:127:0x0292, B:130:0x0299, B:140:0x02ad, B:142:0x02b4, B:145:0x02bb, B:148:0x02c2, B:151:0x02c9, B:153:0x02cd), top: B:215:0x0172 }] */
    /* JADX WARN: Removed duplicated region for block: B:168:0x0306  */
    /* JADX WARN: Removed duplicated region for block: B:175:0x0378  */
    /* JADX WARN: Removed duplicated region for block: B:178:0x0385  */
    /* JADX WARN: Removed duplicated region for block: B:181:0x0393  */
    /* JADX WARN: Removed duplicated region for block: B:184:0x03a2  */
    /* JADX WARN: Removed duplicated region for block: B:187:0x03b1  */
    /* JADX WARN: Removed duplicated region for block: B:189:0x03b8  */
    /* JADX WARN: Removed duplicated region for block: B:195:0x03e2  */
    /* JADX WARN: Removed duplicated region for block: B:249:? A[RETURN, SYNTHETIC] */
    /* JADX WARN: Type inference failed for: r1v0, types: [java.lang.String] */
    /* JADX WARN: Type inference failed for: r1v20 */
    /* JADX WARN: Type inference failed for: r1v21 */
    /* JADX WARN: Type inference failed for: r1v22 */
    /* JADX WARN: Type inference failed for: r1v24 */
    /* JADX WARN: Type inference failed for: r1v25 */
    /* JADX WARN: Type inference failed for: r1v26 */
    /* JADX WARN: Type inference failed for: r2v50, types: [io.netty.util.internal.logging.InternalLogger] */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:92:0x0225 -> B:206:0x0226). Please submit an issue!!! */
    static {
        long sslCtx;
        long certBio;
        long keyBio;
        long cert;
        long key;
        String[] ciphers;
        boolean tlsv13Supported;
        boolean useKeyManagerFactory = "io.netty.handler.ssl.openssl.useKeyManagerFactory";
        Throwable cause = null;
        if (SystemPropertyUtil.getBoolean("io.netty.handler.ssl.noOpenSsl", false)) {
            Throwable unsupportedOperationException = new UnsupportedOperationException("OpenSSL was explicit disabled with -Dio.netty.handler.ssl.noOpenSsl=true");
            logger.debug("netty-tcnative explicit disabled; " + OpenSslEngine.class.getSimpleName() + " will be unavailable.", unsupportedOperationException);
            cause = unsupportedOperationException;
        } else {
            try {
                Class.forName("io.netty.internal.tcnative.SSL", false, OpenSsl.class.getClassLoader());
            } catch (ClassNotFoundException t) {
                cause = t;
                logger.debug("netty-tcnative not in the classpath; " + OpenSslEngine.class.getSimpleName() + " will be unavailable.");
            }
            if (cause == null) {
                try {
                    loadTcNative();
                } catch (Throwable th) {
                    cause = th;
                    logger.debug("Failed to load netty-tcnative; " + OpenSslEngine.class.getSimpleName() + " will be unavailable, unless the application has already loaded the symbols by some other means. See https://netty.io/wiki/forked-tomcat-native.html for more information.", (Throwable) th);
                }
                try {
                    String engine = SystemPropertyUtil.get("io.netty.handler.ssl.openssl.engine", null);
                    if (engine == null) {
                        logger.debug("Initialize netty-tcnative using engine: 'default'");
                    } else {
                        logger.debug("Initialize netty-tcnative using engine: '{}'", engine);
                    }
                    initializeTcNative(engine);
                    cause = null;
                } catch (Throwable th2) {
                    if (cause == null) {
                        cause = th2;
                    }
                    logger.debug("Failed to initialize netty-tcnative; " + OpenSslEngine.class.getSimpleName() + " will be unavailable. See https://netty.io/wiki/forked-tomcat-native.html for more information.", (Throwable) th2);
                }
            }
        }
        UNAVAILABILITY_CAUSE = cause;
        if (cause != null) {
            DEFAULT_CIPHERS = Collections.emptyList();
            AVAILABLE_OPENSSL_CIPHER_SUITES = Collections.emptySet();
            AVAILABLE_JAVA_CIPHER_SUITES = Collections.emptySet();
            AVAILABLE_CIPHER_SUITES = Collections.emptySet();
            SUPPORTS_KEYMANAGER_FACTORY = false;
            USE_KEYMANAGER_FACTORY = false;
            SUPPORTED_PROTOCOLS_SET = Collections.emptySet();
            SUPPORTS_OCSP = false;
            TLSV13_SUPPORTED = false;
            IS_BORINGSSL = false;
            return;
        }
        logger.debug("netty-tcnative using native library: {}", SSL.versionString());
        List<String> defaultCiphers = new ArrayList<>();
        Set<String> availableOpenSslCipherSuites = new LinkedHashSet<>(128);
        boolean supportsKeyManagerFactory = false;
        boolean useKeyManagerFactory2 = false;
        boolean tlsv13Supported2 = false;
        IS_BORINGSSL = "BoringSSL".equals(versionString());
        try {
            sslCtx = SSLContext.make(63, 1);
            certBio = 0;
            keyBio = 0;
            cert = 0;
            key = 0;
            try {
                try {
                    StringBuilder tlsv13Ciphers = new StringBuilder();
                    for (String cipher : SslUtils.TLSV13_CIPHERS) {
                        String converted = CipherSuiteConverter.toOpenSsl(cipher, IS_BORINGSSL);
                        if (converted != null) {
                            tlsv13Ciphers.append(converted);
                            tlsv13Ciphers.append(':');
                        }
                    }
                    if (tlsv13Ciphers.length() == 0) {
                        tlsv13Supported = false;
                    } else {
                        tlsv13Ciphers.setLength(tlsv13Ciphers.length() - 1);
                        SSLContext.setCipherSuite(sslCtx, tlsv13Ciphers.toString(), true);
                        tlsv13Supported = true;
                    }
                    tlsv13Supported2 = tlsv13Supported;
                } catch (Exception e) {
                    e = e;
                    logger.warn("Failed to get the list of available OpenSSL cipher suites.", (Throwable) e);
                    AVAILABLE_OPENSSL_CIPHER_SUITES = Collections.unmodifiableSet(availableOpenSslCipherSuites);
                    Set<String> availableJavaCipherSuites = new LinkedHashSet<>(AVAILABLE_OPENSSL_CIPHER_SUITES.size() * 2);
                    while (r1.hasNext()) {
                    }
                    SslUtils.addIfSupported(availableJavaCipherSuites, defaultCiphers, SslUtils.DEFAULT_CIPHER_SUITES);
                    SslUtils.addIfSupported(availableJavaCipherSuites, defaultCiphers, SslUtils.TLSV13_CIPHER_SUITES);
                    SslUtils.useFallbackCiphersIfDefaultIsEmpty(defaultCiphers, availableJavaCipherSuites);
                    DEFAULT_CIPHERS = Collections.unmodifiableList(defaultCiphers);
                    AVAILABLE_JAVA_CIPHER_SUITES = Collections.unmodifiableSet(availableJavaCipherSuites);
                    Set<String> availableCipherSuites = new LinkedHashSet<>(AVAILABLE_OPENSSL_CIPHER_SUITES.size() + AVAILABLE_JAVA_CIPHER_SUITES.size());
                    availableCipherSuites.addAll(AVAILABLE_OPENSSL_CIPHER_SUITES);
                    availableCipherSuites.addAll(AVAILABLE_JAVA_CIPHER_SUITES);
                    AVAILABLE_CIPHER_SUITES = availableCipherSuites;
                    SUPPORTS_KEYMANAGER_FACTORY = supportsKeyManagerFactory;
                    USE_KEYMANAGER_FACTORY = useKeyManagerFactory2;
                    Set<String> protocols = new LinkedHashSet<>(6);
                    protocols.add("SSLv2Hello");
                    if (doesSupportProtocol(1, SSL.SSL_OP_NO_SSLv2)) {
                    }
                    if (doesSupportProtocol(2, SSL.SSL_OP_NO_SSLv3)) {
                    }
                    if (doesSupportProtocol(4, SSL.SSL_OP_NO_TLSv1)) {
                    }
                    if (doesSupportProtocol(8, SSL.SSL_OP_NO_TLSv1_1)) {
                    }
                    if (doesSupportProtocol(16, SSL.SSL_OP_NO_TLSv1_2)) {
                    }
                    if (tlsv13Supported2) {
                    }
                    TLSV13_SUPPORTED = false;
                    SUPPORTED_PROTOCOLS_SET = Collections.unmodifiableSet(protocols);
                    SUPPORTS_OCSP = doesSupportOcsp();
                    if (logger.isDebugEnabled()) {
                    }
                }
            } catch (Exception e2) {
                tlsv13Supported2 = false;
            } catch (Throwable th3) {
                th = th3;
                SSLContext.free(sslCtx);
                throw th;
            }
        } catch (Exception e3) {
            e = e3;
        }
        try {
            SSLContext.setCipherSuite(sslCtx, "ALL", false);
            long ssl = SSL.newSSL(sslCtx, true);
            try {
                try {
                    for (String c : SSL.getCiphers(ssl)) {
                        try {
                            if (c != null && !c.isEmpty() && !availableOpenSslCipherSuites.contains(c) && (tlsv13Supported2 || !SslUtils.isTLSv13Cipher(c))) {
                                availableOpenSslCipherSuites.add(c);
                            }
                        } catch (Throwable th4) {
                            th = th4;
                            SSL.freeSSL(ssl);
                            if (certBio != 0) {
                            }
                            if (keyBio != 0) {
                            }
                            if (cert != 0) {
                            }
                            if (key != 0) {
                            }
                            throw th;
                        }
                    }
                    if (IS_BORINGSSL) {
                        Collections.addAll(availableOpenSslCipherSuites, "TLS_AES_128_GCM_SHA256", "TLS_AES_256_GCM_SHA384", "TLS_CHACHA20_POLY1305_SHA256", "AEAD-AES128-GCM-SHA256", "AEAD-AES256-GCM-SHA384", "AEAD-CHACHA20-POLY1305-SHA256");
                    }
                    PemEncoded privateKey = PemPrivateKey.valueOf(KEY.getBytes(CharsetUtil.US_ASCII));
                    try {
                        try {
                            SSLContext.setCertificateCallback(sslCtx, (CertificateCallback) null);
                            X509Certificate certificate = selfSignedCertificate();
                            try {
                                certBio = ReferenceCountedOpenSslContext.toBIO(ByteBufAllocator.DEFAULT, certificate);
                                long cert2 = SSL.parseX509Chain(certBio);
                                try {
                                    long keyBio2 = ReferenceCountedOpenSslContext.toBIO(UnpooledByteBufAllocator.DEFAULT, privateKey.retain());
                                    boolean supportsKeyManagerFactory2 = false;
                                    try {
                                        long key2 = SSL.parsePrivateKey(keyBio2, (String) null);
                                        try {
                                            SSL.setKeyMaterial(ssl, cert2, key2);
                                            supportsKeyManagerFactory2 = true;
                                            try {
                                                try {
                                                    boolean propertySet = SystemPropertyUtil.contains("io.netty.handler.ssl.openssl.useKeyManagerFactory");
                                                    try {
                                                        if (IS_BORINGSSL) {
                                                            useKeyManagerFactory = 1;
                                                            useKeyManagerFactory = 1;
                                                            if (propertySet) {
                                                                logger.info("System property 'io.netty.handler.ssl.openssl.useKeyManagerFactory' is deprecated and will be ignored when using BoringSSL");
                                                            }
                                                        } else {
                                                            boolean z = SystemPropertyUtil.getBoolean("io.netty.handler.ssl.openssl.useKeyManagerFactory", true);
                                                            useKeyManagerFactory = z;
                                                            if (propertySet) {
                                                                logger.info("System property 'io.netty.handler.ssl.openssl.useKeyManagerFactory' is deprecated and so will be ignored in the future");
                                                                useKeyManagerFactory = z;
                                                            }
                                                        }
                                                    } catch (Throwable th5) {
                                                        useKeyManagerFactory2 = useKeyManagerFactory;
                                                        logger.debug("Failed to get useKeyManagerFactory system property.");
                                                        useKeyManagerFactory = useKeyManagerFactory2;
                                                        privateKey.release();
                                                        useKeyManagerFactory2 = useKeyManagerFactory;
                                                        keyBio = keyBio2;
                                                        cert = cert2;
                                                        key = key2;
                                                        supportsKeyManagerFactory = true;
                                                        SSL.freeSSL(ssl);
                                                        if (certBio != 0) {
                                                        }
                                                        if (keyBio != 0) {
                                                        }
                                                        if (cert != 0) {
                                                        }
                                                        if (key != 0) {
                                                        }
                                                        SSLContext.free(sslCtx);
                                                        AVAILABLE_OPENSSL_CIPHER_SUITES = Collections.unmodifiableSet(availableOpenSslCipherSuites);
                                                        Set<String> availableJavaCipherSuites2 = new LinkedHashSet<>(AVAILABLE_OPENSSL_CIPHER_SUITES.size() * 2);
                                                        while (r1.hasNext()) {
                                                        }
                                                        SslUtils.addIfSupported(availableJavaCipherSuites2, defaultCiphers, SslUtils.DEFAULT_CIPHER_SUITES);
                                                        SslUtils.addIfSupported(availableJavaCipherSuites2, defaultCiphers, SslUtils.TLSV13_CIPHER_SUITES);
                                                        SslUtils.useFallbackCiphersIfDefaultIsEmpty(defaultCiphers, availableJavaCipherSuites2);
                                                        DEFAULT_CIPHERS = Collections.unmodifiableList(defaultCiphers);
                                                        AVAILABLE_JAVA_CIPHER_SUITES = Collections.unmodifiableSet(availableJavaCipherSuites2);
                                                        Set<String> availableCipherSuites2 = new LinkedHashSet<>(AVAILABLE_OPENSSL_CIPHER_SUITES.size() + AVAILABLE_JAVA_CIPHER_SUITES.size());
                                                        availableCipherSuites2.addAll(AVAILABLE_OPENSSL_CIPHER_SUITES);
                                                        availableCipherSuites2.addAll(AVAILABLE_JAVA_CIPHER_SUITES);
                                                        AVAILABLE_CIPHER_SUITES = availableCipherSuites2;
                                                        SUPPORTS_KEYMANAGER_FACTORY = supportsKeyManagerFactory;
                                                        USE_KEYMANAGER_FACTORY = useKeyManagerFactory2;
                                                        Set<String> protocols2 = new LinkedHashSet<>(6);
                                                        protocols2.add("SSLv2Hello");
                                                        if (doesSupportProtocol(1, SSL.SSL_OP_NO_SSLv2)) {
                                                        }
                                                        if (doesSupportProtocol(2, SSL.SSL_OP_NO_SSLv3)) {
                                                        }
                                                        if (doesSupportProtocol(4, SSL.SSL_OP_NO_TLSv1)) {
                                                        }
                                                        if (doesSupportProtocol(8, SSL.SSL_OP_NO_TLSv1_1)) {
                                                        }
                                                        if (doesSupportProtocol(16, SSL.SSL_OP_NO_TLSv1_2)) {
                                                        }
                                                        if (tlsv13Supported2) {
                                                        }
                                                        TLSV13_SUPPORTED = false;
                                                        SUPPORTED_PROTOCOLS_SET = Collections.unmodifiableSet(protocols2);
                                                        SUPPORTS_OCSP = doesSupportOcsp();
                                                        if (logger.isDebugEnabled()) {
                                                        }
                                                    }
                                                } catch (Throwable th6) {
                                                    logger.debug("Failed to get useKeyManagerFactory system property.");
                                                    useKeyManagerFactory = useKeyManagerFactory2;
                                                    privateKey.release();
                                                    useKeyManagerFactory2 = useKeyManagerFactory;
                                                    keyBio = keyBio2;
                                                    cert = cert2;
                                                    key = key2;
                                                    supportsKeyManagerFactory = true;
                                                    SSL.freeSSL(ssl);
                                                    if (certBio != 0) {
                                                    }
                                                    if (keyBio != 0) {
                                                    }
                                                    if (cert != 0) {
                                                    }
                                                    if (key != 0) {
                                                    }
                                                    SSLContext.free(sslCtx);
                                                    AVAILABLE_OPENSSL_CIPHER_SUITES = Collections.unmodifiableSet(availableOpenSslCipherSuites);
                                                    Set<String> availableJavaCipherSuites22 = new LinkedHashSet<>(AVAILABLE_OPENSSL_CIPHER_SUITES.size() * 2);
                                                    while (r1.hasNext()) {
                                                    }
                                                    SslUtils.addIfSupported(availableJavaCipherSuites22, defaultCiphers, SslUtils.DEFAULT_CIPHER_SUITES);
                                                    SslUtils.addIfSupported(availableJavaCipherSuites22, defaultCiphers, SslUtils.TLSV13_CIPHER_SUITES);
                                                    SslUtils.useFallbackCiphersIfDefaultIsEmpty(defaultCiphers, availableJavaCipherSuites22);
                                                    DEFAULT_CIPHERS = Collections.unmodifiableList(defaultCiphers);
                                                    AVAILABLE_JAVA_CIPHER_SUITES = Collections.unmodifiableSet(availableJavaCipherSuites22);
                                                    Set<String> availableCipherSuites22 = new LinkedHashSet<>(AVAILABLE_OPENSSL_CIPHER_SUITES.size() + AVAILABLE_JAVA_CIPHER_SUITES.size());
                                                    availableCipherSuites22.addAll(AVAILABLE_OPENSSL_CIPHER_SUITES);
                                                    availableCipherSuites22.addAll(AVAILABLE_JAVA_CIPHER_SUITES);
                                                    AVAILABLE_CIPHER_SUITES = availableCipherSuites22;
                                                    SUPPORTS_KEYMANAGER_FACTORY = supportsKeyManagerFactory;
                                                    USE_KEYMANAGER_FACTORY = useKeyManagerFactory2;
                                                    Set<String> protocols22 = new LinkedHashSet<>(6);
                                                    protocols22.add("SSLv2Hello");
                                                    if (doesSupportProtocol(1, SSL.SSL_OP_NO_SSLv2)) {
                                                    }
                                                    if (doesSupportProtocol(2, SSL.SSL_OP_NO_SSLv3)) {
                                                    }
                                                    if (doesSupportProtocol(4, SSL.SSL_OP_NO_TLSv1)) {
                                                    }
                                                    if (doesSupportProtocol(8, SSL.SSL_OP_NO_TLSv1_1)) {
                                                    }
                                                    if (doesSupportProtocol(16, SSL.SSL_OP_NO_TLSv1_2)) {
                                                    }
                                                    if (tlsv13Supported2) {
                                                    }
                                                    TLSV13_SUPPORTED = false;
                                                    SUPPORTED_PROTOCOLS_SET = Collections.unmodifiableSet(protocols22);
                                                    SUPPORTS_OCSP = doesSupportOcsp();
                                                    if (logger.isDebugEnabled()) {
                                                    }
                                                }
                                                privateKey.release();
                                                useKeyManagerFactory2 = useKeyManagerFactory;
                                                keyBio = keyBio2;
                                                cert = cert2;
                                                key = key2;
                                                supportsKeyManagerFactory = true;
                                            } catch (Throwable th7) {
                                                th = th7;
                                                keyBio = keyBio2;
                                                cert = cert2;
                                                key = key2;
                                                SSL.freeSSL(ssl);
                                                if (certBio != 0) {
                                                    SSL.freeBIO(certBio);
                                                }
                                                if (keyBio != 0) {
                                                    SSL.freeBIO(keyBio);
                                                }
                                                if (cert != 0) {
                                                    SSL.freeX509Chain(cert);
                                                }
                                                if (key != 0) {
                                                    SSL.freePrivateKey(key);
                                                }
                                                throw th;
                                            }
                                        } catch (Error e4) {
                                            keyBio = keyBio2;
                                            cert = cert2;
                                            key = key2;
                                            supportsKeyManagerFactory = supportsKeyManagerFactory2;
                                            try {
                                                logger.debug("KeyManagerFactory not supported.");
                                                privateKey.release();
                                                SSL.freeSSL(ssl);
                                                if (certBio != 0) {
                                                }
                                                if (keyBio != 0) {
                                                }
                                                if (cert != 0) {
                                                }
                                                if (key != 0) {
                                                }
                                                SSLContext.free(sslCtx);
                                                AVAILABLE_OPENSSL_CIPHER_SUITES = Collections.unmodifiableSet(availableOpenSslCipherSuites);
                                                Set<String> availableJavaCipherSuites222 = new LinkedHashSet<>(AVAILABLE_OPENSSL_CIPHER_SUITES.size() * 2);
                                                while (r1.hasNext()) {
                                                }
                                                SslUtils.addIfSupported(availableJavaCipherSuites222, defaultCiphers, SslUtils.DEFAULT_CIPHER_SUITES);
                                                SslUtils.addIfSupported(availableJavaCipherSuites222, defaultCiphers, SslUtils.TLSV13_CIPHER_SUITES);
                                                SslUtils.useFallbackCiphersIfDefaultIsEmpty(defaultCiphers, availableJavaCipherSuites222);
                                                DEFAULT_CIPHERS = Collections.unmodifiableList(defaultCiphers);
                                                AVAILABLE_JAVA_CIPHER_SUITES = Collections.unmodifiableSet(availableJavaCipherSuites222);
                                                Set<String> availableCipherSuites222 = new LinkedHashSet<>(AVAILABLE_OPENSSL_CIPHER_SUITES.size() + AVAILABLE_JAVA_CIPHER_SUITES.size());
                                                availableCipherSuites222.addAll(AVAILABLE_OPENSSL_CIPHER_SUITES);
                                                availableCipherSuites222.addAll(AVAILABLE_JAVA_CIPHER_SUITES);
                                                AVAILABLE_CIPHER_SUITES = availableCipherSuites222;
                                                SUPPORTS_KEYMANAGER_FACTORY = supportsKeyManagerFactory;
                                                USE_KEYMANAGER_FACTORY = useKeyManagerFactory2;
                                                Set<String> protocols222 = new LinkedHashSet<>(6);
                                                protocols222.add("SSLv2Hello");
                                                if (doesSupportProtocol(1, SSL.SSL_OP_NO_SSLv2)) {
                                                }
                                                if (doesSupportProtocol(2, SSL.SSL_OP_NO_SSLv3)) {
                                                }
                                                if (doesSupportProtocol(4, SSL.SSL_OP_NO_TLSv1)) {
                                                }
                                                if (doesSupportProtocol(8, SSL.SSL_OP_NO_TLSv1_1)) {
                                                }
                                                if (doesSupportProtocol(16, SSL.SSL_OP_NO_TLSv1_2)) {
                                                }
                                                if (tlsv13Supported2) {
                                                }
                                                TLSV13_SUPPORTED = false;
                                                SUPPORTED_PROTOCOLS_SET = Collections.unmodifiableSet(protocols222);
                                                SUPPORTS_OCSP = doesSupportOcsp();
                                                if (logger.isDebugEnabled()) {
                                                }
                                            } catch (Throwable th8) {
                                                th = th8;
                                                privateKey.release();
                                                throw th;
                                            }
                                        } catch (Throwable th9) {
                                            th = th9;
                                            privateKey.release();
                                            throw th;
                                        }
                                    } catch (Error e5) {
                                        keyBio = keyBio2;
                                        cert = cert2;
                                        supportsKeyManagerFactory = false;
                                    } catch (Throwable th10) {
                                        th = th10;
                                    }
                                } catch (Error e6) {
                                    cert = cert2;
                                } catch (Throwable th11) {
                                    th = th11;
                                }
                            } catch (Error e7) {
                            } catch (Throwable th12) {
                                th = th12;
                            }
                        } catch (Throwable th13) {
                            th = th13;
                        }
                    } catch (Error e8) {
                    } catch (Throwable th14) {
                        th = th14;
                    }
                    SSL.freeSSL(ssl);
                    if (certBio != 0) {
                        SSL.freeBIO(certBio);
                    }
                    if (keyBio != 0) {
                        SSL.freeBIO(keyBio);
                    }
                    if (cert != 0) {
                        SSL.freeX509Chain(cert);
                    }
                    if (key != 0) {
                        SSL.freePrivateKey(key);
                    }
                    SSLContext.free(sslCtx);
                    AVAILABLE_OPENSSL_CIPHER_SUITES = Collections.unmodifiableSet(availableOpenSslCipherSuites);
                    Set<String> availableJavaCipherSuites2222 = new LinkedHashSet<>(AVAILABLE_OPENSSL_CIPHER_SUITES.size() * 2);
                    for (String cipher2 : AVAILABLE_OPENSSL_CIPHER_SUITES) {
                        if (SslUtils.isTLSv13Cipher(cipher2)) {
                            availableJavaCipherSuites2222.add(cipher2);
                        } else {
                            availableJavaCipherSuites2222.add(CipherSuiteConverter.toJava(cipher2, "TLS"));
                            availableJavaCipherSuites2222.add(CipherSuiteConverter.toJava(cipher2, "SSL"));
                        }
                    }
                    SslUtils.addIfSupported(availableJavaCipherSuites2222, defaultCiphers, SslUtils.DEFAULT_CIPHER_SUITES);
                    SslUtils.addIfSupported(availableJavaCipherSuites2222, defaultCiphers, SslUtils.TLSV13_CIPHER_SUITES);
                    SslUtils.useFallbackCiphersIfDefaultIsEmpty(defaultCiphers, availableJavaCipherSuites2222);
                    DEFAULT_CIPHERS = Collections.unmodifiableList(defaultCiphers);
                    AVAILABLE_JAVA_CIPHER_SUITES = Collections.unmodifiableSet(availableJavaCipherSuites2222);
                    Set<String> availableCipherSuites2222 = new LinkedHashSet<>(AVAILABLE_OPENSSL_CIPHER_SUITES.size() + AVAILABLE_JAVA_CIPHER_SUITES.size());
                    availableCipherSuites2222.addAll(AVAILABLE_OPENSSL_CIPHER_SUITES);
                    availableCipherSuites2222.addAll(AVAILABLE_JAVA_CIPHER_SUITES);
                    AVAILABLE_CIPHER_SUITES = availableCipherSuites2222;
                    SUPPORTS_KEYMANAGER_FACTORY = supportsKeyManagerFactory;
                    USE_KEYMANAGER_FACTORY = useKeyManagerFactory2;
                    Set<String> protocols2222 = new LinkedHashSet<>(6);
                    protocols2222.add("SSLv2Hello");
                    if (doesSupportProtocol(1, SSL.SSL_OP_NO_SSLv2)) {
                        protocols2222.add("SSLv2");
                    }
                    if (doesSupportProtocol(2, SSL.SSL_OP_NO_SSLv3)) {
                        protocols2222.add("SSLv3");
                    }
                    if (doesSupportProtocol(4, SSL.SSL_OP_NO_TLSv1)) {
                        protocols2222.add("TLSv1");
                    }
                    if (doesSupportProtocol(8, SSL.SSL_OP_NO_TLSv1_1)) {
                        protocols2222.add("TLSv1.1");
                    }
                    if (doesSupportProtocol(16, SSL.SSL_OP_NO_TLSv1_2)) {
                        protocols2222.add("TLSv1.2");
                    }
                    if (tlsv13Supported2 || !doesSupportProtocol(32, SSL.SSL_OP_NO_TLSv1_3)) {
                        TLSV13_SUPPORTED = false;
                    } else {
                        protocols2222.add("TLSv1.3");
                        TLSV13_SUPPORTED = true;
                    }
                    SUPPORTED_PROTOCOLS_SET = Collections.unmodifiableSet(protocols2222);
                    SUPPORTS_OCSP = doesSupportOcsp();
                    if (logger.isDebugEnabled()) {
                        logger.debug("Supported protocols (OpenSSL): {} ", SUPPORTED_PROTOCOLS_SET);
                        logger.debug("Default cipher suites (OpenSSL): {}", DEFAULT_CIPHERS);
                    }
                } catch (Throwable th15) {
                    th = th15;
                }
            } catch (Throwable th16) {
                th = th16;
                SSLContext.free(sslCtx);
                throw th;
            }
        } catch (Throwable th17) {
            th = th17;
        }
    }

    static X509Certificate selfSignedCertificate() throws CertificateException {
        return (X509Certificate) SslContext.X509_CERT_FACTORY.generateCertificate(new ByteArrayInputStream(CERT.getBytes(CharsetUtil.US_ASCII)));
    }

    /* JADX WARN: Code restructure failed: missing block: B:16:0x0032, code lost:
        if (r1 == (-1)) goto L19;
     */
    /* JADX WARN: Code restructure failed: missing block: B:7:0x0020, code lost:
        if (r1 != (-1)) goto L8;
     */
    /* JADX WARN: Code restructure failed: missing block: B:8:0x0022, code lost:
        io.netty.internal.tcnative.SSLContext.free(r1);
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private static boolean doesSupportOcsp() {
        boolean supportsOcsp = false;
        if (version() >= 268443648) {
            long sslCtx = -1;
            try {
                sslCtx = SSLContext.make(16, 1);
                SSLContext.enableOcsp(sslCtx, false);
                supportsOcsp = true;
            } catch (Exception e) {
            } catch (Throwable th) {
                if (sslCtx != -1) {
                    SSLContext.free(sslCtx);
                }
                throw th;
            }
        }
        return supportsOcsp;
    }

    private static boolean doesSupportProtocol(int protocol, int opt) {
        if (opt == 0) {
            return false;
        }
        try {
            long sslCtx = SSLContext.make(protocol, 2);
            if (sslCtx != -1) {
                SSLContext.free(sslCtx);
            }
            return true;
        } catch (Exception e) {
            if (-1 != -1) {
                SSLContext.free(-1L);
            }
            return false;
        } catch (Throwable th) {
            if (-1 != -1) {
                SSLContext.free(-1L);
            }
            throw th;
        }
    }

    public static boolean isAvailable() {
        return UNAVAILABILITY_CAUSE == null;
    }

    @Deprecated
    public static boolean isAlpnSupported() {
        return ((long) version()) >= 268443648;
    }

    public static boolean isOcspSupported() {
        return SUPPORTS_OCSP;
    }

    public static int version() {
        if (isAvailable()) {
            return SSL.version();
        }
        return -1;
    }

    public static String versionString() {
        if (isAvailable()) {
            return SSL.versionString();
        }
        return null;
    }

    public static void ensureAvailability() {
        if (UNAVAILABILITY_CAUSE != null) {
            throw ((Error) new UnsatisfiedLinkError("failed to load the required native library").initCause(UNAVAILABILITY_CAUSE));
        }
    }

    public static Throwable unavailabilityCause() {
        return UNAVAILABILITY_CAUSE;
    }

    @Deprecated
    public static Set<String> availableCipherSuites() {
        return availableOpenSslCipherSuites();
    }

    public static Set<String> availableOpenSslCipherSuites() {
        return AVAILABLE_OPENSSL_CIPHER_SUITES;
    }

    public static Set<String> availableJavaCipherSuites() {
        return AVAILABLE_JAVA_CIPHER_SUITES;
    }

    public static boolean isCipherSuiteAvailable(String cipherSuite) {
        String converted = CipherSuiteConverter.toOpenSsl(cipherSuite, IS_BORINGSSL);
        if (converted != null) {
            cipherSuite = converted;
        }
        return AVAILABLE_OPENSSL_CIPHER_SUITES.contains(cipherSuite);
    }

    public static boolean supportsKeyManagerFactory() {
        return SUPPORTS_KEYMANAGER_FACTORY;
    }

    @Deprecated
    public static boolean supportsHostnameValidation() {
        return isAvailable();
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static boolean useKeyManagerFactory() {
        return USE_KEYMANAGER_FACTORY;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static long memoryAddress(ByteBuf buf) {
        return buf.hasMemoryAddress() ? buf.memoryAddress() : Buffer.address(buf.nioBuffer());
    }

    private OpenSsl() {
    }

    private static void loadTcNative() throws Exception {
        String os = PlatformDependent.normalizedOs();
        String arch = PlatformDependent.normalizedArch();
        Set<String> libNames = new LinkedHashSet<>(5);
        if ("linux".equalsIgnoreCase(os)) {
            Set<String> classifiers = PlatformDependent.normalizedLinuxClassifiers();
            for (String classifier : classifiers) {
                libNames.add("netty_tcnative_" + os + '_' + arch + "_" + classifier);
            }
            libNames.add("netty_tcnative_" + os + '_' + arch);
            libNames.add("netty_tcnative_" + os + '_' + arch + "_fedora");
        } else {
            libNames.add("netty_tcnative_" + os + '_' + arch);
        }
        libNames.add("netty_tcnative_" + arch);
        libNames.add("netty_tcnative");
        NativeLibraryLoader.loadFirstAvailable(SSL.class.getClassLoader(), (String[]) libNames.toArray(new String[0]));
    }

    private static boolean initializeTcNative(String engine) throws Exception {
        return Library.initialize("provided", engine);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static void releaseIfNeeded(ReferenceCounted counted) {
        if (counted.refCnt() > 0) {
            ReferenceCountUtil.safeRelease(counted);
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static boolean isTlsv13Supported() {
        return TLSV13_SUPPORTED;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static boolean isBoringSSL() {
        return IS_BORINGSSL;
    }
}
