package io.netty.handler.ssl;

import io.netty.buffer.ByteBuf;
import io.netty.buffer.ByteBufAllocator;
import io.netty.handler.ssl.ApplicationProtocolConfig;
import io.netty.internal.tcnative.Buffer;
import io.netty.internal.tcnative.SSL;
import io.netty.util.AbstractReferenceCounted;
import io.netty.util.CharsetUtil;
import io.netty.util.ReferenceCounted;
import io.netty.util.ResourceLeakDetector;
import io.netty.util.ResourceLeakDetectorFactory;
import io.netty.util.ResourceLeakTracker;
import io.netty.util.internal.EmptyArrays;
import io.netty.util.internal.ObjectUtil;
import io.netty.util.internal.PlatformDependent;
import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.nio.ByteBuffer;
import java.nio.ReadOnlyBufferException;
import java.security.Principal;
import java.security.cert.Certificate;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.locks.Lock;
import javax.crypto.spec.SecretKeySpec;
import javax.net.ssl.SSLEngine;
import javax.net.ssl.SSLEngineResult;
import javax.net.ssl.SSLException;
import javax.net.ssl.SSLHandshakeException;
import javax.net.ssl.SSLParameters;
import javax.net.ssl.SSLPeerUnverifiedException;
import javax.net.ssl.SSLSession;
import javax.net.ssl.SSLSessionBindingEvent;
import javax.net.ssl.SSLSessionBindingListener;
import javax.net.ssl.SSLSessionContext;
import javax.security.cert.X509Certificate;
/* loaded from: classes.dex */
public class ReferenceCountedOpenSslEngine extends SSLEngine implements ReferenceCounted, ApplicationProtocolAccessor {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final int OPENSSL_OP_NO_PROTOCOL_INDEX_SSLV2 = 0;
    private static final int OPENSSL_OP_NO_PROTOCOL_INDEX_SSLV3 = 1;
    private static final int OPENSSL_OP_NO_PROTOCOL_INDEX_TLSv1 = 2;
    private static final int OPENSSL_OP_NO_PROTOCOL_INDEX_TLSv1_1 = 3;
    private static final int OPENSSL_OP_NO_PROTOCOL_INDEX_TLSv1_2 = 4;
    private static final int OPENSSL_OP_NO_PROTOCOL_INDEX_TLSv1_3 = 5;
    private Object algorithmConstraints;
    final ByteBufAllocator alloc;
    private final OpenSslApplicationProtocolNegotiator apn;
    private volatile String applicationProtocol;
    private volatile ClientAuth clientAuth;
    private final boolean clientMode;
    private volatile boolean destroyed;
    private final boolean enableOcsp;
    private String endPointIdentificationAlgorithm;
    private final OpenSslEngineMap engineMap;
    private Throwable handshakeException;
    private HandshakeState handshakeState;
    private boolean isInboundDone;
    final boolean jdkCompatibilityMode;
    private volatile long lastAccessed;
    private final ResourceLeakTracker<ReferenceCountedOpenSslEngine> leak;
    private volatile Certificate[] localCertificateChain;
    private volatile Collection<?> matchers;
    private int maxWrapBufferSize;
    private int maxWrapOverhead;
    private volatile boolean needTask;
    private long networkBIO;
    private boolean outboundClosed;
    private final ReferenceCountedOpenSslContext parentContext;
    private boolean receivedShutdown;
    private final AbstractReferenceCounted refCnt;
    private final OpenSslSession session;
    private final ByteBuffer[] singleDstBuffer;
    private final ByteBuffer[] singleSrcBuffer;
    private List<String> sniHostNames;
    private long ssl;
    private static final InternalLogger logger = InternalLoggerFactory.getInstance(ReferenceCountedOpenSslEngine.class);
    private static final ResourceLeakDetector<ReferenceCountedOpenSslEngine> leakDetector = ResourceLeakDetectorFactory.instance().newResourceLeakDetector(ReferenceCountedOpenSslEngine.class);
    private static final int[] OPENSSL_OP_NO_PROTOCOLS = {SSL.SSL_OP_NO_SSLv2, SSL.SSL_OP_NO_SSLv3, SSL.SSL_OP_NO_TLSv1, SSL.SSL_OP_NO_TLSv1_1, SSL.SSL_OP_NO_TLSv1_2, SSL.SSL_OP_NO_TLSv1_3};
    static final int MAX_PLAINTEXT_LENGTH = SSL.SSL_MAX_PLAINTEXT_LENGTH;
    private static final int MAX_RECORD_SIZE = SSL.SSL_MAX_RECORD_LENGTH;
    private static final SSLEngineResult NEED_UNWRAP_OK = new SSLEngineResult(SSLEngineResult.Status.OK, SSLEngineResult.HandshakeStatus.NEED_UNWRAP, 0, 0);
    private static final SSLEngineResult NEED_UNWRAP_CLOSED = new SSLEngineResult(SSLEngineResult.Status.CLOSED, SSLEngineResult.HandshakeStatus.NEED_UNWRAP, 0, 0);
    private static final SSLEngineResult NEED_WRAP_OK = new SSLEngineResult(SSLEngineResult.Status.OK, SSLEngineResult.HandshakeStatus.NEED_WRAP, 0, 0);
    private static final SSLEngineResult NEED_WRAP_CLOSED = new SSLEngineResult(SSLEngineResult.Status.CLOSED, SSLEngineResult.HandshakeStatus.NEED_WRAP, 0, 0);
    private static final SSLEngineResult CLOSED_NOT_HANDSHAKING = new SSLEngineResult(SSLEngineResult.Status.CLOSED, SSLEngineResult.HandshakeStatus.NOT_HANDSHAKING, 0, 0);

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public enum HandshakeState {
        NOT_STARTED,
        STARTED_IMPLICITLY,
        STARTED_EXPLICITLY,
        FINISHED
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public ReferenceCountedOpenSslEngine(ReferenceCountedOpenSslContext context, ByteBufAllocator alloc, String peerHost, int peerPort, boolean jdkCompatibilityMode, boolean leakDetection) {
        super(peerHost, peerPort);
        this.handshakeState = HandshakeState.NOT_STARTED;
        this.refCnt = new AbstractReferenceCounted() { // from class: io.netty.handler.ssl.ReferenceCountedOpenSslEngine.1
            static final /* synthetic */ boolean $assertionsDisabled = false;

            @Override // io.netty.util.ReferenceCounted
            public ReferenceCounted touch(Object hint) {
                if (ReferenceCountedOpenSslEngine.this.leak != null) {
                    ReferenceCountedOpenSslEngine.this.leak.record(hint);
                }
                return ReferenceCountedOpenSslEngine.this;
            }

            @Override // io.netty.util.AbstractReferenceCounted
            protected void deallocate() {
                ReferenceCountedOpenSslEngine.this.shutdown();
                if (ReferenceCountedOpenSslEngine.this.leak != null) {
                    ReferenceCountedOpenSslEngine.this.leak.close(ReferenceCountedOpenSslEngine.this);
                }
                ReferenceCountedOpenSslEngine.this.parentContext.release();
            }
        };
        this.clientAuth = ClientAuth.NONE;
        this.lastAccessed = -1L;
        boolean z = true;
        this.singleSrcBuffer = new ByteBuffer[1];
        this.singleDstBuffer = new ByteBuffer[1];
        OpenSsl.ensureAvailability();
        this.alloc = (ByteBufAllocator) ObjectUtil.checkNotNull(alloc, "alloc");
        this.apn = (OpenSslApplicationProtocolNegotiator) context.applicationProtocolNegotiator();
        this.clientMode = context.isClient();
        if (PlatformDependent.javaVersion() >= 7) {
            this.session = new ExtendedOpenSslSession(new DefaultOpenSslSession(context.sessionContext())) { // from class: io.netty.handler.ssl.ReferenceCountedOpenSslEngine.2
                private String[] peerSupportedSignatureAlgorithms;
                private List requestedServerNames;

                @Override // io.netty.handler.ssl.ExtendedOpenSslSession, javax.net.ssl.ExtendedSSLSession
                public List getRequestedServerNames() {
                    List list;
                    if (ReferenceCountedOpenSslEngine.this.clientMode) {
                        return Java8SslUtils.getSniHostNames(ReferenceCountedOpenSslEngine.this.sniHostNames);
                    }
                    synchronized (ReferenceCountedOpenSslEngine.this) {
                        if (this.requestedServerNames == null) {
                            if (!ReferenceCountedOpenSslEngine.this.isDestroyed()) {
                                String name = SSL.getSniHostname(ReferenceCountedOpenSslEngine.this.ssl);
                                if (name == null) {
                                    this.requestedServerNames = Collections.emptyList();
                                } else {
                                    this.requestedServerNames = Java8SslUtils.getSniHostName(SSL.getSniHostname(ReferenceCountedOpenSslEngine.this.ssl).getBytes(CharsetUtil.UTF_8));
                                }
                            } else {
                                this.requestedServerNames = Collections.emptyList();
                            }
                        }
                        list = this.requestedServerNames;
                    }
                    return list;
                }

                @Override // javax.net.ssl.ExtendedSSLSession
                public String[] getPeerSupportedSignatureAlgorithms() {
                    String[] strArr;
                    synchronized (ReferenceCountedOpenSslEngine.this) {
                        if (this.peerSupportedSignatureAlgorithms == null) {
                            if (!ReferenceCountedOpenSslEngine.this.isDestroyed()) {
                                String[] algs = SSL.getSigAlgs(ReferenceCountedOpenSslEngine.this.ssl);
                                if (algs == null) {
                                    this.peerSupportedSignatureAlgorithms = EmptyArrays.EMPTY_STRINGS;
                                } else {
                                    Set<String> algorithmList = new LinkedHashSet<>(algs.length);
                                    for (String alg : algs) {
                                        String converted = SignatureAlgorithmConverter.toJavaName(alg);
                                        if (converted != null) {
                                            algorithmList.add(converted);
                                        }
                                    }
                                    this.peerSupportedSignatureAlgorithms = (String[]) algorithmList.toArray(new String[0]);
                                }
                            } else {
                                this.peerSupportedSignatureAlgorithms = EmptyArrays.EMPTY_STRINGS;
                            }
                        }
                        strArr = (String[]) this.peerSupportedSignatureAlgorithms.clone();
                    }
                    return strArr;
                }

                @Override // io.netty.handler.ssl.ExtendedOpenSslSession
                public List<byte[]> getStatusResponses() {
                    byte[] ocspResponse = null;
                    if (ReferenceCountedOpenSslEngine.this.enableOcsp && ReferenceCountedOpenSslEngine.this.clientMode) {
                        synchronized (ReferenceCountedOpenSslEngine.this) {
                            if (!ReferenceCountedOpenSslEngine.this.isDestroyed()) {
                                ocspResponse = SSL.getOcspResponse(ReferenceCountedOpenSslEngine.this.ssl);
                            }
                        }
                    }
                    return ocspResponse == null ? Collections.emptyList() : Collections.singletonList(ocspResponse);
                }
            };
        } else {
            this.session = new DefaultOpenSslSession(context.sessionContext());
        }
        this.engineMap = context.engineMap;
        this.enableOcsp = context.enableOcsp;
        this.localCertificateChain = context.keyCertChain;
        this.jdkCompatibilityMode = jdkCompatibilityMode;
        Lock readerLock = context.ctxLock.readLock();
        readerLock.lock();
        try {
            long j = context.ctx;
            if (context.isClient()) {
                z = false;
            }
            long finalSsl = SSL.newSSL(j, z);
            synchronized (this) {
                this.ssl = finalSsl;
                this.networkBIO = SSL.bioNewByteBuffer(finalSsl, context.getBioNonApplicationBufferSize());
                setClientAuth(this.clientMode ? ClientAuth.NONE : context.clientAuth);
                if (context.protocols != null) {
                    setEnabledProtocols(context.protocols);
                }
                if (this.clientMode && SslUtils.isValidHostNameForSNI(peerHost)) {
                    SSL.setTlsExtHostName(this.ssl, peerHost);
                    this.sniHostNames = Collections.singletonList(peerHost);
                }
                if (this.enableOcsp) {
                    SSL.enableOcsp(this.ssl);
                }
                if (!jdkCompatibilityMode) {
                    SSL.setMode(this.ssl, SSL.getMode(this.ssl) | SSL.SSL_MODE_ENABLE_PARTIAL_WRITE);
                }
                calculateMaxWrapOverhead();
            }
            this.parentContext = context;
            context.retain();
            this.leak = leakDetection ? leakDetector.track(this) : null;
        } finally {
            readerLock.unlock();
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final synchronized String[] authMethods() {
        if (isDestroyed()) {
            return EmptyArrays.EMPTY_STRINGS;
        }
        return SSL.authenticationMethods(this.ssl);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final boolean setKeyMaterial(OpenSslKeyMaterial keyMaterial) throws Exception {
        synchronized (this) {
            if (isDestroyed()) {
                return false;
            }
            SSL.setKeyMaterial(this.ssl, keyMaterial.certificateChainAddress(), keyMaterial.privateKeyAddress());
            this.localCertificateChain = keyMaterial.certificateChain();
            return true;
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final synchronized SecretKeySpec masterKey() {
        if (isDestroyed()) {
            return null;
        }
        return new SecretKeySpec(SSL.getMasterKey(this.ssl), "AES");
    }

    public void setOcspResponse(byte[] response) {
        if (!this.enableOcsp) {
            throw new IllegalStateException("OCSP stapling is not enabled");
        }
        if (this.clientMode) {
            throw new IllegalStateException("Not a server SSLEngine");
        }
        synchronized (this) {
            if (!isDestroyed()) {
                SSL.setOcspResponse(this.ssl, response);
            }
        }
    }

    public byte[] getOcspResponse() {
        if (!this.enableOcsp) {
            throw new IllegalStateException("OCSP stapling is not enabled");
        }
        if (!this.clientMode) {
            throw new IllegalStateException("Not a client SSLEngine");
        }
        synchronized (this) {
            if (isDestroyed()) {
                return EmptyArrays.EMPTY_BYTES;
            }
            return SSL.getOcspResponse(this.ssl);
        }
    }

    @Override // io.netty.util.ReferenceCounted
    public final int refCnt() {
        return this.refCnt.refCnt();
    }

    @Override // io.netty.util.ReferenceCounted
    public final ReferenceCounted retain() {
        this.refCnt.retain();
        return this;
    }

    @Override // io.netty.util.ReferenceCounted
    public final ReferenceCounted retain(int increment) {
        this.refCnt.retain(increment);
        return this;
    }

    @Override // io.netty.util.ReferenceCounted
    public final ReferenceCounted touch() {
        this.refCnt.touch();
        return this;
    }

    @Override // io.netty.util.ReferenceCounted
    public final ReferenceCounted touch(Object hint) {
        this.refCnt.touch(hint);
        return this;
    }

    @Override // io.netty.util.ReferenceCounted
    public final boolean release() {
        return this.refCnt.release();
    }

    @Override // io.netty.util.ReferenceCounted
    public final boolean release(int decrement) {
        return this.refCnt.release(decrement);
    }

    @Override // javax.net.ssl.SSLEngine
    public final synchronized SSLSession getHandshakeSession() {
        int i = AnonymousClass4.$SwitchMap$io$netty$handler$ssl$ReferenceCountedOpenSslEngine$HandshakeState[this.handshakeState.ordinal()];
        if (i == 1 || i == 2) {
            return null;
        }
        return this.session;
    }

    public final synchronized long sslPointer() {
        return this.ssl;
    }

    public final synchronized void shutdown() {
        if (!this.destroyed) {
            this.destroyed = true;
            this.engineMap.remove(this.ssl);
            SSL.freeSSL(this.ssl);
            this.networkBIO = 0L;
            this.ssl = 0L;
            this.outboundClosed = true;
            this.isInboundDone = true;
        }
        SSL.clearError();
    }

    private int writePlaintextData(ByteBuffer src, int len) {
        int pos = src.position();
        int limit = src.limit();
        if (src.isDirect()) {
            int sslWrote = SSL.writeToSSL(this.ssl, bufferAddress(src) + pos, len);
            if (sslWrote > 0) {
                src.position(pos + sslWrote);
                return sslWrote;
            }
            return sslWrote;
        }
        ByteBuf buf = this.alloc.directBuffer(len);
        try {
            src.limit(pos + len);
            buf.setBytes(0, src);
            src.limit(limit);
            int sslWrote2 = SSL.writeToSSL(this.ssl, OpenSsl.memoryAddress(buf), len);
            if (sslWrote2 > 0) {
                src.position(pos + sslWrote2);
            } else {
                src.position(pos);
            }
            return sslWrote2;
        } finally {
            buf.release();
        }
    }

    private ByteBuf writeEncryptedData(ByteBuffer src, int len) {
        int pos = src.position();
        if (src.isDirect()) {
            SSL.bioSetByteBuffer(this.networkBIO, bufferAddress(src) + pos, len, false);
            return null;
        }
        ByteBuf buf = this.alloc.directBuffer(len);
        try {
            int limit = src.limit();
            src.limit(pos + len);
            buf.writeBytes(src);
            src.position(pos);
            src.limit(limit);
            SSL.bioSetByteBuffer(this.networkBIO, OpenSsl.memoryAddress(buf), len, false);
            return buf;
        } catch (Throwable cause) {
            buf.release();
            PlatformDependent.throwException(cause);
            return null;
        }
    }

    private int readPlaintextData(ByteBuffer dst) {
        int pos = dst.position();
        if (dst.isDirect()) {
            int sslRead = SSL.readFromSSL(this.ssl, bufferAddress(dst) + pos, dst.limit() - pos);
            if (sslRead > 0) {
                dst.position(pos + sslRead);
                return sslRead;
            }
            return sslRead;
        }
        int limit = dst.limit();
        int len = Math.min(maxEncryptedPacketLength0(), limit - pos);
        ByteBuf buf = this.alloc.directBuffer(len);
        try {
            int sslRead2 = SSL.readFromSSL(this.ssl, OpenSsl.memoryAddress(buf), len);
            if (sslRead2 > 0) {
                dst.limit(pos + sslRead2);
                buf.getBytes(buf.readerIndex(), dst);
                dst.limit(limit);
            }
            return sslRead2;
        } finally {
            buf.release();
        }
    }

    final synchronized int maxWrapOverhead() {
        return this.maxWrapOverhead;
    }

    final synchronized int maxEncryptedPacketLength() {
        return maxEncryptedPacketLength0();
    }

    final int maxEncryptedPacketLength0() {
        return this.maxWrapOverhead + MAX_PLAINTEXT_LENGTH;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final int calculateMaxLengthForWrap(int plaintextLength, int numComponents) {
        return (int) Math.min(this.maxWrapBufferSize, plaintextLength + (this.maxWrapOverhead * numComponents));
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final synchronized int sslPending() {
        return sslPending0();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void calculateMaxWrapOverhead() {
        this.maxWrapOverhead = SSL.getMaxWrapOverhead(this.ssl);
        this.maxWrapBufferSize = this.jdkCompatibilityMode ? maxEncryptedPacketLength0() : maxEncryptedPacketLength0() << 4;
    }

    private int sslPending0() {
        if (this.handshakeState != HandshakeState.FINISHED) {
            return 0;
        }
        return SSL.sslPending(this.ssl);
    }

    private boolean isBytesAvailableEnoughForWrap(int bytesAvailable, int plaintextLength, int numComponents) {
        return ((long) bytesAvailable) - (((long) this.maxWrapOverhead) * ((long) numComponents)) >= ((long) plaintextLength);
    }

    /* JADX WARN: Removed duplicated region for block: B:287:0x0519 A[Catch: all -> 0x0535, TryCatch #4 {all -> 0x0535, blocks: (B:285:0x0511, B:287:0x0519, B:290:0x0531, B:288:0x0528, B:292:0x0533), top: B:310:0x001d }] */
    /* JADX WARN: Removed duplicated region for block: B:288:0x0528 A[Catch: all -> 0x0535, TryCatch #4 {all -> 0x0535, blocks: (B:285:0x0511, B:287:0x0519, B:290:0x0531, B:288:0x0528, B:292:0x0533), top: B:310:0x001d }] */
    @Override // javax.net.ssl.SSLEngine
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public final SSLEngineResult wrap(ByteBuffer[] srcs, int offset, int length, ByteBuffer dst) throws SSLException {
        int availableCapacityForWrap;
        int endOffset;
        int endOffset2;
        SSLEngineResult sSLEngineResult;
        ByteBuffer[] byteBufferArr = srcs;
        int offset2 = offset;
        if (byteBufferArr == null) {
            throw new IllegalArgumentException("srcs is null");
        }
        if (dst == null) {
            throw new IllegalArgumentException("dst is null");
        }
        if (offset2 >= byteBufferArr.length || offset2 + length > byteBufferArr.length) {
            throw new IndexOutOfBoundsException("offset: " + offset2 + ", length: " + length + " (expected: offset <= offset + length <= srcs.length (" + srcs.length + "))");
        } else if (dst.isReadOnly()) {
            throw new ReadOnlyBufferException();
        } else {
            synchronized (this) {
                try {
                    try {
                        if (isOutboundDone()) {
                            if (!isInboundDone() && !isDestroyed()) {
                                sSLEngineResult = NEED_UNWRAP_CLOSED;
                                return sSLEngineResult;
                            }
                            sSLEngineResult = CLOSED_NOT_HANDSHAKING;
                            return sSLEngineResult;
                        }
                        int bytesProduced = 0;
                        ByteBuf bioReadCopyBuf = null;
                        try {
                            if (dst.isDirect()) {
                                SSL.bioSetByteBuffer(this.networkBIO, bufferAddress(dst) + dst.position(), dst.remaining(), true);
                            } else {
                                bioReadCopyBuf = this.alloc.directBuffer(dst.remaining());
                                SSL.bioSetByteBuffer(this.networkBIO, OpenSsl.memoryAddress(bioReadCopyBuf), bioReadCopyBuf.writableBytes(), true);
                            }
                            int bioLengthBefore = SSL.bioLengthByteBuffer(this.networkBIO);
                            if (this.outboundClosed) {
                                if (!isBytesAvailableEnoughForWrap(dst.remaining(), 2, 1)) {
                                    SSLEngineResult sSLEngineResult2 = new SSLEngineResult(SSLEngineResult.Status.BUFFER_OVERFLOW, getHandshakeStatus(), 0, 0);
                                    SSL.bioClearByteBuffer(this.networkBIO);
                                    if (bioReadCopyBuf == null) {
                                        dst.position(dst.position() + 0);
                                    } else {
                                        dst.put(bioReadCopyBuf.internalNioBuffer(bioReadCopyBuf.readerIndex(), 0));
                                        bioReadCopyBuf.release();
                                    }
                                    return sSLEngineResult2;
                                }
                                int bytesProduced2 = SSL.bioFlushByteBuffer(this.networkBIO);
                                if (bytesProduced2 <= 0) {
                                    SSLEngineResult newResultMayFinishHandshake = newResultMayFinishHandshake(SSLEngineResult.HandshakeStatus.NOT_HANDSHAKING, 0, 0);
                                    SSL.bioClearByteBuffer(this.networkBIO);
                                    if (bioReadCopyBuf == null) {
                                        dst.position(dst.position() + bytesProduced2);
                                    } else {
                                        dst.put(bioReadCopyBuf.internalNioBuffer(bioReadCopyBuf.readerIndex(), bytesProduced2));
                                        bioReadCopyBuf.release();
                                    }
                                    return newResultMayFinishHandshake;
                                } else if (!doSSLShutdown()) {
                                    SSLEngineResult newResultMayFinishHandshake2 = newResultMayFinishHandshake(SSLEngineResult.HandshakeStatus.NOT_HANDSHAKING, 0, bytesProduced2);
                                    SSL.bioClearByteBuffer(this.networkBIO);
                                    if (bioReadCopyBuf == null) {
                                        dst.position(dst.position() + bytesProduced2);
                                    } else {
                                        dst.put(bioReadCopyBuf.internalNioBuffer(bioReadCopyBuf.readerIndex(), bytesProduced2));
                                        bioReadCopyBuf.release();
                                    }
                                    return newResultMayFinishHandshake2;
                                } else {
                                    int bytesProduced3 = bioLengthBefore - SSL.bioLengthByteBuffer(this.networkBIO);
                                    SSLEngineResult newResultMayFinishHandshake3 = newResultMayFinishHandshake(SSLEngineResult.HandshakeStatus.NEED_WRAP, 0, bytesProduced3);
                                    SSL.bioClearByteBuffer(this.networkBIO);
                                    if (bioReadCopyBuf == null) {
                                        dst.position(dst.position() + bytesProduced3);
                                    } else {
                                        dst.put(bioReadCopyBuf.internalNioBuffer(bioReadCopyBuf.readerIndex(), bytesProduced3));
                                        bioReadCopyBuf.release();
                                    }
                                    return newResultMayFinishHandshake3;
                                }
                            }
                            SSLEngineResult.HandshakeStatus status = SSLEngineResult.HandshakeStatus.NOT_HANDSHAKING;
                            if (this.handshakeState != HandshakeState.FINISHED) {
                                if (this.handshakeState != HandshakeState.STARTED_EXPLICITLY) {
                                    this.handshakeState = HandshakeState.STARTED_IMPLICITLY;
                                }
                                int bytesProduced4 = SSL.bioFlushByteBuffer(this.networkBIO);
                                if (this.handshakeException != null) {
                                    if (bytesProduced4 > 0) {
                                        SSLEngineResult newResult = newResult(SSLEngineResult.HandshakeStatus.NEED_WRAP, 0, bytesProduced4);
                                        SSL.bioClearByteBuffer(this.networkBIO);
                                        if (bioReadCopyBuf == null) {
                                            dst.position(dst.position() + bytesProduced4);
                                        } else {
                                            dst.put(bioReadCopyBuf.internalNioBuffer(bioReadCopyBuf.readerIndex(), bytesProduced4));
                                            bioReadCopyBuf.release();
                                        }
                                        return newResult;
                                    }
                                    SSLEngineResult newResult2 = newResult(handshakeException(), 0, 0);
                                    SSL.bioClearByteBuffer(this.networkBIO);
                                    if (bioReadCopyBuf == null) {
                                        dst.position(dst.position() + bytesProduced4);
                                    } else {
                                        dst.put(bioReadCopyBuf.internalNioBuffer(bioReadCopyBuf.readerIndex(), bytesProduced4));
                                        bioReadCopyBuf.release();
                                    }
                                    return newResult2;
                                }
                                status = handshake();
                                bytesProduced = bioLengthBefore - SSL.bioLengthByteBuffer(this.networkBIO);
                                if (status == SSLEngineResult.HandshakeStatus.NEED_TASK) {
                                    SSLEngineResult newResult3 = newResult(status, 0, bytesProduced);
                                    SSL.bioClearByteBuffer(this.networkBIO);
                                    if (bioReadCopyBuf == null) {
                                        dst.position(dst.position() + bytesProduced);
                                    } else {
                                        dst.put(bioReadCopyBuf.internalNioBuffer(bioReadCopyBuf.readerIndex(), bytesProduced));
                                        bioReadCopyBuf.release();
                                    }
                                    return newResult3;
                                } else if (bytesProduced > 0) {
                                    SSLEngineResult newResult4 = newResult(mayFinishHandshake(status != SSLEngineResult.HandshakeStatus.FINISHED ? bytesProduced == bioLengthBefore ? SSLEngineResult.HandshakeStatus.NEED_WRAP : getHandshakeStatus(SSL.bioLengthNonApplication(this.networkBIO)) : SSLEngineResult.HandshakeStatus.FINISHED), 0, bytesProduced);
                                    SSL.bioClearByteBuffer(this.networkBIO);
                                    if (bioReadCopyBuf == null) {
                                        dst.position(dst.position() + bytesProduced);
                                    } else {
                                        dst.put(bioReadCopyBuf.internalNioBuffer(bioReadCopyBuf.readerIndex(), bytesProduced));
                                        bioReadCopyBuf.release();
                                    }
                                    return newResult4;
                                } else if (status == SSLEngineResult.HandshakeStatus.NEED_UNWRAP) {
                                    SSLEngineResult sSLEngineResult3 = isOutboundDone() ? NEED_UNWRAP_CLOSED : NEED_UNWRAP_OK;
                                    SSL.bioClearByteBuffer(this.networkBIO);
                                    if (bioReadCopyBuf == null) {
                                        dst.position(dst.position() + bytesProduced);
                                    } else {
                                        dst.put(bioReadCopyBuf.internalNioBuffer(bioReadCopyBuf.readerIndex(), bytesProduced));
                                        bioReadCopyBuf.release();
                                    }
                                    return sSLEngineResult3;
                                } else if (this.outboundClosed) {
                                    int bytesProduced5 = SSL.bioFlushByteBuffer(this.networkBIO);
                                    SSLEngineResult newResultMayFinishHandshake4 = newResultMayFinishHandshake(status, 0, bytesProduced5);
                                    SSL.bioClearByteBuffer(this.networkBIO);
                                    if (bioReadCopyBuf == null) {
                                        dst.position(dst.position() + bytesProduced5);
                                    } else {
                                        dst.put(bioReadCopyBuf.internalNioBuffer(bioReadCopyBuf.readerIndex(), bytesProduced5));
                                        bioReadCopyBuf.release();
                                    }
                                    return newResultMayFinishHandshake4;
                                }
                            }
                            int offset3 = offset2 + length;
                            if (this.jdkCompatibilityMode) {
                                int srcsLen = 0;
                                for (int i = offset; i < offset3; i++) {
                                    ByteBuffer src = byteBufferArr[i];
                                    if (src == null) {
                                        throw new IllegalArgumentException("srcs[" + i + "] is null");
                                    }
                                    int offset4 = MAX_PLAINTEXT_LENGTH;
                                    if (srcsLen != offset4 && ((srcsLen = srcsLen + src.remaining()) > (offset4 = MAX_PLAINTEXT_LENGTH) || srcsLen < 0)) {
                                        offset4 = MAX_PLAINTEXT_LENGTH;
                                        srcsLen = offset4;
                                    }
                                }
                                int i2 = dst.remaining();
                                if (!isBytesAvailableEnoughForWrap(i2, srcsLen, 1)) {
                                    SSLEngineResult sSLEngineResult4 = new SSLEngineResult(SSLEngineResult.Status.BUFFER_OVERFLOW, getHandshakeStatus(), 0, 0);
                                    SSL.bioClearByteBuffer(this.networkBIO);
                                    if (bioReadCopyBuf == null) {
                                        dst.position(dst.position() + bytesProduced);
                                    } else {
                                        dst.put(bioReadCopyBuf.internalNioBuffer(bioReadCopyBuf.readerIndex(), bytesProduced));
                                        bioReadCopyBuf.release();
                                    }
                                    return sSLEngineResult4;
                                }
                            }
                            int bytesConsumed = 0;
                            bytesProduced = SSL.bioFlushByteBuffer(this.networkBIO);
                            while (offset2 < offset3) {
                                try {
                                    try {
                                        try {
                                            ByteBuffer src2 = byteBufferArr[offset2];
                                            int remaining = src2.remaining();
                                            if (remaining != 0) {
                                                try {
                                                    if (this.jdkCompatibilityMode) {
                                                        try {
                                                            availableCapacityForWrap = writePlaintextData(src2, Math.min(remaining, MAX_PLAINTEXT_LENGTH - bytesConsumed));
                                                            endOffset = offset3;
                                                            endOffset2 = offset2;
                                                        } catch (Throwable th) {
                                                            th = th;
                                                            SSL.bioClearByteBuffer(this.networkBIO);
                                                            if (bioReadCopyBuf == null) {
                                                            }
                                                            throw th;
                                                        }
                                                    } else {
                                                        int availableCapacityForWrap2 = (dst.remaining() - bytesProduced) - this.maxWrapOverhead;
                                                        if (availableCapacityForWrap2 <= 0) {
                                                            try {
                                                                SSLEngineResult sSLEngineResult5 = new SSLEngineResult(SSLEngineResult.Status.BUFFER_OVERFLOW, getHandshakeStatus(), bytesConsumed, bytesProduced);
                                                                SSL.bioClearByteBuffer(this.networkBIO);
                                                                if (bioReadCopyBuf == null) {
                                                                    dst.position(dst.position() + bytesProduced);
                                                                } else {
                                                                    dst.put(bioReadCopyBuf.internalNioBuffer(bioReadCopyBuf.readerIndex(), bytesProduced));
                                                                    bioReadCopyBuf.release();
                                                                }
                                                                return sSLEngineResult5;
                                                            } catch (Throwable th2) {
                                                                th = th2;
                                                                SSL.bioClearByteBuffer(this.networkBIO);
                                                                if (bioReadCopyBuf == null) {
                                                                    dst.put(bioReadCopyBuf.internalNioBuffer(bioReadCopyBuf.readerIndex(), bytesProduced));
                                                                    bioReadCopyBuf.release();
                                                                } else {
                                                                    dst.position(dst.position() + bytesProduced);
                                                                }
                                                                throw th;
                                                            }
                                                        }
                                                        endOffset = offset3;
                                                        endOffset2 = offset2;
                                                        try {
                                                            availableCapacityForWrap = writePlaintextData(src2, Math.min(remaining, availableCapacityForWrap2));
                                                        } catch (Throwable th3) {
                                                            th = th3;
                                                            SSL.bioClearByteBuffer(this.networkBIO);
                                                            if (bioReadCopyBuf == null) {
                                                            }
                                                            throw th;
                                                        }
                                                    }
                                                    if (availableCapacityForWrap > 0) {
                                                        bytesConsumed += availableCapacityForWrap;
                                                        int pendingNow = SSL.bioLengthByteBuffer(this.networkBIO);
                                                        bytesProduced += bioLengthBefore - pendingNow;
                                                        bioLengthBefore = pendingNow;
                                                        if (!this.jdkCompatibilityMode) {
                                                            if (bytesProduced == dst.remaining()) {
                                                            }
                                                        }
                                                        SSLEngineResult newResultMayFinishHandshake5 = newResultMayFinishHandshake(status, bytesConsumed, bytesProduced);
                                                        SSL.bioClearByteBuffer(this.networkBIO);
                                                        if (bioReadCopyBuf == null) {
                                                            dst.position(dst.position() + bytesProduced);
                                                        } else {
                                                            dst.put(bioReadCopyBuf.internalNioBuffer(bioReadCopyBuf.readerIndex(), bytesProduced));
                                                            bioReadCopyBuf.release();
                                                        }
                                                        return newResultMayFinishHandshake5;
                                                    }
                                                    int sslError = SSL.getError(this.ssl, availableCapacityForWrap);
                                                    if (sslError == SSL.SSL_ERROR_ZERO_RETURN) {
                                                        if (this.receivedShutdown) {
                                                            SSLEngineResult newResult5 = newResult(SSLEngineResult.HandshakeStatus.NOT_HANDSHAKING, bytesConsumed, bytesProduced);
                                                            SSL.bioClearByteBuffer(this.networkBIO);
                                                            if (bioReadCopyBuf == null) {
                                                                dst.position(dst.position() + bytesProduced);
                                                            } else {
                                                                dst.put(bioReadCopyBuf.internalNioBuffer(bioReadCopyBuf.readerIndex(), bytesProduced));
                                                                bioReadCopyBuf.release();
                                                            }
                                                            return newResult5;
                                                        }
                                                        closeAll();
                                                        bytesProduced += bioLengthBefore - SSL.bioLengthByteBuffer(this.networkBIO);
                                                        SSLEngineResult.HandshakeStatus hs = mayFinishHandshake(status != SSLEngineResult.HandshakeStatus.FINISHED ? bytesProduced == dst.remaining() ? SSLEngineResult.HandshakeStatus.NEED_WRAP : getHandshakeStatus(SSL.bioLengthNonApplication(this.networkBIO)) : SSLEngineResult.HandshakeStatus.FINISHED);
                                                        SSLEngineResult newResult6 = newResult(hs, bytesConsumed, bytesProduced);
                                                        SSL.bioClearByteBuffer(this.networkBIO);
                                                        if (bioReadCopyBuf == null) {
                                                            dst.position(dst.position() + bytesProduced);
                                                        } else {
                                                            dst.put(bioReadCopyBuf.internalNioBuffer(bioReadCopyBuf.readerIndex(), bytesProduced));
                                                            bioReadCopyBuf.release();
                                                        }
                                                        return newResult6;
                                                    } else if (sslError == SSL.SSL_ERROR_WANT_READ) {
                                                        SSLEngineResult newResult7 = newResult(SSLEngineResult.HandshakeStatus.NEED_UNWRAP, bytesConsumed, bytesProduced);
                                                        SSL.bioClearByteBuffer(this.networkBIO);
                                                        if (bioReadCopyBuf == null) {
                                                            dst.position(dst.position() + bytesProduced);
                                                        } else {
                                                            dst.put(bioReadCopyBuf.internalNioBuffer(bioReadCopyBuf.readerIndex(), bytesProduced));
                                                            bioReadCopyBuf.release();
                                                        }
                                                        return newResult7;
                                                    } else if (sslError == SSL.SSL_ERROR_WANT_WRITE) {
                                                        SSLEngineResult newResult8 = newResult(SSLEngineResult.Status.BUFFER_OVERFLOW, status, bytesConsumed, bytesProduced);
                                                        SSL.bioClearByteBuffer(this.networkBIO);
                                                        if (bioReadCopyBuf == null) {
                                                            dst.position(dst.position() + bytesProduced);
                                                        } else {
                                                            dst.put(bioReadCopyBuf.internalNioBuffer(bioReadCopyBuf.readerIndex(), bytesProduced));
                                                            bioReadCopyBuf.release();
                                                        }
                                                        return newResult8;
                                                    } else {
                                                        if (sslError != SSL.SSL_ERROR_WANT_X509_LOOKUP && sslError != SSL.SSL_ERROR_WANT_CERTIFICATE_VERIFY && sslError != SSL.SSL_ERROR_WANT_PRIVATE_KEY_OPERATION) {
                                                            throw shutdownWithError("SSL_write", sslError);
                                                        }
                                                        SSLEngineResult newResult9 = newResult(SSLEngineResult.HandshakeStatus.NEED_TASK, bytesConsumed, bytesProduced);
                                                        SSL.bioClearByteBuffer(this.networkBIO);
                                                        if (bioReadCopyBuf == null) {
                                                            dst.position(dst.position() + bytesProduced);
                                                        } else {
                                                            dst.put(bioReadCopyBuf.internalNioBuffer(bioReadCopyBuf.readerIndex(), bytesProduced));
                                                            bioReadCopyBuf.release();
                                                        }
                                                        return newResult9;
                                                    }
                                                } catch (Throwable th4) {
                                                    th = th4;
                                                    throw th;
                                                }
                                            }
                                            endOffset = offset3;
                                            endOffset2 = offset2;
                                            try {
                                                offset2 = endOffset2 + 1;
                                                byteBufferArr = srcs;
                                                offset3 = endOffset;
                                            } catch (Throwable th5) {
                                                th = th5;
                                                SSL.bioClearByteBuffer(this.networkBIO);
                                                if (bioReadCopyBuf == null) {
                                                }
                                                throw th;
                                            }
                                        } catch (Throwable th6) {
                                            th = th6;
                                        }
                                    } catch (Throwable th7) {
                                        th = th7;
                                    }
                                } catch (Throwable th8) {
                                    th = th8;
                                }
                            }
                            SSLEngineResult newResultMayFinishHandshake6 = newResultMayFinishHandshake(status, bytesConsumed, bytesProduced);
                            SSL.bioClearByteBuffer(this.networkBIO);
                            if (bioReadCopyBuf == null) {
                                dst.position(dst.position() + bytesProduced);
                            } else {
                                dst.put(bioReadCopyBuf.internalNioBuffer(bioReadCopyBuf.readerIndex(), bytesProduced));
                                bioReadCopyBuf.release();
                            }
                            return newResultMayFinishHandshake6;
                        } catch (Throwable th9) {
                            th = th9;
                        }
                    } catch (Throwable th10) {
                        th = th10;
                    }
                } catch (Throwable th11) {
                    th = th11;
                }
            }
        }
    }

    private SSLEngineResult newResult(SSLEngineResult.HandshakeStatus hs, int bytesConsumed, int bytesProduced) {
        return newResult(SSLEngineResult.Status.OK, hs, bytesConsumed, bytesProduced);
    }

    private SSLEngineResult newResult(SSLEngineResult.Status status, SSLEngineResult.HandshakeStatus hs, int bytesConsumed, int bytesProduced) {
        if (isOutboundDone()) {
            if (isInboundDone()) {
                hs = SSLEngineResult.HandshakeStatus.NOT_HANDSHAKING;
                shutdown();
            }
            return new SSLEngineResult(SSLEngineResult.Status.CLOSED, hs, bytesConsumed, bytesProduced);
        }
        if (hs == SSLEngineResult.HandshakeStatus.NEED_TASK) {
            this.needTask = true;
        }
        return new SSLEngineResult(status, hs, bytesConsumed, bytesProduced);
    }

    private SSLEngineResult newResultMayFinishHandshake(SSLEngineResult.HandshakeStatus hs, int bytesConsumed, int bytesProduced) throws SSLException {
        return newResult(mayFinishHandshake(hs != SSLEngineResult.HandshakeStatus.FINISHED ? getHandshakeStatus() : SSLEngineResult.HandshakeStatus.FINISHED), bytesConsumed, bytesProduced);
    }

    private SSLEngineResult newResultMayFinishHandshake(SSLEngineResult.Status status, SSLEngineResult.HandshakeStatus hs, int bytesConsumed, int bytesProduced) throws SSLException {
        return newResult(status, mayFinishHandshake(hs != SSLEngineResult.HandshakeStatus.FINISHED ? getHandshakeStatus() : SSLEngineResult.HandshakeStatus.FINISHED), bytesConsumed, bytesProduced);
    }

    private SSLException shutdownWithError(String operations, int sslError) {
        return shutdownWithError(operations, sslError, SSL.getLastErrorNumber());
    }

    private SSLException shutdownWithError(String operation, int sslError, int error) {
        String errorString = SSL.getErrorString(error);
        if (logger.isDebugEnabled()) {
            logger.debug("{} failed with {}: OpenSSL error: {} {}", operation, Integer.valueOf(sslError), Integer.valueOf(error), errorString);
        }
        shutdown();
        if (this.handshakeState == HandshakeState.FINISHED) {
            return new SSLException(errorString);
        }
        SSLHandshakeException exception = new SSLHandshakeException(errorString);
        Throwable th = this.handshakeException;
        if (th != null) {
            exception.initCause(th);
            this.handshakeException = null;
        }
        return exception;
    }

    /* JADX WARN: Code restructure failed: missing block: B:132:0x0200, code lost:
        if (r7 == null) goto L307;
     */
    /* JADX WARN: Code restructure failed: missing block: B:133:0x0202, code lost:
        r7.release();
     */
    /* JADX WARN: Code restructure failed: missing block: B:135:0x0206, code lost:
        r0 = th;
     */
    /* JADX WARN: Code restructure failed: missing block: B:137:0x0211, code lost:
        r14 = r15;
        r15 = r16;
     */
    /* JADX WARN: Code restructure failed: missing block: B:153:0x024d, code lost:
        if (r13 <= 0) goto L157;
     */
    /* JADX WARN: Code restructure failed: missing block: B:155:0x0251, code lost:
        r0 = newResult(javax.net.ssl.SSLEngineResult.Status.BUFFER_OVERFLOW, r4, r3, r15);
     */
    /* JADX WARN: Code restructure failed: missing block: B:161:0x0268, code lost:
        if (isInboundDone() == false) goto L164;
     */
    /* JADX WARN: Code restructure failed: missing block: B:162:0x026a, code lost:
        r0 = javax.net.ssl.SSLEngineResult.Status.CLOSED;
     */
    /* JADX WARN: Code restructure failed: missing block: B:164:0x026d, code lost:
        r0 = javax.net.ssl.SSLEngineResult.Status.OK;
     */
    /* JADX WARN: Code restructure failed: missing block: B:165:0x026f, code lost:
        r0 = newResultMayFinishHandshake(r0, r4, r3, r15);
     */
    /* JADX WARN: Code restructure failed: missing block: B:167:0x0274, code lost:
        if (r7 == null) goto L149;
     */
    /* JADX WARN: Code restructure failed: missing block: B:168:0x0276, code lost:
        r7.release();
     */
    /* JADX WARN: Code restructure failed: missing block: B:170:0x027d, code lost:
        io.netty.internal.tcnative.SSL.bioClearByteBuffer(r24.networkBIO);
        rejectRemoteInitiatedRenegotiation();
     */
    /* JADX WARN: Code restructure failed: missing block: B:172:0x0286, code lost:
        return r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:173:0x0287, code lost:
        r0 = th;
     */
    /* JADX WARN: Code restructure failed: missing block: B:175:0x028e, code lost:
        r0 = th;
     */
    /* JADX WARN: Code restructure failed: missing block: B:176:0x028f, code lost:
        r2 = r6;
        r6 = r9;
        r10 = r13;
     */
    /* JADX WARN: Code restructure failed: missing block: B:186:0x02c1, code lost:
        if (r7 == null) goto L186;
     */
    /* JADX WARN: Code restructure failed: missing block: B:187:0x02c3, code lost:
        r7.release();
     */
    /* JADX WARN: Code restructure failed: missing block: B:191:0x02d3, code lost:
        r14 = r15;
        r15 = r3;
     */
    /* JADX WARN: Code restructure failed: missing block: B:194:0x02e6, code lost:
        r12 = r10;
     */
    /* JADX WARN: Code restructure failed: missing block: B:195:0x02ed, code lost:
        r0 = io.netty.internal.tcnative.SSL.getError(r24.ssl, r21);
     */
    /* JADX WARN: Code restructure failed: missing block: B:196:0x02f5, code lost:
        if (r0 == io.netty.internal.tcnative.SSL.SSL_ERROR_WANT_READ) goto L290;
     */
    /* JADX WARN: Code restructure failed: missing block: B:198:0x02f9, code lost:
        if (r0 != io.netty.internal.tcnative.SSL.SSL_ERROR_WANT_WRITE) goto L231;
     */
    /* JADX WARN: Code restructure failed: missing block: B:199:0x02fb, code lost:
        r23 = r12;
        r10 = r13;
     */
    /* JADX WARN: Code restructure failed: missing block: B:201:0x0302, code lost:
        if (r0 != io.netty.internal.tcnative.SSL.SSL_ERROR_ZERO_RETURN) goto L258;
     */
    /* JADX WARN: Code restructure failed: missing block: B:203:0x0306, code lost:
        if (r24.receivedShutdown != false) goto L237;
     */
    /* JADX WARN: Code restructure failed: missing block: B:204:0x0308, code lost:
        closeAll();
     */
    /* JADX WARN: Code restructure failed: missing block: B:206:0x030c, code lost:
        r0 = th;
     */
    /* JADX WARN: Code restructure failed: missing block: B:207:0x030d, code lost:
        r2 = r6;
        r10 = r13;
        r6 = r9;
     */
    /* JADX WARN: Code restructure failed: missing block: B:209:0x0319, code lost:
        if (isInboundDone() == false) goto L255;
     */
    /* JADX WARN: Code restructure failed: missing block: B:210:0x031b, code lost:
        r9 = javax.net.ssl.SSLEngineResult.Status.CLOSED;
     */
    /* JADX WARN: Code restructure failed: missing block: B:212:0x031e, code lost:
        r9 = javax.net.ssl.SSLEngineResult.Status.OK;
     */
    /* JADX WARN: Code restructure failed: missing block: B:213:0x0320, code lost:
        r9 = newResultMayFinishHandshake(r9, r4, r3, r15);
     */
    /* JADX WARN: Code restructure failed: missing block: B:214:0x0324, code lost:
        if (r7 == null) goto L242;
     */
    /* JADX WARN: Code restructure failed: missing block: B:215:0x0326, code lost:
        r7.release();
     */
    /* JADX WARN: Code restructure failed: missing block: B:217:0x032a, code lost:
        r0 = th;
     */
    /* JADX WARN: Code restructure failed: missing block: B:220:0x0337, code lost:
        io.netty.internal.tcnative.SSL.bioClearByteBuffer(r24.networkBIO);
        rejectRemoteInitiatedRenegotiation();
     */
    /* JADX WARN: Code restructure failed: missing block: B:222:0x0340, code lost:
        return r9;
     */
    /* JADX WARN: Code restructure failed: missing block: B:223:0x0341, code lost:
        r0 = th;
     */
    /* JADX WARN: Code restructure failed: missing block: B:225:0x0346, code lost:
        r10 = r13;
     */
    /* JADX WARN: Code restructure failed: missing block: B:227:0x034b, code lost:
        if (r0 == io.netty.internal.tcnative.SSL.SSL_ERROR_WANT_X509_LOOKUP) goto L274;
     */
    /* JADX WARN: Code restructure failed: missing block: B:229:0x034f, code lost:
        if (r0 == io.netty.internal.tcnative.SSL.SSL_ERROR_WANT_CERTIFICATE_VERIFY) goto L274;
     */
    /* JADX WARN: Code restructure failed: missing block: B:231:0x0353, code lost:
        if (r0 != io.netty.internal.tcnative.SSL.SSL_ERROR_WANT_PRIVATE_KEY_OPERATION) goto L268;
     */
    /* JADX WARN: Code restructure failed: missing block: B:233:0x0356, code lost:
        r9 = sslReadErrorResult(r0, io.netty.internal.tcnative.SSL.getLastErrorNumber(), r3, r15);
     */
    /* JADX WARN: Code restructure failed: missing block: B:234:0x035e, code lost:
        if (r7 == null) goto L271;
     */
    /* JADX WARN: Code restructure failed: missing block: B:235:0x0360, code lost:
        r7.release();
     */
    /* JADX WARN: Code restructure failed: missing block: B:236:0x0363, code lost:
        io.netty.internal.tcnative.SSL.bioClearByteBuffer(r24.networkBIO);
        rejectRemoteInitiatedRenegotiation();
     */
    /* JADX WARN: Code restructure failed: missing block: B:238:0x036c, code lost:
        return r9;
     */
    /* JADX WARN: Code restructure failed: missing block: B:240:0x0371, code lost:
        if (isInboundDone() == false) goto L283;
     */
    /* JADX WARN: Code restructure failed: missing block: B:241:0x0373, code lost:
        r9 = javax.net.ssl.SSLEngineResult.Status.CLOSED;
     */
    /* JADX WARN: Code restructure failed: missing block: B:242:0x0376, code lost:
        r9 = javax.net.ssl.SSLEngineResult.Status.OK;
     */
    /* JADX WARN: Code restructure failed: missing block: B:243:0x0378, code lost:
        r9 = newResult(r9, javax.net.ssl.SSLEngineResult.HandshakeStatus.NEED_TASK, r3, r15);
     */
    /* JADX WARN: Code restructure failed: missing block: B:244:0x037e, code lost:
        if (r7 == null) goto L280;
     */
    /* JADX WARN: Code restructure failed: missing block: B:245:0x0380, code lost:
        r7.release();
     */
    /* JADX WARN: Code restructure failed: missing block: B:247:0x0384, code lost:
        r0 = th;
     */
    /* JADX WARN: Code restructure failed: missing block: B:249:0x038c, code lost:
        io.netty.internal.tcnative.SSL.bioClearByteBuffer(r24.networkBIO);
        rejectRemoteInitiatedRenegotiation();
     */
    /* JADX WARN: Code restructure failed: missing block: B:251:0x0395, code lost:
        return r9;
     */
    /* JADX WARN: Code restructure failed: missing block: B:252:0x0396, code lost:
        r0 = th;
     */
    /* JADX WARN: Code restructure failed: missing block: B:253:0x0397, code lost:
        r2 = r6;
        r6 = r9;
     */
    /* JADX WARN: Code restructure failed: missing block: B:254:0x039c, code lost:
        r23 = r12;
        r10 = r13;
     */
    /* JADX WARN: Code restructure failed: missing block: B:255:0x039f, code lost:
        r2 = r29 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:256:0x03a1, code lost:
        if (r2 < r11) goto L218;
     */
    /* JADX WARN: Code restructure failed: missing block: B:257:0x03a3, code lost:
        if (r7 == null) goto L230;
     */
    /* JADX WARN: Code restructure failed: missing block: B:258:0x03a5, code lost:
        r7.release();
     */
    /* JADX WARN: Code restructure failed: missing block: B:259:0x03a8, code lost:
        r14 = r15;
        r15 = r3;
     */
    /* JADX WARN: Code restructure failed: missing block: B:272:0x03dc, code lost:
        if (r7 == null) goto L219;
     */
    /* JADX WARN: Code restructure failed: missing block: B:273:0x03de, code lost:
        r7.release();
     */
    /* JADX WARN: Code restructure failed: missing block: B:275:0x03e2, code lost:
        r0 = th;
     */
    /* JADX WARN: Code restructure failed: missing block: B:277:0x03e9, code lost:
        r26 = r6;
        r7 = r10;
        r14 = r15;
        r6 = r9;
        r8 = r17;
        r12 = r19;
        r10 = r23;
        r15 = r3;
        r3 = r2;
        r2 = r25;
     */
    /* JADX WARN: Code restructure failed: missing block: B:278:0x03fb, code lost:
        r0 = th;
     */
    /* JADX WARN: Code restructure failed: missing block: B:279:0x03fc, code lost:
        r10 = r13;
        r2 = r6;
        r6 = r9;
     */
    /* JADX WARN: Removed duplicated region for block: B:329:0x043a A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public final SSLEngineResult unwrap(ByteBuffer[] srcs, int srcsOffset, int srcsLength, ByteBuffer[] dsts, int dstsOffset, int dstsLength) throws SSLException {
        SSLEngineResult.HandshakeStatus status;
        int packetLength;
        long len;
        ByteBuffer src;
        int sslPending;
        int bytesConsumed;
        ByteBuf bioWriteCopyBuf;
        int bytesConsumed2;
        int bytesProduced;
        int pendingEncryptedBytes;
        int packetLength2;
        int srcsOffset2;
        int dstsEndOffset;
        int dstsOffset2;
        int dstsOffset3;
        int bytesConsumed3;
        ByteBuffer src2;
        SSLEngineResult sSLEngineResult;
        ByteBuffer src3;
        ByteBuffer[] byteBufferArr = srcs;
        ObjectUtil.checkNotNull(byteBufferArr, "srcs");
        if (srcsOffset >= byteBufferArr.length || srcsOffset + srcsLength > byteBufferArr.length) {
            throw new IndexOutOfBoundsException("offset: " + srcsOffset + ", length: " + srcsLength + " (expected: offset <= offset + length <= srcs.length (" + srcs.length + "))");
        } else if (dsts == null) {
            throw new IllegalArgumentException("dsts is null");
        } else {
            if (dstsOffset >= dsts.length || dstsOffset + dstsLength > dsts.length) {
                throw new IndexOutOfBoundsException("offset: " + dstsOffset + ", length: " + dstsLength + " (expected: offset <= offset + length <= dsts.length (" + dsts.length + "))");
            }
            long capacity = 0;
            int sslPending2 = dstsOffset + dstsLength;
            for (int i = dstsOffset; i < sslPending2; i++) {
                ByteBuffer dst = dsts[i];
                if (dst == null) {
                    throw new IllegalArgumentException("dsts[" + i + "] is null");
                } else if (dst.isReadOnly()) {
                    throw new ReadOnlyBufferException();
                } else {
                    capacity += dst.remaining();
                }
            }
            int srcsEndOffset = srcsOffset + srcsLength;
            long len2 = 0;
            for (int i2 = srcsOffset; i2 < srcsEndOffset; i2++) {
                if (byteBufferArr[i2] == null) {
                    throw new IllegalArgumentException("srcs[" + i2 + "] is null");
                }
                len2 += src3.remaining();
            }
            synchronized (this) {
                try {
                    try {
                        try {
                            if (isInboundDone()) {
                                if (!isOutboundDone() && !isDestroyed()) {
                                    sSLEngineResult = NEED_WRAP_CLOSED;
                                    return sSLEngineResult;
                                }
                                sSLEngineResult = CLOSED_NOT_HANDSHAKING;
                                return sSLEngineResult;
                            }
                            SSLEngineResult.HandshakeStatus status2 = SSLEngineResult.HandshakeStatus.NOT_HANDSHAKING;
                            if (this.handshakeState != HandshakeState.FINISHED) {
                                if (this.handshakeState != HandshakeState.STARTED_EXPLICITLY) {
                                    this.handshakeState = HandshakeState.STARTED_IMPLICITLY;
                                }
                                SSLEngineResult.HandshakeStatus status3 = handshake();
                                if (status3 == SSLEngineResult.HandshakeStatus.NEED_TASK) {
                                    return newResult(status3, 0, 0);
                                } else if (status3 == SSLEngineResult.HandshakeStatus.NEED_WRAP) {
                                    return NEED_WRAP_OK;
                                } else if (this.isInboundDone) {
                                    return NEED_WRAP_CLOSED;
                                } else {
                                    status = status3;
                                }
                            } else {
                                status = status2;
                            }
                            int sslPending3 = sslPending0();
                            try {
                                if (this.jdkCompatibilityMode) {
                                    if (len2 < 5) {
                                        return newResultMayFinishHandshake(SSLEngineResult.Status.BUFFER_UNDERFLOW, status, 0, 0);
                                    }
                                    packetLength = SslUtils.getEncryptedPacketLength(srcs, srcsOffset);
                                    if (packetLength == -2) {
                                        throw new NotSslRecordException("not an SSL/TLS record");
                                    }
                                    int packetLengthDataOnly = packetLength - 5;
                                    if (packetLengthDataOnly > capacity) {
                                        if (packetLengthDataOnly <= MAX_RECORD_SIZE) {
                                            try {
                                                this.session.tryExpandApplicationBufferSize(packetLengthDataOnly);
                                                return newResultMayFinishHandshake(SSLEngineResult.Status.BUFFER_OVERFLOW, status, 0, 0);
                                            } catch (Throwable th) {
                                                th = th;
                                                throw th;
                                            }
                                        }
                                        throw new SSLException("Illegal packet length: " + packetLengthDataOnly + " > " + this.session.getApplicationBufferSize());
                                    } else if (len2 < packetLength) {
                                        return newResultMayFinishHandshake(SSLEngineResult.Status.BUFFER_UNDERFLOW, status, 0, 0);
                                    }
                                } else if (len2 == 0 && sslPending3 <= 0) {
                                    return newResultMayFinishHandshake(SSLEngineResult.Status.BUFFER_UNDERFLOW, status, 0, 0);
                                } else if (capacity == 0) {
                                    return newResultMayFinishHandshake(SSLEngineResult.Status.BUFFER_OVERFLOW, status, 0, 0);
                                } else {
                                    packetLength = (int) Math.min(2147483647L, len2);
                                }
                                int sslPending4 = sslPending3;
                                int bytesProduced2 = 0;
                                int dstsOffset4 = packetLength;
                                int bytesProduced3 = 0;
                                int srcsOffset3 = srcsOffset;
                                int srcsOffset4 = dstsOffset;
                                loop2: while (true) {
                                    try {
                                        ByteBuffer src4 = byteBufferArr[srcsOffset3];
                                        long capacity2 = capacity;
                                        int remaining = src4.remaining();
                                        if (remaining != 0) {
                                            len = len2;
                                            try {
                                                int pendingEncryptedBytes2 = Math.min(dstsOffset4, remaining);
                                                src = src4;
                                                sslPending = sslPending4;
                                                bytesConsumed = bytesProduced2;
                                                bioWriteCopyBuf = writeEncryptedData(src, pendingEncryptedBytes2);
                                                bytesConsumed2 = bytesProduced3;
                                                bytesProduced = pendingEncryptedBytes2;
                                                pendingEncryptedBytes = dstsOffset4;
                                                packetLength2 = srcsOffset4;
                                            } catch (Throwable th2) {
                                                th = th2;
                                                long capacity3 = this.networkBIO;
                                                SSL.bioClearByteBuffer(capacity3);
                                                rejectRemoteInitiatedRenegotiation();
                                                throw th;
                                            }
                                        } else if (sslPending4 <= 0) {
                                            srcsOffset3++;
                                            if (srcsOffset3 >= srcsEndOffset) {
                                                break;
                                            }
                                            capacity = capacity2;
                                        } else {
                                            len = len2;
                                            try {
                                                long len3 = this.networkBIO;
                                                int bioLengthByteBuffer = SSL.bioLengthByteBuffer(len3);
                                                src = src4;
                                                sslPending = sslPending4;
                                                bytesConsumed = bytesProduced2;
                                                bioWriteCopyBuf = null;
                                                bytesConsumed2 = bytesProduced3;
                                                bytesProduced = bioLengthByteBuffer;
                                                pendingEncryptedBytes = dstsOffset4;
                                                packetLength2 = srcsOffset4;
                                            } catch (Throwable th3) {
                                                th = th3;
                                                long capacity32 = this.networkBIO;
                                                SSL.bioClearByteBuffer(capacity32);
                                                rejectRemoteInitiatedRenegotiation();
                                                throw th;
                                            }
                                        }
                                        while (true) {
                                            try {
                                                ByteBuffer dst2 = dsts[packetLength2];
                                                if (!dst2.hasRemaining()) {
                                                    packetLength2++;
                                                    if (packetLength2 >= sslPending2) {
                                                        break loop2;
                                                    }
                                                } else {
                                                    int bytesRead = readPlaintextData(dst2);
                                                    srcsOffset2 = srcsOffset3;
                                                    try {
                                                        int localBytesConsumed = bytesProduced - SSL.bioLengthByteBuffer(this.networkBIO);
                                                        bytesConsumed3 = bytesConsumed + localBytesConsumed;
                                                        pendingEncryptedBytes -= localBytesConsumed;
                                                        bytesProduced -= localBytesConsumed;
                                                        try {
                                                            int remaining2 = remaining;
                                                            try {
                                                                src.position(src.position() + localBytesConsumed);
                                                                if (bytesRead <= 0) {
                                                                    break;
                                                                }
                                                                bytesConsumed2 += bytesRead;
                                                                try {
                                                                    try {
                                                                        if (dst2.hasRemaining()) {
                                                                            src2 = src;
                                                                            if (pendingEncryptedBytes == 0) {
                                                                                break loop2;
                                                                            }
                                                                            try {
                                                                                if (this.jdkCompatibilityMode) {
                                                                                    break loop2;
                                                                                }
                                                                            } catch (Throwable th4) {
                                                                                th = th4;
                                                                                dstsOffset2 = packetLength2;
                                                                                dstsOffset3 = pendingEncryptedBytes;
                                                                                dstsEndOffset = sslPending;
                                                                                if (bioWriteCopyBuf != null) {
                                                                                    try {
                                                                                        bioWriteCopyBuf.release();
                                                                                    } catch (Throwable th5) {
                                                                                        th = th5;
                                                                                        long capacity322 = this.networkBIO;
                                                                                        SSL.bioClearByteBuffer(capacity322);
                                                                                        rejectRemoteInitiatedRenegotiation();
                                                                                        throw th;
                                                                                    }
                                                                                }
                                                                                throw th;
                                                                            }
                                                                        } else {
                                                                            sslPending = sslPending0();
                                                                            packetLength2++;
                                                                            if (packetLength2 >= sslPending2) {
                                                                                try {
                                                                                    break loop2;
                                                                                } catch (Throwable th6) {
                                                                                    th = th6;
                                                                                    dstsOffset2 = packetLength2;
                                                                                    dstsOffset3 = pendingEncryptedBytes;
                                                                                    dstsEndOffset = sslPending;
                                                                                }
                                                                            } else {
                                                                                src2 = src;
                                                                            }
                                                                        }
                                                                        bytesConsumed = bytesConsumed3;
                                                                        remaining = remaining2;
                                                                        src = src2;
                                                                        srcsOffset3 = srcsOffset2;
                                                                    } catch (Throwable th7) {
                                                                        th = th7;
                                                                        long capacity3222 = this.networkBIO;
                                                                        SSL.bioClearByteBuffer(capacity3222);
                                                                        rejectRemoteInitiatedRenegotiation();
                                                                        throw th;
                                                                    }
                                                                } catch (Throwable th8) {
                                                                    th = th8;
                                                                    dstsOffset2 = packetLength2;
                                                                    dstsOffset3 = pendingEncryptedBytes;
                                                                    dstsEndOffset = sslPending;
                                                                }
                                                            } catch (Throwable th9) {
                                                                th = th9;
                                                                dstsEndOffset = sslPending;
                                                                dstsOffset2 = packetLength2;
                                                                dstsOffset3 = pendingEncryptedBytes;
                                                            }
                                                        } catch (Throwable th10) {
                                                            th = th10;
                                                            dstsEndOffset = sslPending;
                                                            dstsOffset2 = packetLength2;
                                                            dstsOffset3 = pendingEncryptedBytes;
                                                        }
                                                    } catch (Throwable th11) {
                                                        th = th11;
                                                        dstsEndOffset = sslPending;
                                                        dstsOffset2 = packetLength2;
                                                        dstsOffset3 = pendingEncryptedBytes;
                                                        bytesConsumed3 = bytesConsumed;
                                                    }
                                                }
                                            } catch (Throwable th12) {
                                                th = th12;
                                                srcsOffset2 = srcsOffset3;
                                                dstsEndOffset = sslPending;
                                                dstsOffset2 = packetLength2;
                                                dstsOffset3 = pendingEncryptedBytes;
                                                bytesConsumed3 = bytesConsumed;
                                            }
                                        }
                                    } catch (Throwable th13) {
                                        th = th13;
                                    }
                                }
                                SSL.bioClearByteBuffer(this.networkBIO);
                                rejectRemoteInitiatedRenegotiation();
                                if (!this.receivedShutdown && (SSL.getShutdown(this.ssl) & SSL.SSL_RECEIVED_SHUTDOWN) == SSL.SSL_RECEIVED_SHUTDOWN) {
                                    closeAll();
                                }
                                return newResultMayFinishHandshake(isInboundDone() ? SSLEngineResult.Status.CLOSED : SSLEngineResult.Status.OK, status, bytesProduced2, bytesProduced3);
                            } catch (Throwable th14) {
                                th = th14;
                            }
                        } catch (Throwable th15) {
                            th = th15;
                        }
                    } catch (Throwable th16) {
                        th = th16;
                    }
                } catch (Throwable th17) {
                    th = th17;
                }
            }
        }
    }

    private SSLEngineResult sslReadErrorResult(int error, int stackError, int bytesConsumed, int bytesProduced) throws SSLException {
        if (SSL.bioLengthNonApplication(this.networkBIO) > 0) {
            if (this.handshakeException == null && this.handshakeState != HandshakeState.FINISHED) {
                this.handshakeException = new SSLHandshakeException(SSL.getErrorString(stackError));
            }
            SSL.clearError();
            return new SSLEngineResult(SSLEngineResult.Status.OK, SSLEngineResult.HandshakeStatus.NEED_WRAP, bytesConsumed, bytesProduced);
        }
        throw shutdownWithError("SSL_read", error, stackError);
    }

    private void closeAll() throws SSLException {
        this.receivedShutdown = true;
        closeOutbound();
        closeInbound();
    }

    private void rejectRemoteInitiatedRenegotiation() throws SSLHandshakeException {
        if (!isDestroyed() && SSL.getHandshakeCount(this.ssl) > 1 && !"TLSv1.3".equals(this.session.getProtocol()) && this.handshakeState == HandshakeState.FINISHED) {
            shutdown();
            throw new SSLHandshakeException("remote-initiated renegotiation not allowed");
        }
    }

    public final SSLEngineResult unwrap(ByteBuffer[] srcs, ByteBuffer[] dsts) throws SSLException {
        return unwrap(srcs, 0, srcs.length, dsts, 0, dsts.length);
    }

    private ByteBuffer[] singleSrcBuffer(ByteBuffer src) {
        ByteBuffer[] byteBufferArr = this.singleSrcBuffer;
        byteBufferArr[0] = src;
        return byteBufferArr;
    }

    private void resetSingleSrcBuffer() {
        this.singleSrcBuffer[0] = null;
    }

    private ByteBuffer[] singleDstBuffer(ByteBuffer src) {
        ByteBuffer[] byteBufferArr = this.singleDstBuffer;
        byteBufferArr[0] = src;
        return byteBufferArr;
    }

    private void resetSingleDstBuffer() {
        this.singleDstBuffer[0] = null;
    }

    @Override // javax.net.ssl.SSLEngine
    public final synchronized SSLEngineResult unwrap(ByteBuffer src, ByteBuffer[] dsts, int offset, int length) throws SSLException {
        SSLEngineResult unwrap;
        unwrap = unwrap(singleSrcBuffer(src), 0, 1, dsts, offset, length);
        resetSingleSrcBuffer();
        return unwrap;
    }

    @Override // javax.net.ssl.SSLEngine
    public final synchronized SSLEngineResult wrap(ByteBuffer src, ByteBuffer dst) throws SSLException {
        SSLEngineResult wrap;
        wrap = wrap(singleSrcBuffer(src), dst);
        resetSingleSrcBuffer();
        return wrap;
    }

    @Override // javax.net.ssl.SSLEngine
    public final synchronized SSLEngineResult unwrap(ByteBuffer src, ByteBuffer dst) throws SSLException {
        SSLEngineResult unwrap;
        unwrap = unwrap(singleSrcBuffer(src), singleDstBuffer(dst));
        resetSingleSrcBuffer();
        resetSingleDstBuffer();
        return unwrap;
    }

    @Override // javax.net.ssl.SSLEngine
    public final synchronized SSLEngineResult unwrap(ByteBuffer src, ByteBuffer[] dsts) throws SSLException {
        SSLEngineResult unwrap;
        unwrap = unwrap(singleSrcBuffer(src), dsts);
        resetSingleSrcBuffer();
        return unwrap;
    }

    @Override // javax.net.ssl.SSLEngine
    public final synchronized Runnable getDelegatedTask() {
        if (isDestroyed()) {
            return null;
        }
        final Runnable task = SSL.getTask(this.ssl);
        if (task == null) {
            return null;
        }
        return new Runnable() { // from class: io.netty.handler.ssl.ReferenceCountedOpenSslEngine.3
            @Override // java.lang.Runnable
            public void run() {
                if (ReferenceCountedOpenSslEngine.this.isDestroyed()) {
                    return;
                }
                try {
                    task.run();
                } finally {
                    ReferenceCountedOpenSslEngine.this.needTask = false;
                }
            }
        };
    }

    @Override // javax.net.ssl.SSLEngine
    public final synchronized void closeInbound() throws SSLException {
        if (this.isInboundDone) {
            return;
        }
        this.isInboundDone = true;
        if (isOutboundDone()) {
            shutdown();
        }
        if (this.handshakeState != HandshakeState.NOT_STARTED && !this.receivedShutdown) {
            throw new SSLException("Inbound closed before receiving peer's close_notify: possible truncation attack?");
        }
    }

    @Override // javax.net.ssl.SSLEngine
    public final synchronized boolean isInboundDone() {
        return this.isInboundDone;
    }

    @Override // javax.net.ssl.SSLEngine
    public final synchronized void closeOutbound() {
        if (this.outboundClosed) {
            return;
        }
        this.outboundClosed = true;
        if (this.handshakeState != HandshakeState.NOT_STARTED && !isDestroyed()) {
            int mode = SSL.getShutdown(this.ssl);
            if ((SSL.SSL_SENT_SHUTDOWN & mode) != SSL.SSL_SENT_SHUTDOWN) {
                doSSLShutdown();
            }
        } else {
            shutdown();
        }
    }

    private boolean doSSLShutdown() {
        if (SSL.isInInit(this.ssl) != 0) {
            return false;
        }
        int err = SSL.shutdownSSL(this.ssl);
        if (err < 0) {
            int sslErr = SSL.getError(this.ssl, err);
            if (sslErr == SSL.SSL_ERROR_SYSCALL || sslErr == SSL.SSL_ERROR_SSL) {
                if (logger.isDebugEnabled()) {
                    int error = SSL.getLastErrorNumber();
                    logger.debug("SSL_shutdown failed: OpenSSL error: {} {}", Integer.valueOf(error), SSL.getErrorString(error));
                }
                shutdown();
                return false;
            }
            SSL.clearError();
            return true;
        }
        return true;
    }

    /* JADX WARN: Code restructure failed: missing block: B:8:0x0013, code lost:
        if (io.netty.internal.tcnative.SSL.bioLengthNonApplication(r5.networkBIO) == 0) goto L10;
     */
    @Override // javax.net.ssl.SSLEngine
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public final synchronized boolean isOutboundDone() {
        boolean z;
        if (this.outboundClosed) {
            if (this.networkBIO != 0) {
            }
            z = true;
        }
        z = false;
        return z;
    }

    @Override // javax.net.ssl.SSLEngine
    public final String[] getSupportedCipherSuites() {
        return (String[]) OpenSsl.AVAILABLE_CIPHER_SUITES.toArray(new String[0]);
    }

    @Override // javax.net.ssl.SSLEngine
    public final String[] getEnabledCipherSuites() {
        synchronized (this) {
            if (!isDestroyed()) {
                String[] enabled = SSL.getCiphers(this.ssl);
                if (enabled == null) {
                    return EmptyArrays.EMPTY_STRINGS;
                }
                List<String> enabledList = new ArrayList<>();
                synchronized (this) {
                    for (int i = 0; i < enabled.length; i++) {
                        String mapped = toJavaCipherSuite(enabled[i]);
                        String cipher = mapped == null ? enabled[i] : mapped;
                        if (OpenSsl.isTlsv13Supported() || !SslUtils.isTLSv13Cipher(cipher)) {
                            enabledList.add(cipher);
                        }
                    }
                }
                return (String[]) enabledList.toArray(new String[0]);
            }
            return EmptyArrays.EMPTY_STRINGS;
        }
    }

    @Override // javax.net.ssl.SSLEngine
    public final void setEnabledCipherSuites(String[] cipherSuites) {
        ObjectUtil.checkNotNull(cipherSuites, "cipherSuites");
        StringBuilder buf = new StringBuilder();
        StringBuilder bufTLSv13 = new StringBuilder();
        CipherSuiteConverter.convertToCipherStrings(Arrays.asList(cipherSuites), buf, bufTLSv13, OpenSsl.isBoringSSL());
        String cipherSuiteSpec = buf.toString();
        String cipherSuiteSpecTLSv13 = bufTLSv13.toString();
        if (!OpenSsl.isTlsv13Supported() && !cipherSuiteSpecTLSv13.isEmpty()) {
            throw new IllegalArgumentException("TLSv1.3 is not supported by this java version.");
        }
        synchronized (this) {
            if (!isDestroyed()) {
                try {
                    SSL.setCipherSuites(this.ssl, cipherSuiteSpec, false);
                    if (OpenSsl.isTlsv13Supported()) {
                        SSL.setCipherSuites(this.ssl, cipherSuiteSpecTLSv13, true);
                    }
                } catch (Exception e) {
                    throw new IllegalStateException("failed to enable cipher suites: " + cipherSuiteSpec, e);
                }
            } else {
                throw new IllegalStateException("failed to enable cipher suites: " + cipherSuiteSpec);
            }
        }
    }

    @Override // javax.net.ssl.SSLEngine
    public final String[] getSupportedProtocols() {
        return (String[]) OpenSsl.SUPPORTED_PROTOCOLS_SET.toArray(new String[0]);
    }

    @Override // javax.net.ssl.SSLEngine
    public final String[] getEnabledProtocols() {
        List<String> enabled = new ArrayList<>(6);
        enabled.add("SSLv2Hello");
        synchronized (this) {
            if (!isDestroyed()) {
                int opts = SSL.getOptions(this.ssl);
                if (isProtocolEnabled(opts, SSL.SSL_OP_NO_TLSv1, "TLSv1")) {
                    enabled.add("TLSv1");
                }
                if (isProtocolEnabled(opts, SSL.SSL_OP_NO_TLSv1_1, "TLSv1.1")) {
                    enabled.add("TLSv1.1");
                }
                if (isProtocolEnabled(opts, SSL.SSL_OP_NO_TLSv1_2, "TLSv1.2")) {
                    enabled.add("TLSv1.2");
                }
                if (isProtocolEnabled(opts, SSL.SSL_OP_NO_TLSv1_3, "TLSv1.3")) {
                    enabled.add("TLSv1.3");
                }
                if (isProtocolEnabled(opts, SSL.SSL_OP_NO_SSLv2, "SSLv2")) {
                    enabled.add("SSLv2");
                }
                if (isProtocolEnabled(opts, SSL.SSL_OP_NO_SSLv3, "SSLv3")) {
                    enabled.add("SSLv3");
                }
                return (String[]) enabled.toArray(new String[0]);
            }
            return (String[]) enabled.toArray(new String[0]);
        }
    }

    private static boolean isProtocolEnabled(int opts, int disableMask, String protocolString) {
        return (opts & disableMask) == 0 && OpenSsl.SUPPORTED_PROTOCOLS_SET.contains(protocolString);
    }

    @Override // javax.net.ssl.SSLEngine
    public final void setEnabledProtocols(String[] protocols) {
        if (protocols == null) {
            throw new IllegalArgumentException();
        }
        int minProtocolIndex = OPENSSL_OP_NO_PROTOCOLS.length;
        int maxProtocolIndex = 0;
        for (String p : protocols) {
            if (!OpenSsl.SUPPORTED_PROTOCOLS_SET.contains(p)) {
                throw new IllegalArgumentException("Protocol " + p + " is not supported.");
            }
            if (p.equals("SSLv2")) {
                if (minProtocolIndex > 0) {
                    minProtocolIndex = 0;
                }
                if (maxProtocolIndex < 0) {
                    maxProtocolIndex = 0;
                }
            } else if (p.equals("SSLv3")) {
                if (minProtocolIndex > 1) {
                    minProtocolIndex = 1;
                }
                if (maxProtocolIndex < 1) {
                    maxProtocolIndex = 1;
                }
            } else if (p.equals("TLSv1")) {
                if (minProtocolIndex > 2) {
                    minProtocolIndex = 2;
                }
                if (maxProtocolIndex < 2) {
                    maxProtocolIndex = 2;
                }
            } else if (p.equals("TLSv1.1")) {
                if (minProtocolIndex > 3) {
                    minProtocolIndex = 3;
                }
                if (maxProtocolIndex < 3) {
                    maxProtocolIndex = 3;
                }
            } else if (p.equals("TLSv1.2")) {
                if (minProtocolIndex > 4) {
                    minProtocolIndex = 4;
                }
                if (maxProtocolIndex < 4) {
                    maxProtocolIndex = 4;
                }
            } else if (p.equals("TLSv1.3")) {
                if (minProtocolIndex > 5) {
                    minProtocolIndex = 5;
                }
                if (maxProtocolIndex < 5) {
                    maxProtocolIndex = 5;
                }
            }
        }
        synchronized (this) {
            if (!isDestroyed()) {
                SSL.clearOptions(this.ssl, SSL.SSL_OP_NO_SSLv2 | SSL.SSL_OP_NO_SSLv3 | SSL.SSL_OP_NO_TLSv1 | SSL.SSL_OP_NO_TLSv1_1 | SSL.SSL_OP_NO_TLSv1_2 | SSL.SSL_OP_NO_TLSv1_3);
                int opts = 0;
                for (int i = 0; i < minProtocolIndex; i++) {
                    opts |= OPENSSL_OP_NO_PROTOCOLS[i];
                }
                for (int i2 = maxProtocolIndex + 1; i2 < OPENSSL_OP_NO_PROTOCOLS.length; i2++) {
                    opts |= OPENSSL_OP_NO_PROTOCOLS[i2];
                }
                SSL.setOptions(this.ssl, opts);
            } else {
                throw new IllegalStateException("failed to enable protocols: " + Arrays.asList(protocols));
            }
        }
    }

    @Override // javax.net.ssl.SSLEngine
    public final SSLSession getSession() {
        return this.session;
    }

    @Override // javax.net.ssl.SSLEngine
    public final synchronized void beginHandshake() throws SSLException {
        int i = AnonymousClass4.$SwitchMap$io$netty$handler$ssl$ReferenceCountedOpenSslEngine$HandshakeState[this.handshakeState.ordinal()];
        if (i == 1) {
            this.handshakeState = HandshakeState.STARTED_EXPLICITLY;
            if (handshake() == SSLEngineResult.HandshakeStatus.NEED_TASK) {
                this.needTask = true;
            }
            calculateMaxWrapOverhead();
        } else if (i == 2) {
            throw new SSLException("renegotiation unsupported");
        } else {
            if (i == 3) {
                checkEngineClosed();
                this.handshakeState = HandshakeState.STARTED_EXPLICITLY;
                calculateMaxWrapOverhead();
            } else if (i != 4) {
                throw new Error();
            }
        }
    }

    private void checkEngineClosed() throws SSLException {
        if (isDestroyed()) {
            throw new SSLException("engine closed");
        }
    }

    private static SSLEngineResult.HandshakeStatus pendingStatus(int pendingStatus) {
        return pendingStatus > 0 ? SSLEngineResult.HandshakeStatus.NEED_WRAP : SSLEngineResult.HandshakeStatus.NEED_UNWRAP;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static boolean isEmpty(Object[] arr) {
        return arr == null || arr.length == 0;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static boolean isEmpty(byte[] cert) {
        return cert == null || cert.length == 0;
    }

    private SSLEngineResult.HandshakeStatus handshakeException() throws SSLException {
        if (SSL.bioLengthNonApplication(this.networkBIO) > 0) {
            return SSLEngineResult.HandshakeStatus.NEED_WRAP;
        }
        Throwable exception = this.handshakeException;
        this.handshakeException = null;
        shutdown();
        if (exception instanceof SSLHandshakeException) {
            throw ((SSLHandshakeException) exception);
        }
        SSLHandshakeException e = new SSLHandshakeException("General OpenSslEngine problem");
        e.initCause(exception);
        throw e;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final void initHandshakeException(Throwable cause) {
        this.handshakeException = cause;
    }

    private SSLEngineResult.HandshakeStatus handshake() throws SSLException {
        if (this.needTask) {
            return SSLEngineResult.HandshakeStatus.NEED_TASK;
        }
        if (this.handshakeState == HandshakeState.FINISHED) {
            return SSLEngineResult.HandshakeStatus.FINISHED;
        }
        checkEngineClosed();
        if (this.handshakeException != null) {
            if (SSL.doHandshake(this.ssl) <= 0) {
                SSL.clearError();
            }
            return handshakeException();
        }
        this.engineMap.add(this);
        if (this.lastAccessed == -1) {
            this.lastAccessed = System.currentTimeMillis();
        }
        int code = SSL.doHandshake(this.ssl);
        if (code <= 0) {
            int sslError = SSL.getError(this.ssl, code);
            if (sslError == SSL.SSL_ERROR_WANT_READ || sslError == SSL.SSL_ERROR_WANT_WRITE) {
                return pendingStatus(SSL.bioLengthNonApplication(this.networkBIO));
            }
            if (sslError == SSL.SSL_ERROR_WANT_X509_LOOKUP || sslError == SSL.SSL_ERROR_WANT_CERTIFICATE_VERIFY || sslError == SSL.SSL_ERROR_WANT_PRIVATE_KEY_OPERATION) {
                return SSLEngineResult.HandshakeStatus.NEED_TASK;
            }
            if (this.handshakeException != null) {
                return handshakeException();
            }
            throw shutdownWithError("SSL_do_handshake", sslError);
        } else if (SSL.bioLengthNonApplication(this.networkBIO) > 0) {
            return SSLEngineResult.HandshakeStatus.NEED_WRAP;
        } else {
            this.session.handshakeFinished();
            return SSLEngineResult.HandshakeStatus.FINISHED;
        }
    }

    private SSLEngineResult.HandshakeStatus mayFinishHandshake(SSLEngineResult.HandshakeStatus status) throws SSLException {
        if (status == SSLEngineResult.HandshakeStatus.NOT_HANDSHAKING && this.handshakeState != HandshakeState.FINISHED) {
            return handshake();
        }
        return status;
    }

    @Override // javax.net.ssl.SSLEngine
    public final synchronized SSLEngineResult.HandshakeStatus getHandshakeStatus() {
        if (needPendingStatus()) {
            if (this.needTask) {
                return SSLEngineResult.HandshakeStatus.NEED_TASK;
            }
            return pendingStatus(SSL.bioLengthNonApplication(this.networkBIO));
        }
        return SSLEngineResult.HandshakeStatus.NOT_HANDSHAKING;
    }

    private SSLEngineResult.HandshakeStatus getHandshakeStatus(int pending) {
        if (needPendingStatus()) {
            if (this.needTask) {
                return SSLEngineResult.HandshakeStatus.NEED_TASK;
            }
            return pendingStatus(pending);
        }
        return SSLEngineResult.HandshakeStatus.NOT_HANDSHAKING;
    }

    private boolean needPendingStatus() {
        return (this.handshakeState == HandshakeState.NOT_STARTED || isDestroyed() || (this.handshakeState == HandshakeState.FINISHED && !isInboundDone() && !isOutboundDone())) ? false : true;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public String toJavaCipherSuite(String openSslCipherSuite) {
        if (openSslCipherSuite == null) {
            return null;
        }
        String version = SSL.getVersion(this.ssl);
        String prefix = toJavaCipherSuitePrefix(version);
        return CipherSuiteConverter.toJava(openSslCipherSuite, prefix);
    }

    private static String toJavaCipherSuitePrefix(String protocolVersion) {
        char c;
        if (protocolVersion == null || protocolVersion.isEmpty()) {
            c = 0;
        } else {
            c = protocolVersion.charAt(0);
        }
        if (c != 'S') {
            if (c == 'T') {
                return "TLS";
            }
            return "UNKNOWN";
        }
        return "SSL";
    }

    @Override // javax.net.ssl.SSLEngine
    public final void setUseClientMode(boolean clientMode) {
        if (clientMode != this.clientMode) {
            throw new UnsupportedOperationException();
        }
    }

    @Override // javax.net.ssl.SSLEngine
    public final boolean getUseClientMode() {
        return this.clientMode;
    }

    @Override // javax.net.ssl.SSLEngine
    public final void setNeedClientAuth(boolean b) {
        setClientAuth(b ? ClientAuth.REQUIRE : ClientAuth.NONE);
    }

    @Override // javax.net.ssl.SSLEngine
    public final boolean getNeedClientAuth() {
        return this.clientAuth == ClientAuth.REQUIRE;
    }

    @Override // javax.net.ssl.SSLEngine
    public final void setWantClientAuth(boolean b) {
        setClientAuth(b ? ClientAuth.OPTIONAL : ClientAuth.NONE);
    }

    @Override // javax.net.ssl.SSLEngine
    public final boolean getWantClientAuth() {
        return this.clientAuth == ClientAuth.OPTIONAL;
    }

    public final synchronized void setVerify(int verifyMode, int depth) {
        SSL.setVerify(this.ssl, verifyMode, depth);
    }

    private void setClientAuth(ClientAuth mode) {
        if (this.clientMode) {
            return;
        }
        synchronized (this) {
            if (this.clientAuth == mode) {
                return;
            }
            int i = AnonymousClass4.$SwitchMap$io$netty$handler$ssl$ClientAuth[mode.ordinal()];
            if (i == 1) {
                SSL.setVerify(this.ssl, 0, 10);
            } else if (i == 2) {
                SSL.setVerify(this.ssl, 2, 10);
            } else if (i == 3) {
                SSL.setVerify(this.ssl, 1, 10);
            } else {
                throw new Error(mode.toString());
            }
            this.clientAuth = mode;
        }
    }

    @Override // javax.net.ssl.SSLEngine
    public final void setEnableSessionCreation(boolean b) {
        if (b) {
            throw new UnsupportedOperationException();
        }
    }

    @Override // javax.net.ssl.SSLEngine
    public final boolean getEnableSessionCreation() {
        return false;
    }

    @Override // javax.net.ssl.SSLEngine
    public final synchronized SSLParameters getSSLParameters() {
        SSLParameters sslParameters;
        sslParameters = super.getSSLParameters();
        int version = PlatformDependent.javaVersion();
        if (version >= 7) {
            sslParameters.setEndpointIdentificationAlgorithm(this.endPointIdentificationAlgorithm);
            Java7SslParametersUtils.setAlgorithmConstraints(sslParameters, this.algorithmConstraints);
            if (version >= 8) {
                if (this.sniHostNames != null) {
                    Java8SslUtils.setSniHostNames(sslParameters, this.sniHostNames);
                }
                if (!isDestroyed()) {
                    Java8SslUtils.setUseCipherSuitesOrder(sslParameters, (SSL.getOptions(this.ssl) & SSL.SSL_OP_CIPHER_SERVER_PREFERENCE) != 0);
                }
                Java8SslUtils.setSNIMatchers(sslParameters, this.matchers);
            }
        }
        return sslParameters;
    }

    @Override // javax.net.ssl.SSLEngine
    public final synchronized void setSSLParameters(SSLParameters sslParameters) {
        int version = PlatformDependent.javaVersion();
        if (version >= 7) {
            if (sslParameters.getAlgorithmConstraints() != null) {
                throw new IllegalArgumentException("AlgorithmConstraints are not supported.");
            }
            if (version >= 8) {
                if (!isDestroyed()) {
                    if (this.clientMode) {
                        List<String> sniHostNames = Java8SslUtils.getSniHostNames(sslParameters);
                        for (String name : sniHostNames) {
                            SSL.setTlsExtHostName(this.ssl, name);
                        }
                        this.sniHostNames = sniHostNames;
                    }
                    if (Java8SslUtils.getUseCipherSuitesOrder(sslParameters)) {
                        SSL.setOptions(this.ssl, SSL.SSL_OP_CIPHER_SERVER_PREFERENCE);
                    } else {
                        SSL.clearOptions(this.ssl, SSL.SSL_OP_CIPHER_SERVER_PREFERENCE);
                    }
                }
                this.matchers = sslParameters.getSNIMatchers();
            }
            String endPointIdentificationAlgorithm = sslParameters.getEndpointIdentificationAlgorithm();
            boolean endPointVerificationEnabled = isEndPointVerificationEnabled(endPointIdentificationAlgorithm);
            if (this.clientMode && endPointVerificationEnabled) {
                SSL.setVerify(this.ssl, 2, -1);
            }
            this.endPointIdentificationAlgorithm = endPointIdentificationAlgorithm;
            this.algorithmConstraints = sslParameters.getAlgorithmConstraints();
        }
        super.setSSLParameters(sslParameters);
    }

    private static boolean isEndPointVerificationEnabled(String endPointIdentificationAlgorithm) {
        return (endPointIdentificationAlgorithm == null || endPointIdentificationAlgorithm.isEmpty()) ? false : true;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public boolean isDestroyed() {
        return this.destroyed;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final boolean checkSniHostnameMatch(byte[] hostname) {
        return Java8SslUtils.checkSniHostnameMatch(this.matchers, hostname);
    }

    @Override // io.netty.handler.ssl.ApplicationProtocolAccessor
    public String getNegotiatedApplicationProtocol() {
        return this.applicationProtocol;
    }

    private static long bufferAddress(ByteBuffer b) {
        if (PlatformDependent.hasUnsafe()) {
            return PlatformDependent.directBufferAddress(b);
        }
        return Buffer.address(b);
    }

    /* loaded from: classes.dex */
    private final class DefaultOpenSslSession implements OpenSslSession {
        static final /* synthetic */ boolean $assertionsDisabled = false;
        private volatile int applicationBufferSize = ReferenceCountedOpenSslEngine.MAX_PLAINTEXT_LENGTH;
        private String cipher;
        private long creationTime;
        private byte[] id;
        private Certificate[] peerCerts;
        private String protocol;
        private final OpenSslSessionContext sessionContext;
        private Map<String, Object> values;
        private X509Certificate[] x509PeerCerts;

        DefaultOpenSslSession(OpenSslSessionContext sessionContext) {
            this.sessionContext = sessionContext;
        }

        private SSLSessionBindingEvent newSSLSessionBindingEvent(String name) {
            return new SSLSessionBindingEvent(ReferenceCountedOpenSslEngine.this.session, name);
        }

        @Override // javax.net.ssl.SSLSession
        public byte[] getId() {
            synchronized (ReferenceCountedOpenSslEngine.this) {
                if (this.id == null) {
                    return EmptyArrays.EMPTY_BYTES;
                }
                return (byte[]) this.id.clone();
            }
        }

        @Override // javax.net.ssl.SSLSession
        public SSLSessionContext getSessionContext() {
            return this.sessionContext;
        }

        @Override // javax.net.ssl.SSLSession
        public long getCreationTime() {
            synchronized (ReferenceCountedOpenSslEngine.this) {
                if (this.creationTime == 0 && !ReferenceCountedOpenSslEngine.this.isDestroyed()) {
                    this.creationTime = SSL.getTime(ReferenceCountedOpenSslEngine.this.ssl) * 1000;
                }
            }
            return this.creationTime;
        }

        @Override // javax.net.ssl.SSLSession
        public long getLastAccessedTime() {
            long lastAccessed = ReferenceCountedOpenSslEngine.this.lastAccessed;
            return lastAccessed == -1 ? getCreationTime() : lastAccessed;
        }

        @Override // javax.net.ssl.SSLSession
        public void invalidate() {
            synchronized (ReferenceCountedOpenSslEngine.this) {
                if (!ReferenceCountedOpenSslEngine.this.isDestroyed()) {
                    SSL.setTimeout(ReferenceCountedOpenSslEngine.this.ssl, 0L);
                }
            }
        }

        @Override // javax.net.ssl.SSLSession
        public boolean isValid() {
            synchronized (ReferenceCountedOpenSslEngine.this) {
                if (ReferenceCountedOpenSslEngine.this.isDestroyed()) {
                    return false;
                }
                return System.currentTimeMillis() - (SSL.getTimeout(ReferenceCountedOpenSslEngine.this.ssl) * 1000) < SSL.getTime(ReferenceCountedOpenSslEngine.this.ssl) * 1000;
            }
        }

        @Override // javax.net.ssl.SSLSession
        public void putValue(String name, Object value) {
            Object old;
            ObjectUtil.checkNotNull(name, "name");
            ObjectUtil.checkNotNull(value, "value");
            synchronized (this) {
                Map<String, Object> values = this.values;
                if (values == null) {
                    HashMap hashMap = new HashMap(2);
                    this.values = hashMap;
                    values = hashMap;
                }
                old = values.put(name, value);
            }
            if (value instanceof SSLSessionBindingListener) {
                ((SSLSessionBindingListener) value).valueBound(newSSLSessionBindingEvent(name));
            }
            notifyUnbound(old, name);
        }

        @Override // javax.net.ssl.SSLSession
        public Object getValue(String name) {
            ObjectUtil.checkNotNull(name, "name");
            synchronized (this) {
                if (this.values == null) {
                    return null;
                }
                return this.values.get(name);
            }
        }

        @Override // javax.net.ssl.SSLSession
        public void removeValue(String name) {
            ObjectUtil.checkNotNull(name, "name");
            synchronized (this) {
                Map<String, Object> values = this.values;
                if (values == null) {
                    return;
                }
                Object old = values.remove(name);
                notifyUnbound(old, name);
            }
        }

        @Override // javax.net.ssl.SSLSession
        public String[] getValueNames() {
            synchronized (this) {
                Map<String, Object> values = this.values;
                if (values != null && !values.isEmpty()) {
                    return (String[]) values.keySet().toArray(new String[0]);
                }
                return EmptyArrays.EMPTY_STRINGS;
            }
        }

        private void notifyUnbound(Object value, String name) {
            if (value instanceof SSLSessionBindingListener) {
                ((SSLSessionBindingListener) value).valueUnbound(newSSLSessionBindingEvent(name));
            }
        }

        @Override // io.netty.handler.ssl.OpenSslSession
        public void handshakeFinished() throws SSLException {
            synchronized (ReferenceCountedOpenSslEngine.this) {
                if (!ReferenceCountedOpenSslEngine.this.isDestroyed()) {
                    this.id = SSL.getSessionId(ReferenceCountedOpenSslEngine.this.ssl);
                    this.cipher = ReferenceCountedOpenSslEngine.this.toJavaCipherSuite(SSL.getCipherForSSL(ReferenceCountedOpenSslEngine.this.ssl));
                    this.protocol = SSL.getVersion(ReferenceCountedOpenSslEngine.this.ssl);
                    initPeerCerts();
                    selectApplicationProtocol();
                    ReferenceCountedOpenSslEngine.this.calculateMaxWrapOverhead();
                    ReferenceCountedOpenSslEngine.this.handshakeState = HandshakeState.FINISHED;
                } else {
                    throw new SSLException("Already closed");
                }
            }
        }

        private void initPeerCerts() {
            byte[][] chain = SSL.getPeerCertChain(ReferenceCountedOpenSslEngine.this.ssl);
            if (ReferenceCountedOpenSslEngine.this.clientMode) {
                if (ReferenceCountedOpenSslEngine.isEmpty(chain)) {
                    this.peerCerts = EmptyArrays.EMPTY_CERTIFICATES;
                    this.x509PeerCerts = EmptyArrays.EMPTY_JAVAX_X509_CERTIFICATES;
                    return;
                }
                this.peerCerts = new Certificate[chain.length];
                this.x509PeerCerts = new X509Certificate[chain.length];
                initCerts(chain, 0);
                return;
            }
            byte[] clientCert = SSL.getPeerCertificate(ReferenceCountedOpenSslEngine.this.ssl);
            if (!ReferenceCountedOpenSslEngine.isEmpty(clientCert)) {
                if (!ReferenceCountedOpenSslEngine.isEmpty(chain)) {
                    Certificate[] certificateArr = new Certificate[chain.length + 1];
                    this.peerCerts = certificateArr;
                    this.x509PeerCerts = new X509Certificate[chain.length + 1];
                    certificateArr[0] = new OpenSslX509Certificate(clientCert);
                    this.x509PeerCerts[0] = new OpenSslJavaxX509Certificate(clientCert);
                    initCerts(chain, 1);
                    return;
                }
                this.peerCerts = new Certificate[]{new OpenSslX509Certificate(clientCert)};
                this.x509PeerCerts = new X509Certificate[]{new OpenSslJavaxX509Certificate(clientCert)};
                return;
            }
            this.peerCerts = EmptyArrays.EMPTY_CERTIFICATES;
            this.x509PeerCerts = EmptyArrays.EMPTY_JAVAX_X509_CERTIFICATES;
        }

        private void initCerts(byte[][] chain, int startPos) {
            for (int i = 0; i < chain.length; i++) {
                int certPos = startPos + i;
                this.peerCerts[certPos] = new OpenSslX509Certificate(chain[i]);
                this.x509PeerCerts[certPos] = new OpenSslJavaxX509Certificate(chain[i]);
            }
        }

        private void selectApplicationProtocol() throws SSLException {
            ApplicationProtocolConfig.SelectedListenerFailureBehavior behavior = ReferenceCountedOpenSslEngine.this.apn.selectedListenerFailureBehavior();
            List<String> protocols = ReferenceCountedOpenSslEngine.this.apn.protocols();
            int i = AnonymousClass4.$SwitchMap$io$netty$handler$ssl$ApplicationProtocolConfig$Protocol[ReferenceCountedOpenSslEngine.this.apn.protocol().ordinal()];
            if (i != 1) {
                if (i == 2) {
                    String applicationProtocol = SSL.getAlpnSelected(ReferenceCountedOpenSslEngine.this.ssl);
                    if (applicationProtocol != null) {
                        ReferenceCountedOpenSslEngine.this.applicationProtocol = selectApplicationProtocol(protocols, behavior, applicationProtocol);
                    }
                } else if (i == 3) {
                    String applicationProtocol2 = SSL.getNextProtoNegotiated(ReferenceCountedOpenSslEngine.this.ssl);
                    if (applicationProtocol2 != null) {
                        ReferenceCountedOpenSslEngine.this.applicationProtocol = selectApplicationProtocol(protocols, behavior, applicationProtocol2);
                    }
                } else if (i == 4) {
                    String applicationProtocol3 = SSL.getAlpnSelected(ReferenceCountedOpenSslEngine.this.ssl);
                    if (applicationProtocol3 == null) {
                        applicationProtocol3 = SSL.getNextProtoNegotiated(ReferenceCountedOpenSslEngine.this.ssl);
                    }
                    if (applicationProtocol3 != null) {
                        ReferenceCountedOpenSslEngine.this.applicationProtocol = selectApplicationProtocol(protocols, behavior, applicationProtocol3);
                    }
                } else {
                    throw new Error();
                }
            }
        }

        private String selectApplicationProtocol(List<String> protocols, ApplicationProtocolConfig.SelectedListenerFailureBehavior behavior, String applicationProtocol) throws SSLException {
            if (behavior == ApplicationProtocolConfig.SelectedListenerFailureBehavior.ACCEPT) {
                return applicationProtocol;
            }
            int size = protocols.size();
            if (protocols.contains(applicationProtocol)) {
                return applicationProtocol;
            }
            if (behavior == ApplicationProtocolConfig.SelectedListenerFailureBehavior.CHOOSE_MY_LAST_PROTOCOL) {
                return protocols.get(size - 1);
            }
            throw new SSLException("unknown protocol " + applicationProtocol);
        }

        @Override // javax.net.ssl.SSLSession
        public Certificate[] getPeerCertificates() throws SSLPeerUnverifiedException {
            Certificate[] certificateArr;
            synchronized (ReferenceCountedOpenSslEngine.this) {
                if (ReferenceCountedOpenSslEngine.isEmpty(this.peerCerts)) {
                    throw new SSLPeerUnverifiedException("peer not verified");
                }
                certificateArr = (Certificate[]) this.peerCerts.clone();
            }
            return certificateArr;
        }

        @Override // javax.net.ssl.SSLSession
        public Certificate[] getLocalCertificates() {
            Certificate[] localCerts = ReferenceCountedOpenSslEngine.this.localCertificateChain;
            if (localCerts == null) {
                return null;
            }
            return (Certificate[]) localCerts.clone();
        }

        @Override // javax.net.ssl.SSLSession
        public X509Certificate[] getPeerCertificateChain() throws SSLPeerUnverifiedException {
            X509Certificate[] x509CertificateArr;
            synchronized (ReferenceCountedOpenSslEngine.this) {
                if (ReferenceCountedOpenSslEngine.isEmpty(this.x509PeerCerts)) {
                    throw new SSLPeerUnverifiedException("peer not verified");
                }
                x509CertificateArr = (X509Certificate[]) this.x509PeerCerts.clone();
            }
            return x509CertificateArr;
        }

        @Override // javax.net.ssl.SSLSession
        public Principal getPeerPrincipal() throws SSLPeerUnverifiedException {
            Certificate[] peer = getPeerCertificates();
            return ((java.security.cert.X509Certificate) peer[0]).getSubjectX500Principal();
        }

        @Override // javax.net.ssl.SSLSession
        public Principal getLocalPrincipal() {
            Certificate[] local = ReferenceCountedOpenSslEngine.this.localCertificateChain;
            if (local == null || local.length == 0) {
                return null;
            }
            return ((java.security.cert.X509Certificate) local[0]).getIssuerX500Principal();
        }

        @Override // javax.net.ssl.SSLSession
        public String getCipherSuite() {
            synchronized (ReferenceCountedOpenSslEngine.this) {
                if (this.cipher == null) {
                    return "SSL_NULL_WITH_NULL_NULL";
                }
                return this.cipher;
            }
        }

        @Override // javax.net.ssl.SSLSession
        public String getProtocol() {
            String protocol = this.protocol;
            if (protocol == null) {
                synchronized (ReferenceCountedOpenSslEngine.this) {
                    if (!ReferenceCountedOpenSslEngine.this.isDestroyed()) {
                        protocol = SSL.getVersion(ReferenceCountedOpenSslEngine.this.ssl);
                    } else {
                        protocol = "";
                    }
                }
            }
            return protocol;
        }

        @Override // javax.net.ssl.SSLSession
        public String getPeerHost() {
            return ReferenceCountedOpenSslEngine.this.getPeerHost();
        }

        @Override // javax.net.ssl.SSLSession
        public int getPeerPort() {
            return ReferenceCountedOpenSslEngine.this.getPeerPort();
        }

        @Override // javax.net.ssl.SSLSession
        public int getPacketBufferSize() {
            return ReferenceCountedOpenSslEngine.this.maxEncryptedPacketLength();
        }

        @Override // javax.net.ssl.SSLSession
        public int getApplicationBufferSize() {
            return this.applicationBufferSize;
        }

        @Override // io.netty.handler.ssl.OpenSslSession
        public void tryExpandApplicationBufferSize(int packetLengthDataOnly) {
            if (packetLengthDataOnly > ReferenceCountedOpenSslEngine.MAX_PLAINTEXT_LENGTH && this.applicationBufferSize != ReferenceCountedOpenSslEngine.MAX_RECORD_SIZE) {
                this.applicationBufferSize = ReferenceCountedOpenSslEngine.MAX_RECORD_SIZE;
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* renamed from: io.netty.handler.ssl.ReferenceCountedOpenSslEngine$4  reason: invalid class name */
    /* loaded from: classes.dex */
    public static /* synthetic */ class AnonymousClass4 {
        static final /* synthetic */ int[] $SwitchMap$io$netty$handler$ssl$ApplicationProtocolConfig$Protocol;
        static final /* synthetic */ int[] $SwitchMap$io$netty$handler$ssl$ClientAuth;
        static final /* synthetic */ int[] $SwitchMap$io$netty$handler$ssl$ReferenceCountedOpenSslEngine$HandshakeState;

        static {
            int[] iArr = new int[ApplicationProtocolConfig.Protocol.values().length];
            $SwitchMap$io$netty$handler$ssl$ApplicationProtocolConfig$Protocol = iArr;
            try {
                iArr[ApplicationProtocolConfig.Protocol.NONE.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$io$netty$handler$ssl$ApplicationProtocolConfig$Protocol[ApplicationProtocolConfig.Protocol.ALPN.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$io$netty$handler$ssl$ApplicationProtocolConfig$Protocol[ApplicationProtocolConfig.Protocol.NPN.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$io$netty$handler$ssl$ApplicationProtocolConfig$Protocol[ApplicationProtocolConfig.Protocol.NPN_AND_ALPN.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
            int[] iArr2 = new int[ClientAuth.values().length];
            $SwitchMap$io$netty$handler$ssl$ClientAuth = iArr2;
            try {
                iArr2[ClientAuth.NONE.ordinal()] = 1;
            } catch (NoSuchFieldError e5) {
            }
            try {
                $SwitchMap$io$netty$handler$ssl$ClientAuth[ClientAuth.REQUIRE.ordinal()] = 2;
            } catch (NoSuchFieldError e6) {
            }
            try {
                $SwitchMap$io$netty$handler$ssl$ClientAuth[ClientAuth.OPTIONAL.ordinal()] = 3;
            } catch (NoSuchFieldError e7) {
            }
            int[] iArr3 = new int[HandshakeState.values().length];
            $SwitchMap$io$netty$handler$ssl$ReferenceCountedOpenSslEngine$HandshakeState = iArr3;
            try {
                iArr3[HandshakeState.NOT_STARTED.ordinal()] = 1;
            } catch (NoSuchFieldError e8) {
            }
            try {
                $SwitchMap$io$netty$handler$ssl$ReferenceCountedOpenSslEngine$HandshakeState[HandshakeState.FINISHED.ordinal()] = 2;
            } catch (NoSuchFieldError e9) {
            }
            try {
                $SwitchMap$io$netty$handler$ssl$ReferenceCountedOpenSslEngine$HandshakeState[HandshakeState.STARTED_IMPLICITLY.ordinal()] = 3;
            } catch (NoSuchFieldError e10) {
            }
            try {
                $SwitchMap$io$netty$handler$ssl$ReferenceCountedOpenSslEngine$HandshakeState[HandshakeState.STARTED_EXPLICITLY.ordinal()] = 4;
            } catch (NoSuchFieldError e11) {
            }
        }
    }
}
