package io.netty.handler.ssl.util;

import io.netty.buffer.ByteBuf;
import io.netty.buffer.Unpooled;
import io.netty.handler.codec.base64.Base64;
import io.netty.util.CharsetUtil;
import io.netty.util.internal.SystemPropertyUtil;
import io.netty.util.internal.ThrowableUtil;
import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.security.KeyPair;
import java.security.KeyPairGenerator;
import java.security.NoSuchAlgorithmException;
import java.security.PrivateKey;
import java.security.SecureRandom;
import java.security.cert.CertificateEncodingException;
import java.security.cert.CertificateException;
import java.security.cert.CertificateFactory;
import java.security.cert.X509Certificate;
import java.util.Date;
/* loaded from: classes.dex */
public final class SelfSignedCertificate {
    private final X509Certificate cert;
    private final File certificate;
    private final PrivateKey key;
    private final File privateKey;
    private static final InternalLogger logger = InternalLoggerFactory.getInstance(SelfSignedCertificate.class);
    private static final Date DEFAULT_NOT_BEFORE = new Date(SystemPropertyUtil.getLong("io.netty.selfSignedCertificate.defaultNotBefore", System.currentTimeMillis() - 31536000000L));
    private static final Date DEFAULT_NOT_AFTER = new Date(SystemPropertyUtil.getLong("io.netty.selfSignedCertificate.defaultNotAfter", 253402300799000L));
    private static final int DEFAULT_KEY_LENGTH_BITS = SystemPropertyUtil.getInt("io.netty.handler.ssl.util.selfSignedKeyStrength", 2048);

    public SelfSignedCertificate() throws CertificateException {
        this(DEFAULT_NOT_BEFORE, DEFAULT_NOT_AFTER);
    }

    public SelfSignedCertificate(Date notBefore, Date notAfter) throws CertificateException {
        this("example.com", notBefore, notAfter);
    }

    public SelfSignedCertificate(String fqdn) throws CertificateException {
        this(fqdn, DEFAULT_NOT_BEFORE, DEFAULT_NOT_AFTER);
    }

    public SelfSignedCertificate(String fqdn, Date notBefore, Date notAfter) throws CertificateException {
        this(fqdn, ThreadLocalInsecureRandom.current(), DEFAULT_KEY_LENGTH_BITS, notBefore, notAfter);
    }

    public SelfSignedCertificate(String fqdn, SecureRandom random, int bits) throws CertificateException {
        this(fqdn, random, bits, DEFAULT_NOT_BEFORE, DEFAULT_NOT_AFTER);
    }

    public SelfSignedCertificate(String fqdn, SecureRandom random, int bits, Date notBefore, Date notAfter) throws CertificateException {
        String[] paths;
        try {
            KeyPairGenerator keyGen = KeyPairGenerator.getInstance("RSA");
            keyGen.initialize(bits, random);
            KeyPair keypair = keyGen.generateKeyPair();
            try {
                paths = OpenJdkSelfSignedCertGenerator.generate(fqdn, keypair, random, notBefore, notAfter);
            } catch (Throwable t) {
                logger.debug("Failed to generate a self-signed X.509 certificate using sun.security.x509:", t);
                try {
                    String[] paths2 = BouncyCastleSelfSignedCertGenerator.generate(fqdn, keypair, random, notBefore, notAfter);
                    paths = paths2;
                } catch (Throwable t2) {
                    logger.debug("Failed to generate a self-signed X.509 certificate using Bouncy Castle:", t2);
                    CertificateException certificateException = new CertificateException("No provider succeeded to generate a self-signed certificate. See debug log for the root cause.", t2);
                    ThrowableUtil.addSuppressed(certificateException, t);
                    throw certificateException;
                }
            }
            this.certificate = new File(paths[0]);
            this.privateKey = new File(paths[1]);
            this.key = keypair.getPrivate();
            FileInputStream certificateInput = null;
            try {
                try {
                    certificateInput = new FileInputStream(this.certificate);
                    this.cert = (X509Certificate) CertificateFactory.getInstance("X509").generateCertificate(certificateInput);
                    try {
                        certificateInput.close();
                    } catch (IOException e) {
                        if (logger.isWarnEnabled()) {
                            InternalLogger internalLogger = logger;
                            internalLogger.warn("Failed to close a file: " + this.certificate, (Throwable) e);
                        }
                    }
                } catch (Exception e2) {
                    throw new CertificateEncodingException(e2);
                }
            } catch (Throwable th) {
                if (certificateInput != null) {
                    try {
                        certificateInput.close();
                    } catch (IOException e3) {
                        if (logger.isWarnEnabled()) {
                            InternalLogger internalLogger2 = logger;
                            internalLogger2.warn("Failed to close a file: " + this.certificate, (Throwable) e3);
                        }
                    }
                }
                throw th;
            }
        } catch (NoSuchAlgorithmException e4) {
            throw new Error(e4);
        }
    }

    public File certificate() {
        return this.certificate;
    }

    public File privateKey() {
        return this.privateKey;
    }

    public X509Certificate cert() {
        return this.cert;
    }

    public PrivateKey key() {
        return this.key;
    }

    public void delete() {
        safeDelete(this.certificate);
        safeDelete(this.privateKey);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static String[] newSelfSignedCertificate(String fqdn, PrivateKey key, X509Certificate cert) throws IOException, CertificateEncodingException {
        ByteBuf wrappedBuf = Unpooled.wrappedBuffer(key.getEncoded());
        try {
            ByteBuf encodedBuf = Base64.encode(wrappedBuf, true);
            String keyText = "-----BEGIN PRIVATE KEY-----\n" + encodedBuf.toString(CharsetUtil.US_ASCII) + "\n-----END PRIVATE KEY-----\n";
            encodedBuf.release();
            wrappedBuf.release();
            File keyFile = File.createTempFile("keyutil_" + fqdn + '_', ".key");
            keyFile.deleteOnExit();
            OutputStream keyOut = new FileOutputStream(keyFile);
            try {
                keyOut.write(keyText.getBytes(CharsetUtil.US_ASCII));
                keyOut.close();
                keyOut = null;
                if (keyOut != null) {
                }
                wrappedBuf = Unpooled.wrappedBuffer(cert.getEncoded());
                try {
                    ByteBuf encodedBuf2 = Base64.encode(wrappedBuf, true);
                    String certText = "-----BEGIN CERTIFICATE-----\n" + encodedBuf2.toString(CharsetUtil.US_ASCII) + "\n-----END CERTIFICATE-----\n";
                    encodedBuf2.release();
                    wrappedBuf.release();
                    File certFile = File.createTempFile("keyutil_" + fqdn + '_', ".crt");
                    certFile.deleteOnExit();
                    OutputStream certOut = new FileOutputStream(certFile);
                    try {
                        certOut.write(certText.getBytes(CharsetUtil.US_ASCII));
                        certOut.close();
                        certOut = null;
                        if (certOut != null) {
                        }
                        return new String[]{certFile.getPath(), keyFile.getPath()};
                    } finally {
                        safeClose(certFile, certOut);
                        safeDelete(certFile);
                        safeDelete(keyFile);
                    }
                } finally {
                }
            } finally {
                safeClose(keyFile, keyOut);
                safeDelete(keyFile);
            }
        } finally {
        }
    }

    private static void safeDelete(File certFile) {
        if (!certFile.delete() && logger.isWarnEnabled()) {
            InternalLogger internalLogger = logger;
            internalLogger.warn("Failed to delete a file: " + certFile);
        }
    }

    private static void safeClose(File keyFile, OutputStream keyOut) {
        try {
            keyOut.close();
        } catch (IOException e) {
            if (logger.isWarnEnabled()) {
                InternalLogger internalLogger = logger;
                internalLogger.warn("Failed to close a file: " + keyFile, (Throwable) e);
            }
        }
    }
}
