package io.netty.handler.traffic;

import io.netty.buffer.ByteBuf;
import io.netty.channel.Channel;
import io.netty.channel.ChannelHandler;
import io.netty.channel.ChannelHandlerContext;
import io.netty.channel.ChannelPromise;
import io.netty.util.concurrent.EventExecutor;
import io.netty.util.internal.ObjectUtil;
import io.netty.util.internal.PlatformDependent;
import java.util.ArrayDeque;
import java.util.Iterator;
import java.util.concurrent.ConcurrentMap;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.atomic.AtomicLong;
@ChannelHandler.Sharable
/* loaded from: classes.dex */
public class GlobalTrafficShapingHandler extends AbstractTrafficShapingHandler {
    private final ConcurrentMap<Integer, PerChannel> channelQueues;
    long maxGlobalWriteSize;
    private final AtomicLong queuesSize;

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static final class PerChannel {
        long lastReadTimestamp;
        long lastWriteTimestamp;
        ArrayDeque<ToSend> messagesQueue;
        long queueSize;

        private PerChannel() {
        }
    }

    void createGlobalTrafficCounter(ScheduledExecutorService executor) {
        TrafficCounter tc = new TrafficCounter(this, (ScheduledExecutorService) ObjectUtil.checkNotNull(executor, "executor"), "GlobalTC", this.checkInterval);
        setTrafficCounter(tc);
        tc.start();
    }

    @Override // io.netty.handler.traffic.AbstractTrafficShapingHandler
    protected int userDefinedWritabilityIndex() {
        return 2;
    }

    public GlobalTrafficShapingHandler(ScheduledExecutorService executor, long writeLimit, long readLimit, long checkInterval, long maxTime) {
        super(writeLimit, readLimit, checkInterval, maxTime);
        this.channelQueues = PlatformDependent.newConcurrentHashMap();
        this.queuesSize = new AtomicLong();
        this.maxGlobalWriteSize = 419430400L;
        createGlobalTrafficCounter(executor);
    }

    public GlobalTrafficShapingHandler(ScheduledExecutorService executor, long writeLimit, long readLimit, long checkInterval) {
        super(writeLimit, readLimit, checkInterval);
        this.channelQueues = PlatformDependent.newConcurrentHashMap();
        this.queuesSize = new AtomicLong();
        this.maxGlobalWriteSize = 419430400L;
        createGlobalTrafficCounter(executor);
    }

    public GlobalTrafficShapingHandler(ScheduledExecutorService executor, long writeLimit, long readLimit) {
        super(writeLimit, readLimit);
        this.channelQueues = PlatformDependent.newConcurrentHashMap();
        this.queuesSize = new AtomicLong();
        this.maxGlobalWriteSize = 419430400L;
        createGlobalTrafficCounter(executor);
    }

    public GlobalTrafficShapingHandler(ScheduledExecutorService executor, long checkInterval) {
        super(checkInterval);
        this.channelQueues = PlatformDependent.newConcurrentHashMap();
        this.queuesSize = new AtomicLong();
        this.maxGlobalWriteSize = 419430400L;
        createGlobalTrafficCounter(executor);
    }

    public GlobalTrafficShapingHandler(EventExecutor executor) {
        this.channelQueues = PlatformDependent.newConcurrentHashMap();
        this.queuesSize = new AtomicLong();
        this.maxGlobalWriteSize = 419430400L;
        createGlobalTrafficCounter(executor);
    }

    public long getMaxGlobalWriteSize() {
        return this.maxGlobalWriteSize;
    }

    public void setMaxGlobalWriteSize(long maxGlobalWriteSize) {
        this.maxGlobalWriteSize = maxGlobalWriteSize;
    }

    public long queuesSize() {
        return this.queuesSize.get();
    }

    public final void release() {
        this.trafficCounter.stop();
    }

    private PerChannel getOrSetPerChannel(ChannelHandlerContext ctx) {
        Channel channel = ctx.channel();
        Integer key = Integer.valueOf(channel.hashCode());
        PerChannel perChannel = this.channelQueues.get(key);
        if (perChannel == null) {
            PerChannel perChannel2 = new PerChannel();
            perChannel2.messagesQueue = new ArrayDeque<>();
            perChannel2.queueSize = 0L;
            perChannel2.lastReadTimestamp = TrafficCounter.milliSecondFromNano();
            perChannel2.lastWriteTimestamp = perChannel2.lastReadTimestamp;
            this.channelQueues.put(key, perChannel2);
            return perChannel2;
        }
        return perChannel;
    }

    @Override // io.netty.channel.ChannelHandlerAdapter, io.netty.channel.ChannelHandler
    public void handlerAdded(ChannelHandlerContext ctx) throws Exception {
        getOrSetPerChannel(ctx);
        super.handlerAdded(ctx);
    }

    @Override // io.netty.channel.ChannelHandlerAdapter, io.netty.channel.ChannelHandler
    public void handlerRemoved(ChannelHandlerContext ctx) throws Exception {
        Channel channel = ctx.channel();
        Integer key = Integer.valueOf(channel.hashCode());
        PerChannel perChannel = this.channelQueues.remove(key);
        if (perChannel != null) {
            synchronized (perChannel) {
                if (channel.isActive()) {
                    Iterator<ToSend> it = perChannel.messagesQueue.iterator();
                    while (it.hasNext()) {
                        ToSend toSend = it.next();
                        long size = calculateSize(toSend.toSend);
                        this.trafficCounter.bytesRealWriteFlowControl(size);
                        perChannel.queueSize -= size;
                        this.queuesSize.addAndGet(-size);
                        ctx.write(toSend.toSend, toSend.promise);
                    }
                } else {
                    this.queuesSize.addAndGet(-perChannel.queueSize);
                    Iterator<ToSend> it2 = perChannel.messagesQueue.iterator();
                    while (it2.hasNext()) {
                        ToSend toSend2 = it2.next();
                        if (toSend2.toSend instanceof ByteBuf) {
                            ((ByteBuf) toSend2.toSend).release();
                        }
                    }
                }
                perChannel.messagesQueue.clear();
            }
        }
        releaseWriteSuspended(ctx);
        releaseReadSuspended(ctx);
        super.handlerRemoved(ctx);
    }

    @Override // io.netty.handler.traffic.AbstractTrafficShapingHandler
    long checkWaitReadTime(ChannelHandlerContext ctx, long wait, long now) {
        Integer key = Integer.valueOf(ctx.channel().hashCode());
        PerChannel perChannel = this.channelQueues.get(key);
        if (perChannel != null && wait > this.maxTime && (now + wait) - perChannel.lastReadTimestamp > this.maxTime) {
            return this.maxTime;
        }
        return wait;
    }

    @Override // io.netty.handler.traffic.AbstractTrafficShapingHandler
    void informReadOperation(ChannelHandlerContext ctx, long now) {
        Integer key = Integer.valueOf(ctx.channel().hashCode());
        PerChannel perChannel = this.channelQueues.get(key);
        if (perChannel != null) {
            perChannel.lastReadTimestamp = now;
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static final class ToSend {
        final ChannelPromise promise;
        final long relativeTimeAction;
        final long size;
        final Object toSend;

        private ToSend(long delay, Object toSend, long size, ChannelPromise promise) {
            this.relativeTimeAction = delay;
            this.toSend = toSend;
            this.size = size;
            this.promise = promise;
        }
    }

    /* JADX WARN: Removed duplicated region for block: B:41:0x00b6  */
    /* JADX WARN: Removed duplicated region for block: B:44:0x00bb  */
    @Override // io.netty.handler.traffic.AbstractTrafficShapingHandler
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    void submitWrite(final ChannelHandlerContext ctx, Object msg, long size, long writedelay, long now, ChannelPromise promise) {
        final PerChannel perChannel;
        long delay;
        long delay2;
        boolean globalSizeExceeded;
        Channel channel = ctx.channel();
        Integer key = Integer.valueOf(channel.hashCode());
        PerChannel perChannel2 = this.channelQueues.get(key);
        PerChannel perChannel3 = perChannel2 == null ? getOrSetPerChannel(ctx) : perChannel2;
        synchronized (perChannel3) {
            if (writedelay == 0) {
                try {
                    if (perChannel3.messagesQueue.isEmpty()) {
                        this.trafficCounter.bytesRealWriteFlowControl(size);
                        try {
                            ctx.write(msg, promise);
                            perChannel3.lastWriteTimestamp = now;
                        } catch (Throwable th) {
                            th = th;
                            perChannel = perChannel3;
                            while (true) {
                                try {
                                    break;
                                } catch (Throwable th2) {
                                    th = th2;
                                }
                            }
                            throw th;
                        }
                    }
                } catch (Throwable th3) {
                    th = th3;
                }
            }
            try {
                try {
                    try {
                        try {
                            if (writedelay > this.maxTime) {
                                long j = now + writedelay;
                                delay = writedelay;
                                try {
                                    long delay3 = perChannel3.lastWriteTimestamp;
                                    if (j - delay3 > this.maxTime) {
                                        delay2 = this.maxTime;
                                        long delay4 = delay2;
                                        ToSend newToSend = new ToSend(delay2 + now, msg, size, promise);
                                        perChannel3.messagesQueue.addLast(newToSend);
                                        perChannel3.queueSize += size;
                                        this.queuesSize.addAndGet(size);
                                        perChannel = perChannel3;
                                        checkWriteSuspend(ctx, delay4, perChannel3.queueSize);
                                        globalSizeExceeded = this.queuesSize.get() > this.maxGlobalWriteSize;
                                        if (globalSizeExceeded) {
                                            setUserDefinedWritability(ctx, false);
                                        }
                                        final long futureNow = newToSend.relativeTimeAction;
                                        ctx.executor().schedule(new Runnable() { // from class: io.netty.handler.traffic.GlobalTrafficShapingHandler.1
                                            @Override // java.lang.Runnable
                                            public void run() {
                                                GlobalTrafficShapingHandler.this.sendAllValid(ctx, perChannel, futureNow);
                                            }
                                        }, delay4, TimeUnit.MILLISECONDS);
                                        return;
                                    }
                                } catch (Throwable th4) {
                                    th = th4;
                                    perChannel = perChannel3;
                                    while (true) {
                                        break;
                                        break;
                                    }
                                    throw th;
                                }
                            } else {
                                delay = writedelay;
                            }
                            checkWriteSuspend(ctx, delay4, perChannel3.queueSize);
                            if (this.queuesSize.get() > this.maxGlobalWriteSize) {
                            }
                            if (globalSizeExceeded) {
                            }
                            final long futureNow2 = newToSend.relativeTimeAction;
                            ctx.executor().schedule(new Runnable() { // from class: io.netty.handler.traffic.GlobalTrafficShapingHandler.1
                                @Override // java.lang.Runnable
                                public void run() {
                                    GlobalTrafficShapingHandler.this.sendAllValid(ctx, perChannel, futureNow2);
                                }
                            }, delay4, TimeUnit.MILLISECONDS);
                            return;
                        } catch (Throwable th5) {
                            th = th5;
                            while (true) {
                                break;
                                break;
                            }
                            throw th;
                        }
                        ToSend newToSend2 = new ToSend(delay2 + now, msg, size, promise);
                        perChannel3.messagesQueue.addLast(newToSend2);
                        perChannel3.queueSize += size;
                        this.queuesSize.addAndGet(size);
                        perChannel = perChannel3;
                    } catch (Throwable th6) {
                        th = th6;
                        perChannel = perChannel3;
                    }
                    long delay42 = delay2;
                } catch (Throwable th7) {
                    th = th7;
                    perChannel = perChannel3;
                }
                delay2 = delay;
            } catch (Throwable th8) {
                th = th8;
                perChannel = perChannel3;
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void sendAllValid(ChannelHandlerContext ctx, PerChannel perChannel, long now) {
        synchronized (perChannel) {
            ToSend newToSend = perChannel.messagesQueue.pollFirst();
            while (true) {
                if (newToSend != null) {
                    if (newToSend.relativeTimeAction <= now) {
                        long size = newToSend.size;
                        this.trafficCounter.bytesRealWriteFlowControl(size);
                        perChannel.queueSize -= size;
                        this.queuesSize.addAndGet(-size);
                        ctx.write(newToSend.toSend, newToSend.promise);
                        perChannel.lastWriteTimestamp = now;
                        newToSend = perChannel.messagesQueue.pollFirst();
                    } else {
                        perChannel.messagesQueue.addFirst(newToSend);
                        break;
                    }
                } else {
                    break;
                }
            }
            if (perChannel.messagesQueue.isEmpty()) {
                releaseWriteSuspended(ctx);
            }
        }
        ctx.flush();
    }
}
